# -*- encoding: UTF-8 -*-

# list of affix codes
_lTags = ['1', '4eur', '2r', '1|2ux', '2', '1ux', '3er', '2f', '0x', '2x', '2i', '2a', '2u', '3c', '0es', '3x', '3|2', '1i', '1ies', '2ux', '5ur', '2en', '3en', '3ef', '3n', '3et', '3s', '4is', '3', '3ek', '1e', '4ec']

# dictionary of words with uncommon plurals (-x, -ux, english, latin and italian plurals) and tags to generate them
_dPlurMisc = {'fourneau': 8, 'memorandum': 11, 'jazzman': 21, 'mâtereau': 8, 'enfaiteau': 8, 'ouvreau': 8, 'pipeau': 8, 'barreau': 8, 'damoiseau': 8, 'winch': 14, 'monsignore': 17, 'instrumental': 5, 'penny': 18, 'alleu': 8, 'coupe-chou': 8, 'hippy': 18, 'corbeau': 8, 'bihoreau': 8, 'renouveau': 8, 'boutefeu': 8, 'sous-réseau': 8, 'troubleau': 8, 'maquereau': 8, 'acinus': 10, 'emporium': 11, 'yachtsman': 21, 'museau': 8, 'plateau': 8, 'hobereau': 8, 'genou': 8, 'écriteau': 8, 'ormeau': 8, 'corail': 19, 'terreau': 8, 'esquimau': 8, 'pizzicato': 17, 'bourreau': 8, 'pizzaiolo': 17, 'yeoman': 21, 'match': 14, 'bonneteau': 8, 'pieu': 8, 'matériau': 8, 'zigoteau': 8, 'présidial': 5, 'hoyau': 8, 'ramponneau': 8, 'hachereau': 8, 'écheveau': 8, 'cailleteau': 8, 'partita': 30, 'box': 14, 'libretto': 17, 'équatorial': 5, 'coach': 14, 'clash': 14, 'nursery': 18, 'grumeau': 8, 'louveteau': 8, 'passereau': 8, 'rampeau': 8, 'céteau': 8, 'condottiere': 17, 'brise-copeau': 8, 'rational': 5, 'travail': 19, 'escabeau': 8, 'tribunal': 5, 'bardeau': 8, 'chemineau': 8, 'oripeau': 8, 'dandy': 18, 'grimpereau': 8, 'moineau': 8, 'étau': 8, 'orignal': 5, 'flûtiau': 8, 'slash': 14, 'pourceau': 8, 'trumeau': 8, 'cranberry': 18, 'porte-manteau': 8, 'vantail': 19, 'camaïeu': 8, 'bail': 19, 'cuveau': 8, 'arioso': 17, 'bordereau': 8, 'canardeau': 8, 'plumasseau': 8, 'plumeau': 8, 'vassiveau': 8, 'oral': 5, 'vaisseau': 8, 'poètereau': 8, 'veau': 8, 'enfaîteau': 8, 'toccata': 30, 'hébreu': 8, 'franco-provençal': 5, 'caveau': 8, 'cuisseau': 8, 'géosynclinal': 5, 'carpeau': 8, 'niveau': 8, 'radeau': 8, 'vigneau': 8, 'trullo': 17, 'cheveu': 8, 'aveu': 8, 'nuraghe': 17, 'stimulus': 10, 'tommy': 18, 'brunch': 14, 'beau': 8, 'nanoréseau': 8, 'caniveau': 8, 'château': 8, 'canzone': 17, 'cyclo-cross': 14, 'chalumeau': 8, 'coupeau': 8, 'pointeau': 8, 'porte-couteau': 8, 'râteau': 8, 'batardeau': 8, 'meneau': 8, 'épieu': 8, 'piédestal': 5, 'tory': 18, 'jeu': 8, 'mail-coach': 14, 'sherry': 18, 'baby': 18, 'émail': 19, 'xénocristal': 5, 'burgau': 8, 'wallaby': 18, 'body': 18, 'penalty': 18, 'antiviral': 5, 'vocero': 17, 'soprano': 17, 'mal': 5, 'perchman': 21, 'sanatorium': 11, 'bateau': 8, 'arsenal': 5, 'triclinium': 11, 'bitoniau': 8, 'barbeau': 8, 'tyranneau': 8, 'fabliau': 8, 'aboiteau': 8, 'recordwoman': 21, 'latifundium': 11, 'portemanteau': 8, 'traineau': 8, 'feld-maréchal': 5, 'pigeonneau': 8, 'vousseau': 8, 'ypréau': 8, 'gentleman': 21, 'pastoureau': 8, 'demi-dieu': 8, 'pou': 8, 'caillou': 8, 'columbarium': 11, 'proxy': 18, 'barman': 21, 'biscoteau': 8, 'baggy': 18, 'couteau': 8, 'midshipman': 21, 'biveau': 8, 'bravo': 17, 'non-métal': 5, 'biomatériau': 8, 'dindonneau': 8, 'recordman': 21, 'rouleau': 8, 'tuyau': 8, 'faiteau': 8, 'arceau': 8, 'cherry': 18, 'girafeau': 8, 'scratch': 14, 'bedeau': 8, 'chauffe-eau': 8, 'ventail': 19, 'quintal': 5, 'carreau': 8, 'lieu': 8, 'puceau': 8, 'brigandeau': 8, 'sureau': 8, 'dinghy': 18, 'grau': 8, 'biseau': 8, 'micronoyau': 8, 'doubleau': 8, 'rugbyman': 21, 'bécasseau': 8, 'coyau': 8, 'verseau': 8, 'gentry': 18, 'contre-feu': 8, 'jumeau': 8, 'gouttereau': 8, 'scenario': 17, 'flambeau': 8, 'yachtwoman': 21, 'scriptorium': 11, 'faisanneau': 8, 'étourneau': 8, 'ruisseau': 8, 'prima-donna': 30, 'garden-party': 18, 'saumoneau': 8, 'ramereau': 8, 'naseau': 8, 'casseau': 8, 'cristal': 5, 'maffioso': 17, 'peau': 8, 'sulky': 18, 'fronteau': 8, 'exemplum': 11, 'neveu': 8, 'claveau': 8, 'antijeu': 8, 'hâtiveau': 8, 'ferry': 18, 'tufeau': 8, 'trousseau': 8, 'fromental': 5, 'porte-drapeau': 8, 'tonlieu': 8, 'fanal': 5, 'baliveau': 8, 'hors-jeu': 8, 'coagulum': 11, 'bush': 14, 'smash': 14, 'lionceau': 8, 'carneau': 8, 'organeau': 8, 'oppidum': 11, 'tord-boyau': 8, 'outardeau': 8, 'morceau': 8, 'bocal': 5, 'gerzeau': 8, 'pointal': 5, 'boucau': 8, 'milieu': 8, 'couvre-feu': 8, 'impresario': 17, 'éfourceau': 8, 'sketch': 14, 'rideau': 8, 'lapereau': 8, 'fluteau': 8, 'bouleau': 8, 'corporal': 5, 'self-made-woman': 21, 'businessman': 21, 'paparazzo': 17, 'prélinteau': 8, 'houseau': 8, 'pique-feu': 8, 'hobby': 18, 'bijou': 8, 'clameau': 8, 'fricandeau': 8, 'soupirail': 19, 'rondeau': 8, 'hameau': 8, 'quasi-cristal': 5, 'crash': 14, 'porte-chapeau': 8, 'pousse-caillou': 8, 'soliveau': 8, 'flutiau': 8, 'tourteau': 8, 'boisseau': 8, 'curriculum': 11, 'ripou': 8, 'bluteau': 8, 'héronneau': 8, 'chéneau': 8, 'policeman': 21, 'lavatory': 18, 'non-lieu': 8, 'baleineau': 8, 'flash': 14, 'pifferaro': 17, 'métal': 5, 'desideratum': 11, 'pecorino': 17, 'rejeu': 8, 'agneau': 8, 'quantum': 11, 'noyau': 8, 'urinal': 5, 'majoral': 5, 'journal': 5, 'racinal': 5, 'cigogneau': 8, 'chevreau': 8, 'loqueteau': 8, 'fuseau': 8, 'coccus': 10, 'bull-finch': 14, 'yachtman': 21, 'ricercare': 17, 'contrefeu': 8, 'confessionnal': 5, 'boss': 14, 'chameau': 8, 'liteau': 8, 'renardeau': 8, 'rabat-eau': 8, 'tennisman': 21, 'boyau': 8, 'poireau': 8, 'tenniswoman': 21, 'joyau': 8, 'cardinal': 5, 'dieu': 8, 'arrière-vassal': 5, 'zingaro': 17, 'hâtereau': 8, 'phylum': 11, 'gâteau': 8, 'souriceau': 8, 'sénéchal': 5, 'lambeau': 8, 'friponneau': 8, 'pineau': 8, 'merleau': 8, 'sceau': 8, 'faisandeau': 8, 'arbrisseau': 8, 'berceau': 8, 'guideau': 8, 'éléphanteau': 8, 'carbonaro': 17, 'vanneau': 8, 'doleau': 8, 'speakeasy': 18, 'tourangeau': 8, 'animal': 5, 'oculus': 10, 'réal': 5, 'signal': 5, 'vau': 8, 'roseau': 8, 'jottereau': 8, 'sautereau': 8, 'ecstasy': 18, 'trijumeau': 8, 'crève-tonneau': 8, 'jouvenceau': 8, 'pommeau': 8, 'fesse-mathieu': 8, 'ronchonneau': 8, 'vitrail': 19, 'godelureau': 8, 'bau': 8, 'phénocristal': 5, 'scotch': 14, 'nouveau': 8, 'cerveau': 8, 'marteau': 8, 'businesswoman': 21, 'fauconneau': 8, 'antislash': 14, 'hirondeau': 8, 'gémeau': 8, 'tumulus': 10, 'appeau': 8, 'cadeau': 8, 'lady': 18, 'tréteau': 8, 'daleau': 8, 'touchau': 8, 'chou': 8, 'pectoral': 5, 'bigarreau': 8, 'cameraman': 21, 'local': 5, 'enjeu': 8, 'official': 5, 'grizzly': 18, 'chapiteau': 8, 'canal': 5, 'paisseau': 8, 'guindeau': 8, 'courlieu': 8, 'grémial': 5, 'réseau': 8, 'antirétroviral': 5, 'rameau': 8, 'surjeu': 8, 'conneau': 8, 'tasseau': 8, 'panneau': 8, 'téléjournal': 5, 'moyeu': 8, 'bandeau': 8, 'solo': 17, 'snoreau': 8, 'coteau': 8, 'colineau': 8, 'fieu': 8, 'pianissimo': 17, 'gruau': 8, 'tombeau': 8, 'processionnal': 5, 'sèche-cheveu': 8, 'tableau': 8, 'linteau': 8, 'aisseau': 8, 'sandwich': 14, 'garde-feu': 8, 'cross-country': 18, 'medium': 11, 'vice-amiral': 5, 'gemmail': 19, 'sanctoral': 5, 'flûteau': 8, 'têteau': 8, 'drapeau': 8, 'eau': 8, 'juste-milieu': 8, 'arrière-cerveau': 8, 'vermisseau': 8, 'lazzarone': 17, 'arcdoubleau': 8, 'superman': 21, 'hôpital': 5, 'hottereau': 8, 'dégueu': 8, 'aboteau': 8, 'allume-feu': 8, 'essieu': 8, 'marsupial': 5, 'scutum': 11, 'gluau': 8, 'vipéreau': 8, 'merbau': 8, 'vœu': 8, 'poétereau': 8, 'faisceau': 8, 'javeau': 8, 'fardeau': 8, 'husky': 18, 'sous-arbrisseau': 8, 'conoyau': 8, 'tuffeau': 8, 'rush': 14, 'mémorial': 5, 'taxum': 11, 'idéal': 5, 'asseau': 8, 'gagman': 21, 'godiveau': 8, 'traîneau': 8, 'miss': 14, 'jet-society': 18, 'mafioso': 17, 'whisky': 18, 'coulisseau': 8, 'pagus': 10, 'pintadeau': 8, 'ciseau': 8, 'porreau': 8, 'gruppetto': 17, 'levreau': 8, 'bestiau': 8, 'temporal': 5, 'couleuvreau': 8, 'fléau': 8, 'tire-feu': 8, 'coupe-feu': 8, 'saute-ruisseau': 8, 'panonceau': 8, 'rousseau': 8, 'criterium': 11, 'chenal': 5, 'ramponeau': 8, 'haveneau': 8, 'putto': 17, 'junky': 18, 'chapeau': 8, 'végétal': 5, 'optimum': 11, 'ponceau': 8, 'lobby': 18, 'tempo': 17, 'préau': 8, 'serdeau': 8, 'brandy': 18, 'manteau': 8, 'abdominal': 5, 'chrémeau': 8, 'bigorneau': 8, 'hibou': 8, 'wattman': 21, 'numéral': 5, 'demi-mal': 5, 'désaveu': 8, 'cerceau': 8, 'éditorial': 5, 'car-ferry': 18, 'faîteau': 8, 'jambonneau': 8, 'sportsman': 21, 'aloyau': 8, 'diurnal': 5, 'taureau': 8, 'pinceau': 8, 'cache-museau': 8, 'télétravail': 19, 'adieu': 8, 'tourtereau': 8, 'paonneau': 8, 'madrigal': 5, 'feu': 8, 'fermail': 19, 'polycristal': 5, 'tuileau': 8, 'cerneau': 8, 'listeau': 8, 'caïeu': 8, 'flush': 14, 'fécial': 5, 'tonneau': 8, 'sacramental': 5, 'speech': 14, 'poteau': 8, 'troupeau': 8, 'erseau': 8, 'pruneau': 8, 'pontuseau': 8, 'seau': 8, 'nanomatériau': 8, 'monceau': 8, 'self-made-man': 21, 'nobliau': 8, 'chaudeau': 8, 'boqueteau': 8, 'clergyman': 21, 'moreau': 8, 'lorry': 18, 'oiseau': 8, 'gerseau': 8, 'créneau': 8, 'procès-verbal': 5, 'impedimentum': 11, 'rinceau': 8, 'yeomanry': 18, 'buggy': 18, 'cheval': 5, 'bureau': 8, 'pureau': 8, 'rash': 14, 'blaireau': 8, 'cordeau': 8, 'mangonneau': 8, 'serpenteau': 8, 'ombudsman': 21, 'pupazzo': 17, 'chanteau': 8, 'perdreau': 8, 'yachtswoman': 21, 'monocristal': 5, 'microcristal': 5, 'copeau': 8, 'protège-genou': 8, 'lunch': 14, 'ranch': 14, 'joujou': 8, 'pare-feu': 8, 'lanterneau': 8, 'pitch': 14, 'addendum': 11, 'marmenteau': 8, 'simbleau': 8, 'symposium': 11, 'juke-box': 14, 'fontainebleau': 8, 'scrogneugneu': 8, 'remix': 14, 'fourreau': 8, 'tombereau': 8, 'anneau': 8}

# dictionary of feminine forms and tags to generate masculine forms (singular and plural)
_dMasFW = {'pétocharde': 0, 'corticospinale': 3, 'déstabilisatrice': 1, 'capricante': 0, 'salienne': 4, 'abyssine': 0, 'souveraine': 0, 'longitudinale': 3, 'chlorophyllienne': 4, 'pompeuse': 9, 'répétitrice': 1, 'vivrière': 6, 'canneuse': 2, 'noircissante': 0, 'pédaleuse': 2, 'arroseuse': 2, 'synchroniseuse': 2, 'haline': 0, 'piétinante': 0, 'chiffonnière': 6, 'laveuse': 2, 'azoteuse': 9, 'hydrothermale': 3, 'braillante': 0, 'hypothético-déductive': 7, 'bouchonnière': 6, 'séparative': 7, 'inattaquée': 0, 'assyro-babylonienne': 4, 'préorale': 3, 'grivoise': 0, 'relationnelle': 4, 'orale': 3, 'jubilante': 0, 'receveuse': 2, 'voisée': 0, 'urticante': 0, 'virevoltante': 0, 'bougresse': 16, 'brulante': 0, 'inhumaine': 0, 'tienne': 4, 'étalonneuse': 2, 'alcalescente': 0, 'scrotale': 3, 'poussiéreuse': 9, 'foraminée': 0, 'primordiale': 3, 'corailleuse': 2, 'imbue': 0, 'suprahumaine': 0, 'bringuebalante': 0, 'louviéroise': 0, 'tombante': 0, 'ionisante': 0, 'essayeuse': 2, 'infuse': 0, 'tutrice': 1, 'moricaude': 0, 'surréelle': 4, 'radiotélévisée': 0, 'boutonneuse': 9, 'palée': 0, 'tiraillante': 0, 'retorse': 0, 'conservative': 7, 'catégorielle': 4, 'harassante': 0, 'lisseuse': 2, 'ressasseuse': 2, 'fromentale': 3, 'blasonneuse': 2, 'légiférée': 0, 'aveyronnaise': 0, 'sentencieuse': 9, 'kleinienne': 4, 'excitatrice': 1, 'affreuse': 9, 'cacaotée': 0, 'consolatrice': 1, 'rhodiée': 0, 'robinétière': 6, 'pratiquante': 0, 'survireuse': 2, 'surie': 0, 'saligote': 0, 'normalienne': 4, 'bastillée': 0, 'attractrice': 1, 'ribosomale': 3, 'introductrice': 1, 'suspensive': 7, 'impatientante': 0, 'bolivarienne': 4, 'fuyante': 0, 'amatrice': 1, 'effluente': 0, 'alizéenne': 4, 'ratière': 6, 'routinière': 6, 'exerçante': 0, 'coréenne': 4, 'berçante': 0, 'curative': 7, 'révisionnelle': 4, 'exaspérante': 0, 'ténébreuse': 9, 'mugissante': 0, 'rajeunisseuse': 2, 'rétienne': 4, 'existante': 0, 'bretillienne': 4, 'héliograveuse': 2, 'basselissière': 6, 'catalane': 0, 'méningée': 0, 'seule': 0, 'pénalisante': 0, 'éditoriale': 3, 'procuratrice': 1, 'gamine': 0, 'grognonne': 4, 'didacticienne': 4, 'romaine': 0, 'surintendante': 0, 'mouflette': 4, 'pensionnée': 0, 'rouée': 0, 'tournante': 0, 'proactive': 7, 'songeuse': 2, 'usagère': 6, 'pisseuse': 9, 'chevrière': 6, 'qualifiée': 0, 'huileuse': 9, 'cambodgienne': 4, 'ethmoïdale': 3, 'hollandaise': 0, 'climatisante': 0, 'photoconductrice': 1, 'déchiffreuse': 2, 'camérière': 6, 'inquisitive': 7, 'melliflue': 0, 'gantelée': 0, 'opalescente': 0, 'salariée': 0, 'sotte': 4, 'perforatrice': 1, 'descriptrice': 1, 'préfacière': 6, 'bassecourière': 6, 'hormonale': 3, 'agrafeuse': 2, 'phonatrice': 1, 'biculturelle': 4, 'bienvenue': 0, 'meulière': 6, 'liquoreuse': 9, 'fréquente': 0, 'cliquetante': 0, 'camuse': 0, 'poudroyante': 0, 'presciente': 0, 'puérile': 0, 'alcaline': 0, 'arabo-musulmane': 0, 'nuptiale': 3, 'orthonormale': 3, 'béguë': 0, 'patrilocale': 3, 'troqueuse': 2, 'inconventionnelle': 4, 'fréquentielle': 4, 'prostitutionnelle': 4, 'introvertie': 0, 'infinitive': 7, 'performante': 0, 'pharaonienne': 4, 'biphasée': 0, 'dépossédée': 0, 'naturelle': 4, 'pensante': 0, 'originelle': 4, 'relieuse': 2, 'délinquante': 0, 'pronatrice': 1, 'hypogée': 0, 'tricoteuse': 2, 'agatisée': 0, 'maigriotte': 4, 'compilatrice': 1, 'austro-américaine': 0, 'causative': 7, 'akkadienne': 4, 'clapotante': 0, 'malicieuse': 9, 'béninoise': 0, 'irréfutée': 0, 'qualificative': 7, 'enragée': 0, 'répartitrice': 1, 'latinisante': 0, 'bardeuse': 2, 'calomniatrice': 1, 'batteuse': 2, 'gazouilleuse': 2, 'écrivassière': 6, 'polynomiale': 3, 'fraichissante': 0, 'surgénératrice': 1, 'catégorisante': 0, 'anglo-française': 0, 'interruptrice': 1, 'diaconale': 3, 'stéréorégulière': 6, 'transfuseuse': 2, 'avenante': 0, 'attendrissante': 0, 'infradienne': 4, 'monophasée': 0, 'chaussante': 0, 'jennérienne': 4, 'veinarde': 0, 'boueuse': 9, 'demi-morte': 0, 'unilobée': 0, 'durale': 3, 'branchiale': 3, 'amélioratrice': 1, 'noueuse': 9, 'pro-occidentale': 3, 'émeutière': 6, 'humaine': 0, 'nicheuse': 2, 'nazie': 0, 'phylogénéticienne': 4, 'assommante': 0, 'rebutante': 0, 'détenue': 0, 'extra-professionnelle': 4, 'pleurarde': 0, 'brillante': 0, 'oxydoréductrice': 1, 'post-industrielle': 4, 'jouisseuse': 2, 'guindailleuse': 2, 'méticuleuse': 9, 'expéditrice': 1, 'curieuse': 9, 'aliénée': 0, 'bioluminescente': 0, 'enquiquinante': 0, 'pigeonnante': 0, 'indo-européenne': 4, 'stoïcienne': 4, 'recruteuse': 2, 'codificatrice': 1, 'éventée': 0, 'vigilante': 0, 'haussmannienne': 4, 'tordeuse': 2, 'fuligineuse': 9, 'entarteuse': 2, 'monocamérale': 3, 'émancipatrice': 1, 'flambeuse': 2, 'toulousaine': 0, 'jacobine': 0, 'pétrinienne': 4, 'interindividuelle': 4, 'locomotive': 7, 'disproportionnelle': 4, 'fomenteuse': 2, 'coléreuse': 9, 'écrivaine': 0, 'avouée': 0, 'capétienne': 4, 'crevante': 0, 'archimédienne': 4, 'autoportante': 0, 'affétée': 0, 'admiratrice': 1, 'réorganisatrice': 1, 'eczémateuse': 9, 'wallingante': 0, 'sectatrice': 1, 'dégoulinante': 0, 'surencombrée': 0, 'applaudisseuse': 2, 'résistive': 7, 'occurrente': 0, 'fulgurante': 0, 'saunante': 0, 'pascalienne': 4, 'jobarde': 0, 'hauturière': 6, 'trifoliée': 0, 'tarbaise': 0, 'véhémente': 0, 'hôtelière': 6, 'solfatarienne': 4, 'intestine': 0, 'entraînante': 0, 'dispersante': 0, 'économétricienne': 4, 'dispersive': 7, 'dubitative': 7, 'oblate': 0, 'pointeuse': 2, 'bileuse': 9, 'magrébine': 0, 'cocardière': 6, 'charançonnée': 0, 'phosphatière': 6, 'pharyngée': 0, 'rigoureuse': 9, 'resarcelée': 0, 'pommetée': 0, 'synoviale': 3, 'aragonaise': 0, 'raccommodeuse': 2, 'vivrée': 0, 'qualitative': 7, 'cuniculicultrice': 1, 'vannière': 6, 'miroitée': 0, 'voltigeante': 0, 'insurgée': 0, 'agenouillée': 0, 'hurluberlue': 0, 'faucardeuse': 2, 'réalisatrice': 1, 'composante': 0, 'usitée': 0, 'desséchante': 0, 'nuageuse': 9, 'limitante': 0, 'désabusée': 0, 'polycristalline': 0, 'non-inscrite': 0, 'silencieuse': 9, 'simulatrice': 1, 'biquette': 4, 'mixeuse': 2, 'enchanteresse': 20, 'garibaldienne': 4, 'choyée': 0, 'péteuse': 9, 'vertébrée': 0, 'intergénérationnelle': 4, 'avant-courrière': 6, 'non-résidente': 0, 'amincissante': 0, 'appelée': 0, 'déchargeuse': 2, 'développeuse': 2, 'tricamérale': 3, 'néolibérale': 3, 'subventionnelle': 4, 'interpolatrice': 1, 'résiliente': 0, 'semi-finie': 0, 'unidirectionnelle': 4, 'zimbabwéenne': 4, 'mulâtresse': 16, 'épuratrice': 1, 'rappeuse': 2, 'dolosive': 7, 'transcriptrice': 1, 'formante': 0, 'curarisante': 0, 'différentielle': 4, 'abatteuse': 2, 'protectionnelle': 4, 'réprobatrice': 1, 'coffreuse': 2, 'verrière': 6, 'néohébridaise': 0, 'cagneuse': 9, 'grenobloise': 0, 'aisée': 0, 'béatifiante': 0, 'faiblarde': 0, 'pénarde': 0, 'émotionnelle': 4, 'ornementale': 3, 'compositrice': 1, 'miellée': 0, 'denchée': 0, 'glottale': 3, 'censée': 0, 'bonifiante': 0, 'affréteuse': 2, 'génoise': 0, 'assidue': 0, 'bourdonnée': 0, 'cyberdépendante': 0, 'isarienne': 4, 'brisante': 0, 'microbienne': 4, 'randonneuse': 2, 'fiscale': 3, 'laudanisée': 0, 'traversante': 0, 'pluvieuse': 9, 'hypertensive': 7, 'agglomérante': 0, 'traumatisante': 0, 'coorganisatrice': 1, 'ordinatrice': 1, 'boulette': 4, 'mycélienne': 4, 'impatiente': 0, 'béarnaise': 0, 'australo-néo-zélandaise': 0, 'retardée': 0, 'enrouleuse': 2, 'pâlichonne': 4, 'abrutissante': 0, 'aumônière': 6, 'volleyeuse': 2, 'précambrienne': 4, 'capacitive': 7, 'distributionnelle': 4, 'marécageuse': 9, 'recycleuse': 2, 'affranchie': 0, 'régatière': 6, 'radiale': 3, 'ailière': 6, 'pressante': 0, 'cathédrale': 3, 'croustilleuse': 9, 'prévaricatrice': 1, 'chamoiseuse': 2, 'combative': 7, 'bourgeoisiale': 3, 'subintrante': 0, 'rotacée': 0, 'joufflue': 0, 'gommeuse': 9, 'amortisseuse': 2, 'surabondante': 0, 'imparidigitée': 0, 'ratiocineuse': 2, 'contrastante': 0, 'gersoise': 0, 'aéronavale': 0, 'artérielle': 4, 'gemmeuse': 2, 'pronominale': 3, 'rhodanienne': 4, 'autopropulsée': 0, 'forgeuse': 2, 'thermopropulsée': 0, 'chryséléphantine': 0, 'pharisienne': 4, 'commensale': 3, 'prêcheuse': 2, 'irrévélée': 0, 'bitumineuse': 9, 'déclamatrice': 1, 'tempérante': 0, 'extracorporelle': 4, 'anti-microbienne': 4, 'intergouvernementale': 3, 'basketteuse': 2, 'gantière': 6, 'neurocognitive': 7, 'claustrale': 3, 'ansérine': 0, 'notatrice': 1, 'recréatrice': 1, 'perceptrice': 1, 'infiltrée': 0, 'farfelue': 0, 'guérisseuse': 2, 'anomale': 3, 'perturbative': 7, 'bottière': 6, 'gambadeuse': 2, 'crayonneuse': 9, 'métayère': 6, 'volatile': 0, 'reposante': 0, 'autoroutière': 6, 'inconsistante': 0, 'stationnée': 0, 'soulaude': 0, 'lithinée': 0, 'grisonnante': 0, 'tachante': 0, 'canardière': 6, 'réticente': 0, 'connaisseuse': 2, 'gauloise': 0, 'parapétrolière': 6, 'remonteuse': 2, 'routière': 6, 'convergente': 0, 'laceuse': 2, 'luxueuse': 9, 'persécutante': 0, 'croisée': 0, 'séléniteuse': 9, 'hydratante': 0, 'permanente': 0, 'herborisatrice': 1, 'radiative': 7, 'flicarde': 0, 'suburbaine': 0, 'éjective': 7, 'extrémale': 3, 'suspecte': 0, 'polarde': 0, 'dénominative': 7, 'designeuse': 2, 'ginguette': 4, 'franco-italienne': 4, 'coracoïdienne': 4, 'pattue': 0, 'thésarde': 0, 'siamoise': 0, 'pétrolière': 6, 'avant-dernière': 6, 'gazetière': 6, 'bagarreuse': 2, 'plombeuse': 9, 'éthérée': 0, 'pionne': 4, 'blonde': 0, 'suppresseuse': 2, 'brunette': 4, 'chirurgicale': 3, 'rabatteuse': 2, 'bilatérale': 3, 'versaillaise': 0, 'aidante': 0, 'virginale': 3, 'allumée': 0, 'loco-régionale': 3, 'réhabilitatrice': 1, 'végétale': 3, 'paire': 0, 'plurielle': 4, 'paraverbale': 3, 'cendreuse': 9, 'biacuminée': 0, 'américano-canadienne': 4, 'injonctive': 7, 'mandante': 0, 'abbatiale': 3, 'tutorale': 0, 'filleule': 0, 'maxillofaciale': 3, 'échauffée': 0, 'poursuiveuse': 2, 'péroreuse': 2, 'compendieuse': 9, 'susvisée': 0, 'abrogative': 7, 'spatiotemporelle': 4, 'viseuse': 9, 'aphteuse': 9, 'clavière': 6, 'retraitée': 0, 'condescendante': 0, 'blêmissante': 0, 'indomptée': 0, 'venimeuse': 9, 'modale': 3, 'subsidiante': 0, 'confirmative': 7, 'prétentiarde': 0, 'rationalisante': 0, 'inexacte': 0, 'hélicoïdale': 3, 'comparative': 7, 'empoisonnante': 0, 'ptoléméenne': 4, 'nivale': 3, 'vagabonde': 0, 'caramélée': 0, 'iridescente': 0, 'intégrodifférentielle': 4, 'grognante': 0, 'sucrière': 6, 'silicatée': 0, 'écuyère': 6, 'bimodale': 3, 'faciale': 3, 'caravanière': 6, 'sadducéenne': 4, 'markovienne': 4, 'altitudinale': 3, 'conditionnelle': 4, 'strip-teaseuse': 2, 'amorceuse': 2, 'confiturière': 6, 'carcinomateuse': 9, 'flemmarde': 0, 'autoexcitatrice': 1, 'intentionnée': 0, 'trivalente': 0, 'stative': 7, 'accompagnatrice': 1, 'intracérébrale': 3, 'électromécanicienne': 4, 'aigrelette': 4, 'cicatricielle': 4, 'cabaretière': 6, 'circonciseuse': 2, 'socioprofessionnelle': 4, 'promise': 0, 'regimbeuse': 2, 'couperosée': 0, 'bélizienne': 4, 'birationnelle': 4, 'exfoliante': 0, 'châtreuse': 2, 'diophantienne': 4, 'arrondisseuse': 2, 'paulinienne': 4, 'adnée': 0, 'groenlandaise': 0, 'nord-coréenne': 4, 'compacteuse': 2, 'thyristorisée': 0, 'surcapitalisante': 0, 'passionnelle': 4, 'tapissière': 6, 'accommodatrice': 1, 'spoliatrice': 1, 'neuromotrice': 1, 'couverte': 0, 'automnale': 3, 'ascendante': 0, 'allaitante': 0, 'câblière': 6, 'napoléonienne': 4, 'pipelette': 4, 'décatisseuse': 2, 'grincheuse': 9, 'coccygienne': 4, 'maniaco-dépressive': 7, 'alcalino-terreuse': 9, 'individualisante': 0, 'ano-rectale': 3, 'interronégative': 7, 'ferblantière': 6, 'franchouillarde': 0, 'califale': 3, 'maximale': 3, 'brunissante': 0, 'frotteuse': 2, 'discale': 3, 'pénitentielle': 4, 'abélienne': 4, 'fragrante': 0, 'zodiacale': 3, 'conquérante': 0, 'prestidigitatrice': 1, 'jacasseuse': 2, 'encenseuse': 2, 'captante': 0, 'cotonneuse': 9, 'violoneuse': 9, 'couteuse': 9, 'flirteuse': 2, 'technicienne': 4, 'grisouteuse': 9, 'cafetière': 6, 'insultée': 0, 'usuelle': 4, 'aqueuse': 9, 'injurieuse': 9, 'mafieuse': 9, 'délibérée': 0, 'passante': 0, 'mentholée': 0, 'massive': 7, 'appauvrissante': 0, 'fricoteuse': 2, 'supplétive': 7, 'hercynienne': 4, 'opacifiante': 0, 'pelvienne': 4, 'franco-macédonienne': 4, 'dynamicienne': 4, 'vraie': 0, 'papoue': 0, 'successorale': 3, 'jardinière': 6, 'fondée': 0, 'chevaline': 0, 'entôleuse': 2, 'suractivée': 0, 'cascadeuse': 2, 'piteuse': 9, 'masculine': 0, 'ultramarine': 0, 'récognitive': 7, 'radoteuse': 2, 'néo-natale': 0, 'régisseuse': 2, 'insidieuse': 9, 'intercommunale': 3, 'vicésimale': 3, 'initiale': 3, 'indochinoise': 0, 'caleuse': 2, 'inanimée': 0, 'cahotante': 0, 'ennemie': 0, 'ogresse': 16, 'labiodentale': 3, 'ambulancière': 6, 'aiguilleuse': 2, 'triennale': 3, 'youpine': 0, 'fortuite': 0, 'écumeuse': 9, 'vaine': 0, 'périlleuse': 9, 'déblayeuse': 2, 'enfileuse': 2, 'paresseuse': 9, 'machinatrice': 1, 'loueuse': 2, 'amylacée': 0, 'conciliante': 0, 'commentatrice': 1, 'glaucomateuse': 9, 'médicochirurgicale': 3, 'boucheuse': 2, 'résidentielle': 4, 'aérodigestive': 7, 'ardéchoise': 0, 'mortifiante': 0, 'sèche': 31, 'régénérante': 0, 'défoliante': 0, 'duodénale': 3, 'gerbante': 0, 'tempéramentale': 3, 'ansée': 0, 'zinzoline': 0, 'sélectrice': 1, 'dégénérative': 7, 'mieux-disante': 0, 'permanencière': 6, 'rectificatrice': 1, 'puéricultrice': 1, 'variolée': 0, 'mort-née': 0, 'tireuse': 2, 'intervieweuse': 2, 'embosseuse': 2, 'graveuse': 2, 'joueuse': 2, 'frissonnante': 0, 'mystificatrice': 1, 'néo-grecque': 28, 'packageuse': 2, 'infractionnelle': 4, 'bandante': 0, 'monacale': 3, 'rémunératrice': 1, 'assertive': 7, 'douanière': 6, 'immunosuppressive': 7, 'objectale': 3, 'trimestrielle': 4, 'inhospitalière': 6, 'médullosurrénale': 3, 'monomotrice': 1, 'éprise': 0, 'baissière': 6, 'gélatineuse': 9, 'électropositive': 7, 'trempeuse': 2, 'cornéenne': 4, 'bruinée': 0, 'protubérante': 0, 'variationnelle': 4, 'déstressante': 0, 'irraisonnée': 0, 'parapublique': 13, 'trésorière': 6, 'séminale': 3, 'cimmérienne': 4, 'lénitive': 7, 'ciliée': 0, 'bledarde': 0, 'arménienne': 4, 'reprise': 0, 'excipée': 0, 'junonienne': 4, 'rostrale': 3, 'communiante': 0, 'soûlarde': 0, 'ivoirienne': 4, 'classicisante': 0, 'subaiguë': 0, 'féroïenne': 4, 'apprêteuse': 2, 'non-figurative': 7, 'bienséante': 0, 'débraillée': 0, 'capucine': 0, 'charognarde': 0, 'rajeunissante': 0, 'bourrue': 0, 'quinquennale': 3, 'gaussienne': 4, 'fautive': 7, 'chamailleuse': 2, 'narratrice': 1, 'auscultatrice': 1, 'piémontaise': 0, 'hongkongaise': 0, 'stabilisante': 0, 'hachischine': 0, 'obsessionnelle': 4, 'reconnaissante': 0, 'chiridienne': 4, 'quadripartie': 0, 'physicienne': 4, 'estudiantine': 0, 'boréale': 3, 'déréelle': 4, 'faraude': 0, 'accaparante': 0, 'salée': 0, 'vasculeuse': 9, 'coproductrice': 1, 'achirale': 3, 'dédaléenne': 4, 'zostérienne': 4, 'préoccupante': 0, 'cybercriminelle': 4, 'spiralée': 0, 'anticancéreuse': 9, 'falote': 0, 'phalanstérienne': 4, 'butinante': 0, 'scélérate': 0, 'obédientielle': 4, 'apprentie': 0, 'sadico-anale': 3, 'hennuyère': 6, 'chevelée': 0, 'pareuse': 2, 'mentale': 3, 'vairée': 0, 'transfusionnelle': 4, 'ordonnancière': 6, 'scléreuse': 9, 'visqueuse': 9, 'cruelle': 4, 'malteuse': 2, 'décérébrée': 0, 'martiniquaise': 0, 'impécunieuse': 9, 'laideronne': 4, 'démonstratrice': 1, 'transylvaine': 0, 'diamantine': 0, 'seigneuriale': 3, 'déprédatrice': 1, 'sébacée': 0, 'couillue': 0, 'flamboyante': 0, 'foliée': 0, 'croquignolette': 4, 'paysagère': 6, 'ultra-libérale': 3, 'lettrée': 0, 'cédante': 0, 'quêteuse': 2, 'diagnosticienne': 4, 'marmiteuse': 9, 'administrative': 7, 'locatrice': 1, 'majorante': 0, 'technico-commerciale': 3, 'praticienne': 4, 'malfaitrice': 1, 'rustaude': 0, 'pillarde': 0, 'ministérielle': 4, 'dépaysante': 0, 'urogénitale': 3, 'réfractrice': 1, 'perlière': 6, 'californienne': 4, 'stipitée': 0, 'cantonnière': 6, 'solidienne': 4, 'coobligée': 0, 'enrichissante': 0, 'indulgente': 0, 'laudatrice': 1, 'épicycloïdale': 3, 'déstructurante': 0, 'jugale': 3, 'déconneuse': 2, 'alarmante': 0, 'préceptorale': 3, 'unifoliée': 0, 'associatrice': 1, 'assonancée': 0, 'sacrificielle': 4, 'pure': 0, 'comorienne': 4, 'dineuse': 2, 'tambourinante': 0, 'emberlificoteuse': 2, 'diluviale': 3, 'zonière': 6, 'pondérale': 3, 'niveleuse': 2, 'omnipuissante': 0, 'désoxydante': 0, 'stripteaseuse': 2, 'prosociale': 3, 'mitoyenne': 4, 'bourgeonneuse': 9, 'distributrice': 1, 'cafarde': 0, 'gouleyante': 0, 'régale': 0, 'caponne': 4, 'coquelucheuse': 9, 'journaleuse': 9, 'parotidienne': 4, 'fruitarienne': 4, 'jointée': 0, 'échafaudeuse': 2, 'meilleure': 0, 'circonspecte': 0, 'surcompensatrice': 1, 'taraudeuse': 2, 'rurbaine': 0, 'anglaise': 0, 'policière': 6, 'charnue': 0, 'enchaînée': 0, 'possédante': 0, 'décervelée': 0, 'jurisprudentielle': 4, 'énervante': 0, 'étuveuse': 2, 'alvéolée': 0, 'mandarinale': 3, 'métaxiale': 3, 'correctionnelle': 4, 'appellative': 7, 'corégente': 0, 'impartiale': 3, 'éradicatrice': 1, 'ouvrante': 0, 'contre-productive': 7, 'consonante': 0, 'crédirentière': 6, 'fatale': 0, 'romane': 0, 'récollette': 4, 'rythmicienne': 4, 'déserte': 0, 'éthicienne': 4, 'falsificatrice': 1, 'équipière': 6, 'recenseuse': 2, 'placière': 6, 'fourmillante': 0, 'monitrice': 1, 'exagérative': 7, 'guillocheuse': 2, 'démarcheuse': 2, 'chichiteuse': 9, 'gallo-romane': 0, 'stridulante': 0, 'fraîchissante': 0, 'aguichante': 0, 'scrabbleuse': 2, 'soûle': 0, 'lorentzienne': 4, 'filante': 0, 'paumière': 6, 'conative': 7, 'chartreuse': 9, 'adlérienne': 4, 'vogoule': 0, 'empotée': 0, 'tentatrice': 1, 'artisane': 0, 'alternative': 7, 'agresseuse': 2, 'agenceuse': 2, 'tapeuse': 2, 'récifale': 3, 'ratée': 0, 'hypochloreuse': 9, 'matelote': 0, 'dégourdissante': 0, 'géopoliticienne': 4, 'émanée': 0, 'incompréhensive': 7, 'gasconne': 4, 'saxonne': 4, 'bourbonienne': 4, 'enfoirée': 0, 'tocarde': 0, 'bosnienne': 4, 'fœtale': 3, 'léonarde': 0, 'percluse': 0, 'patriarcale': 3, 'ronceuse': 9, 'marathonienne': 4, 'foreuse': 2, 'bissectrice': 1, 'contrintuitive': 7, 'pelletière': 6, 'rétinienne': 4, 'interrogatrice': 1, 'matriceuse': 2, 'antidétonante': 0, 'analysée': 0, 'contrôleuse': 2, 'cérébro-spinale': 3, 'arsine': 0, 'gymnasienne': 4, 'rhino-pharyngienne': 4, 'prévoyante': 0, 'ultracourte': 0, 'amplificatrice': 1, 'eurasienne': 4, 'encaissante': 0, 'qualiticienne': 4, 'arnaquée': 0, 'parqueuse': 2, 'charnelle': 4, 'négociante': 0, 'ottomane': 0, 'médicamenteuse': 9, 'omnidirectionnelle': 4, 'stridente': 0, 'ressortissante': 0, 'imposante': 0, 'profective': 7, 'paumée': 0, 'pelleteuse': 2, 'bourrative': 7, 'plaideuse': 2, 'estivante': 0, 'décalqueuse': 2, 'surcomposée': 0, 'médiatrice': 1, 'inhérente': 0, 'encodeuse': 2, 'éducatrice': 1, 'soûlote': 0, 'rangeuse': 2, 'inétendue': 0, 'flaireuse': 2, 'flammée': 0, 'expiratrice': 1, 'papilleuse': 9, 'kafkaïenne': 4, 'traitante': 0, 'imprécise': 0, 'héritière': 6, 'multiplicative': 7, 'valorisante': 0, 'passeuse': 2, 'intrusive': 7, 'courageuse': 9, 'mutilante': 0, 'inductrice': 1, 'cireuse': 9, 'flippante': 0, 'écraseuse': 2, 'mongolienne': 4, 'flapie': 0, 'bloqueuse': 2, 'inquisitrice': 1, 'crawleuse': 2, 'pionnière': 6, 'rénitente': 0, 'ancestrale': 3, 'dessiccatrice': 1, 'expropriatrice': 1, 'jaunette': 4, 'géocacheuse': 2, 'franco-vénézuélienne': 4, 'petiote': 0, 'salonnière': 6, 'abyssinienne': 4, 'navale': 0, 'antirationnelle': 4, 'déhontée': 0, 'tyrolienne': 4, 'anodiseuse': 2, 'lunetière': 6, 'additionnelle': 4, 'ignée': 0, 'noiraude': 0, 'herseuse': 2, 'antenaise': 0, 'cérébelleuse': 9, 'positive': 7, 'incarnadine': 0, 'perfoliée': 0, 'assiégée': 0, 'publique': 13, 'inconnue': 0, 'ordinale': 3, 'pakistanaise': 0, 'autopunitive': 7, 'archère': 6, 'thermidorienne': 4, 'consistoriale': 3, 'grandelette': 4, 'survitaminée': 0, 'globuleuse': 9, 'impressionnante': 0, 'freudienne': 4, 'bisannuelle': 4, 'sahraouie': 0, 'évolutive': 7, 'réactionnelle': 4, 'constante': 0, 'patagonne': 4, 'experte': 0, 'entremetteuse': 2, 'pleurale': 3, 'verticillée': 0, 'miraillée': 0, 'développée': 0, 'antigravitationnelle': 4, 'offrante': 0, 'nippo-coréenne': 4, 'dimissoriale': 3, 'périgourdine': 0, 'traçante': 0, 'occasionnelle': 4, 'sévrienne': 4, 'crêpière': 6, 'glissante': 0, 'amuseuse': 2, 'occupante': 0, 'démesurée': 0, 'groupale': 3, 'brève': 23, 'identificatrice': 1, 'lignifiante': 0, 'redentée': 0, 'fruitière': 6, 'divertissante': 0, 'échangeuse': 2, 'atténuante': 0, 'polarisatrice': 1, 'atonale': 3, 'sinisante': 0, 'florentine': 0, 'recourante': 0, 'monopoleuse': 2, 'libidineuse': 9, 'cagote': 0, 'calqueuse': 2, 'gaveuse': 2, 'platonicienne': 4, 'cavalière': 6, 'validatrice': 1, 'exclue': 0, 'immunodépressive': 7, 'chrismale': 3, 'murrhine': 0, 'poilue': 0, 'affabulatrice': 1, 'danienne': 4, 'vaincue': 0, 'superlative': 7, 'dissimulatrice': 1, 'explosée': 0, 'empaleuse': 2, 'plate': 0, 'cadreuse': 2, 'charpentière': 6, 'négatrice': 1, 'gloutonne': 4, 'roublarde': 0, 'autoadjointe': 0, 'amante': 0, 'mouvante': 0, 'tonifiante': 0, 'acclamatrice': 1, 'unitive': 7, 'anti-ministérielle': 4, 'survirante': 0, 'antimicrobienne': 4, 'seulette': 4, 'séropositive': 7, 'attacheuse': 2, 'astucieuse': 9, 'annulatrice': 1, 'néocalédonienne': 4, 'focalisante': 0, 'graillonneuse': 9, 'défavorisée': 0, 'zingueuse': 2, 'cintrière': 6, 'simplette': 4, 'adulescente': 0, 'magyare': 0, 'éminatie': 0, 'oratrice': 1, 'effective': 7, 'nabote': 0, 'relayeuse': 2, 'pasteurienne': 4, 'véreuse': 9, 'nictitante': 0, 'basse-lissière': 6, 'stabilisatrice': 1, 'cuproammoniacale': 3, 'fainéante': 0, 'enficelée': 0, 'lyonnaise': 0, 'presseuse': 2, 'rétive': 7, 'clocharde': 0, 'patronnière': 6, 'ambleuse': 2, 'préfixale': 3, 'décourageante': 0, 'pluridimensionnelle': 4, 'américaine': 0, 'carcérale': 3, 'anticoncurrentielle': 4, 'sirupeuse': 9, 'soufie': 0, 'sacrifiée': 0, 'amochée': 0, 'jointoyeuse': 2, 'cigarière': 6, 'ouralienne': 4, 'polyinsaturée': 0, 'élévatrice': 1, 'tuante': 0, 'réglante': 0, 'idempotente': 0, 'non-comparante': 0, 'gagnante': 0, 'visitatrice': 1, 'spiritueuse': 9, 'facturière': 6, 'détersive': 7, 'lorraine': 0, 'pimpante': 0, 'pyrénéenne': 4, 'immorale': 3, 'harmonieuse': 9, 'persévérante': 0, 'opaline': 0, 'dolente': 0, 'galonnière': 6, 'malnutrie': 0, 'résignée': 0, 'normale': 3, 'accélératrice': 1, 'trompeuse': 2, 'vaginale': 3, 'germano-chinoise': 0, 'ottonienne': 4, 'bobeuse': 2, 'prudentielle': 4, 'laborantine': 0, 'narrative': 7, 'cachotière': 6, 'propharmacienne': 4, 'dératiseuse': 2, 'colorante': 0, 'vichyssoise': 0, 'archetière': 6, 'avitailleuse': 2, 'hypotendue': 0, 'batifoleuse': 2, 'fourchue': 0, 'prisonnière': 6, 'endormeuse': 2, 'agaçante': 0, 'trépignante': 0, 'œuvée': 0, 'lutéale': 3, 'suceuse': 2, 'métrosexuelle': 4, 'lianescente': 0, 'œstrale': 3, 'indue': 0, 'badigeonneuse': 2, 'conchoïdale': 3, 'bergère': 6, 'septembrale': 3, 'jeuneuse': 2, 'préenregistrée': 0, 'manifestante': 0, 'élisabéthaine': 0, 'néogrecque': 28, 'historienne': 4, 'casernière': 6, 'tavernière': 6, 'centennale': 3, 'luxembourgeoise': 0, 'singapourienne': 4, 'oléicultrice': 1, 'transcontinentale': 3, 'grassmannienne': 4, 'asphyxiante': 0, 'juteuse': 9, 'trifoliolée': 0, 'émulsive': 7, 'pollinisatrice': 1, 'malaimée': 0, 'traînante': 0, 'anémiante': 0, 'sempervirente': 0, 'nouménale': 3, 'cavaleuse': 2, 'barbette': 4, 'congénitale': 3, 'imprimeuse': 2, 'nulle': 4, 'incohérente': 0, 'coquillère': 6, 'pourvoyeuse': 2, 'émergente': 0, 'membraneuse': 9, 'inertielle': 4, 'galvanisante': 0, 'insatisfaisante': 0, 'cueilleuse': 2, 'interro-négative': 7, 'batelière': 6, 'déodorante': 0, 'foncière': 6, 'mayennaise': 0, 'bouillante': 0, 'immortelle': 4, 'landaise': 0, 'aboyeuse': 2, 'crénelée': 0, 'verticale': 3, 'pointilleuse': 9, 'bouleversante': 0, 'contraventionnelle': 4, 'marsupiale': 3, 'ulcéreuse': 9, 'excitée': 0, 'nationale': 3, 'momentanée': 0, 'réconfortante': 0, 'adoratrice': 1, 'assesseure': 0, 'mate': 0, 'driveuse': 2, 'militante': 0, 'semi-ouvrée': 0, 'beylicale': 3, 'grossissante': 0, 'dissipative': 7, 'cafardeuse': 9, 'médiane': 0, 'circassienne': 4, 'truculente': 0, 'dépouilleuse': 2, 'décisionnelle': 4, 'hivernale': 3, 'claironnante': 0, 'taxative': 7, 'décolleteuse': 2, 'bas-jointée': 0, 'ocellée': 0, 'accédée': 0, 'franco-américaine': 0, 'infinitésimale': 3, 'percheuse': 2, 'pantoise': 0, 'souillarde': 0, 'réquisitoriale': 3, 'inter-institutionnelle': 4, 'cybernéticienne': 4, 'intersidérale': 3, 'sud-africaine': 0, 'albumineuse': 9, 'alcalinoterreuse': 9, 'blédarde': 0, 'intempérante': 0, 'rocailleuse': 9, 'bourgeoise': 0, 'gracieuse': 9, 'surirradiée': 0, 'abracadabrante': 0, 'maigrichonne': 4, 'fanatiseuse': 2, 'vice-chancelière': 6, 'faramineuse': 9, 'saccharinée': 0, 'foutue': 0, 'anti-infectieuse': 9, 'onguiculée': 0, 'univariante': 0, 'centreuse': 2, 'laineuse': 9, 'tinctoriale': 3, 'taupière': 6, 'dilatante': 0, 'pernicieuse': 9, 'mogole': 0, 'sanieuse': 9, 'hyperactive': 7, 'tibiotarsienne': 4, 'gangréneuse': 9, 'shamane': 0, 'renifleuse': 2, 'disruptive': 7, 'rationnelle': 4, 'capitulée': 0, 'traverse': 0, 'semi-publique': 13, 'géomaticienne': 4, 'roguée': 0, 'psychomotricienne': 4, 'serpentante': 0, 'alternante': 0, 'batelée': 0, 'intestinale': 3, 'sodée': 0, 'monologueuse': 2, 'végétarienne': 4, 'togolaise': 0, 'offensante': 0, 'persécutée': 0, 'phéromonale': 3, 'équarrisseuse': 2, 'luminescente': 0, 'critiqueuse': 2, 'avisée': 0, 'ombiliquée': 0, 'cotisante': 0, 'croquante': 0, 'ludo-éducative': 7, 'dissolutive': 7, 'rôtisseuse': 2, 'larmoyante': 0, 'détoxifiante': 0, 'différenciatrice': 1, 'régressée': 0, 'coprésidente': 0, 'impondérée': 0, 'nodale': 3, 'répétitive': 7, 'molletonneuse': 9, 'incuite': 0, 'skieuse': 2, 'anticoagulante': 0, 'ramenarde': 0, 'fortraite': 0, 'casinotière': 6, 'broussailleuse': 9, 'néandertalienne': 4, 'corrélative': 7, 'tiercée': 0, 'grasse': 4, 'grise': 0, 'trachéenne': 4, 'haineuse': 9, 'godillante': 0, 'chaisière': 6, 'sénégambienne': 4, 'nosocomiale': 3, 'exclusive': 7, 'vaurienne': 4, 'trouveuse': 2, 'dégravelante': 0, 'immunisée': 0, 'radioamatrice': 1, 'haversienne': 4, 'carrière': 6, 'éclairante': 0, 'contreperçante': 0, 'mutante': 0, 'quincaillère': 6, 'buccogénitale': 3, 'épépineuse': 2, 'dégoûtante': 0, 'sétacée': 0, 'congolaise': 0, 'chanoinesse': 16, 'augustinienne': 4, 'maîtresse': 16, 'émulsifiante': 0, 'piqueniqueuse': 2, 'cotidale': 3, 'cobelligérante': 0, 'belgo-allemande': 0, 'voisine': 0, 'pourfendeuse': 2, 'instrumentale': 3, 'amusante': 0, 'vocale': 3, 'unifamiliale': 3, 'connotative': 7, 'givrante': 0, 'finissante': 0, 'instructive': 7, 'thermopropulsive': 7, 'escrimeuse': 2, 'persistante': 0, 'avalante': 0, 'botswanaise': 0, 'ptérygoïdienne': 4, 'saleuse': 2, 'chanteuse': 2, 'bigoudène': 22, 'combinarde': 0, 'minérale': 3, 'cantinière': 6, 'villageoise': 0, 'trilatérale': 3, 'menottée': 0, 'formative': 7, 'teenageuse': 2, 'grande': 0, 'impersonnelle': 4, 'provocante': 0, 'chélatrice': 1, 'divine': 0, 'prénormale': 3, 'cigarettière': 6, 'barlongue': 4, 'irréligieuse': 9, 'balayeuse': 2, 'aconière': 6, 'berceuse': 2, 'salante': 0, 'reconventionnelle': 4, 'asociale': 3, 'nécessiteuse': 9, 'sarthoise': 0, 'inaperçue': 0, 'objective': 7, 'sarcleuse': 2, 'incarnate': 0, 'instructrice': 1, 'jamaïquaine': 0, 'silurienne': 4, 'antérieure': 0, 'sous-dominante': 0, 'uro-génitale': 3, 'empaillée': 0, 'chauffante': 0, 'scriptrice': 1, 'néonatale': 0, 'déroulante': 0, 'paternelle': 4, 'cocréancière': 6, 'noire': 0, 'conserveuse': 2, 'microtonale': 0, 'libéroligneuse': 9, 'géomancienne': 4, 'interprofessionnelle': 4, 'épateuse': 2, 'coulée': 0, 'antimoniée': 0, 'homoparentale': 3, 'ventripotente': 0, 'conséquente': 0, 'hondurienne': 4, 'poseuse': 2, 'naisseuse': 2, 'sénatrice': 1, 'houspilleuse': 2, 'déchirante': 0, 'trachéale': 3, 'contre-amirale': 3, 'singulière': 6, 'téléspectatrice': 1, 'gazée': 0, 'antillaise': 0, 'kirghize': 0, 'supra-humaine': 0, 'maraîchère': 6, 'crawlée': 0, 'vilaine': 0, 'fonceuse': 2, 'féline': 0, 'soixante-huitarde': 0, 'ovarienne': 4, 'liliale': 3, 'intrafamiliale': 3, 'néo-nazie': 0, 'transformante': 0, 'péjorative': 7, 'trophomicrobienne': 4, 'survolante': 0, 'fouteuse': 2, 'fascisante': 0, 'rimbaldienne': 4, 'pieuse': 9, 'réhydratante': 0, 'déperlante': 0, 'imprécatrice': 1, 'bestiale': 3, 'rechigneuse': 9, 'pulsative': 7, 'avantageuse': 9, 'markéteuse': 2, 'procréatrice': 1, 'routarde': 0, 'malandreuse': 9, 'moulante': 0, 'surale': 3, 'non-croyante': 0, 'éteigneuse': 2, 'dévoratrice': 1, 'immersive': 7, 'sauvageonne': 4, 'tisserande': 0, 'séante': 0, 'encartoucheuse': 2, 'querelleuse': 2, 'partielle': 4, 'terrorisante': 0, 'actuelle': 4, 'collaborative': 7, 'convertisseuse': 2, 'bâtisseuse': 2, 'peltée': 0, 'étonnante': 0, 'informaticienne': 4, 'déchue': 0, 'arrimeuse': 2, 'tractrice': 1, 'organophosphorée': 0, 'irritante': 0, 'diffluente': 0, 'nociceptive': 7, 'nominatrice': 1, 'naufragée': 0, 'assamaise': 0, 'intéressée': 0, 'matrilocale': 3, 'institutrice': 1, 'protestante': 0, 'rieuse': 2, 'centrafricaine': 0, 'parentérale': 3, 'pilleuse': 2, 'talentueuse': 9, 'infranationale': 3, 'errante': 0, 'judéo-espagnole': 0, 'naïve': 7, 'lipschitzienne': 4, 'vitupératrice': 1, 'druidesse': 16, 'inconsolée': 0, 'quadragésimale': 3, 'judéo-allemande': 0, 'pointue': 0, 'fraternelle': 4, 'cubitale': 3, 'confectionneuse': 2, 'préadolescente': 0, 'captative': 7, 'adverbiale': 3, 'hâbleuse': 2, 'sacchareuse': 9, 'coucheuse': 2, 'livreuse': 2, 'commettante': 0, 'démonstrative': 7, 'trainante': 0, 'dévotieuse': 9, 'inactuelle': 4, 'écrue': 0, 'buissonnante': 0, 'moussue': 0, 'sud-américaine': 0, 'luisante': 0, 'tabulatrice': 1, 'sigillée': 0, 'résonante': 0, 'pèquenotte': 4, 'contributive': 7, 'anglo-saxonne': 4, 'marteleuse': 2, 'dopante': 0, 'ammoniacée': 0, 'saisonnière': 6, 'hervienne': 4, 'transafricaine': 0, 'ténue': 0, 'auboise': 0, 'emphysémateuse': 9, 'curiale': 3, 'pourrisseuse': 2, 'paysagée': 0, 'arthurienne': 4, 'gazonnante': 0, 'insistante': 0, 'polytraumatisée': 0, 'adjacente': 0, 'antipodale': 3, 'rayonnante': 0, 'semi-développée': 0, 'compensatrice': 1, 'gymnasiale': 3, 'cancéreuse': 9, 'bio-industrielle': 4, 'réticulo-endothéliale': 3, 'joviale': 3, 'incorrecte': 0, 'inondée': 0, 'patente': 0, 'reçue': 0, 'concentreuse': 2, 'lointaine': 0, 'non-voyante': 0, 'significative': 7, 'belligérante': 0, 'ombrageuse': 9, 'bailleresse': 20, 'varappeuse': 2, 'développante': 0, 'tranquillisante': 0, 'linière': 6, 'brideuse': 2, 'repasseuse': 2, 'indivise': 0, 'réduplicative': 7, 'découpeuse': 2, 'verveuse': 9, 'récursive': 7, 'polisseuse': 2, 'rénovatrice': 1, 'binaurale': 3, 'mûrie': 0, 'décalcifiante': 0, 'graffeuse': 2, 'tenante': 0, 'écolière': 6, 'cabote': 0, 'sicilienne': 4, 'sclérifiante': 0, 'lustrale': 3, 'papillonnante': 0, 'médico-chirurgicale': 3, 'fovéale': 3, 'compacte': 0, 'dahoméenne': 4, 'bannie': 0, 'vénézuélienne': 4, 'hebdomadière': 6, 'muette': 4, 'thermorésistante': 0, 'picoleuse': 2, 'antibourgeoise': 0, 'consultrice': 1, 'équine': 0, 'greffeuse': 2, 'huronienne': 4, 'buronnière': 6, 'domoticienne': 4, 'titubante': 0, 'verviétoise': 0, 'hircine': 0, 'bibeloteuse': 2, 'prépalatale': 3, 'providente': 0, 'épierreuse': 2, 'hachichine': 0, 'verdurière': 6, 'savoureuse': 9, 'vénéneuse': 9, 'écailleuse': 9, 'corticale': 3, 'jet-setteuse': 2, 'rougissante': 0, 'gravitationnelle': 4, 'susdénommée': 0, 'magicienne': 4, 'sortante': 0, 'cytogénéticienne': 4, 'accentuelle': 4, 'porchère': 6, 'cooccurrente': 0, 'engazonneuse': 2, 'haschischée': 0, 'chiffreuse': 2, 'rimeuse': 2, 'bourguignonne': 4, 'buffetière': 6, 'embusquée': 0, 'incantatrice': 1, 'populeuse': 9, 'préélectorale': 3, 'totipotente': 0, 'jordanienne': 4, 'modernisatrice': 1, 'martienne': 4, 'inspiratrice': 1, 'fédérative': 7, 'ankylosante': 0, 'subexponentielle': 4, 'lobulée': 0, 'vociférante': 0, 'herborisée': 0, 'alfatière': 6, 'intimée': 0, 'kényane': 0, 'irrévérente': 0, 'faîtière': 6, 'meusienne': 4, 'percheronne': 4, 'vénielle': 4, 'aiguë': 0, 'collatérale': 3, 'altière': 6, 'décevante': 0, 'bise': 0, 'rabattante': 0, 'orofaciale': 3, 'surdéterminée': 0, 'quémandeuse': 2, 'aigrettée': 0, 'fuguée': 0, 'olivacée': 0, 'isospectrale': 3, 'pulsionnelle': 4, 'bibliotechnicienne': 4, 'australo-américaine': 0, 'sulfurisée': 0, 'envoûtée': 0, 'spectatrice': 1, 'soleilleuse': 9, 'sensibilisatrice': 1, 'allodiale': 3, 'opprimée': 0, 'fiévreuse': 9, 'mécontente': 0, 'clairvoyante': 0, 'inférovariée': 0, 'remorqueuse': 2, 'enfantine': 0, 'craqueuse': 2, 'circonvoisine': 0, 'rotatrice': 1, 'ressemeleuse': 2, 'dépréciatrice': 1, 'paneuropéenne': 4, 'carminative': 7, 'multidirectionnelle': 4, 'autoadaptative': 7, 'vieillissante': 0, 'précédente': 0, 'éreintante': 0, 'contraignante': 0, 'notariée': 0, 'décanale': 3, 'baylienne': 4, 'repoussante': 0, 'compactifiée': 0, 'marxienne': 4, 'redistributive': 7, 'survivante': 0, 'tripoteuse': 2, 'déloyale': 3, 'contremaitresse': 16, 'clinquante': 0, 'captatrice': 1, 'citatrice': 1, 'égéenne': 4, 'trigonale': 3, 'trancheuse': 2, 'confédérale': 3, 'maçonne': 4, 'complimenteuse': 2, 'solénoïdale': 3, 'vitelline': 0, 'purifiante': 0, 'habilleuse': 2, 'mâtine': 0, 'intégrale': 3, 'battante': 0, 'inchoative': 7, 'hardie': 0, 'rudérale': 3, 'horodatrice': 1, 'frisquette': 4, 'beurrière': 6, 'modificatrice': 1, 'formosane': 0, 'vacharde': 0, 'filtrante': 0, 'proportionnelle': 4, 'santonnière': 6, 'biduale': 3, 'raisonneuse': 2, 'intransigeante': 0, 'hensélienne': 4, 'carbonylée': 0, 'pétreuse': 9, 'hominisée': 0, 'biennale': 3, 'minière': 6, 'positionnelle': 4, 'fructueuse': 9, 'calamiteuse': 9, 'invariante': 0, 'fausse': 15, 'gouteuse': 9, 'aberrante': 0, 'palatiale': 3, 'parsie': 0, 'bouquetière': 6, 'pluviale': 3, 'raideuse': 2, 'hackeuse': 2, 'cruciale': 3, 'extinctrice': 1, 'exploratrice': 1, 'faneuse': 2, 'luxuriante': 0, 'lancinante': 0, 'teneuse': 2, 'imagière': 6, 'capésienne': 4, 'vaudoise': 0, 'inséminatrice': 1, 'sécurisante': 0, 'citoyenne': 4, 'fondante': 0, 'ovine': 0, 'bridgeuse': 2, 'dévorante': 0, 'herniée': 0, 'réceptrice': 1, 'parnassienne': 4, 'circumnavigatrice': 1, 'absorbante': 0, 'horticultrice': 1, 'cokéfiante': 0, 'biseauteuse': 2, 'hyposulfureuse': 9, 'ensemblière': 6, 'loubarde': 0, 'dévolutive': 7, 'lamellée': 0, 'resquilleuse': 2, 'avocate': 0, 'marinière': 6, 'glanduleuse': 9, 'extra-sensorielle': 4, 'apicultrice': 1, 'interrogée': 0, 'bradeuse': 2, 'mailleuse': 2, 'vétilleuse': 9, 'métaphysicienne': 4, 'franco-vietnamienne': 4, 'fongueuse': 9, 'bouillonnante': 0, 'lysosomiale': 3, 'thermocollée': 0, 'soufflante': 0, 'conversationnelle': 4, 'polluposteuse': 2, 'arénacée': 0, 'astringente': 0, 'gueulante': 0, 'chauvine': 0, 'possédée': 0, 'calabraise': 0, 'assombrissante': 0, 'ferroutière': 6, 'chanceuse': 9, 'plante': 0, 'dérangeuse': 2, 'presbytérale': 3, 'épithéliale': 3, 'préalpine': 0, 'illustratrice': 1, 'namuroise': 0, 'hideuse': 9, 'enfonceuse': 2, 'sismale': 3, 'sensationnelle': 4, 'coronarienne': 4, 'confabulatrice': 1, 'hermitienne': 4, 'vice-présidente': 0, 'surfine': 0, 'captivante': 0, 'débourgeoisée': 0, 'tensio-active': 7, 'brownienne': 4, 'adjudicatrice': 1, 'vésicante': 0, 'mélanésienne': 4, 'inexpérimentée': 0, 'résiduelle': 4, 'généreuse': 9, 'atemporelle': 4, 'criminelle': 4, 'extinctive': 7, 'sasseuse': 2, 'pastilleuse': 2, 'lombosacrée': 0, 'rinceuse': 2, 'spécificative': 7, 'vantarde': 0, 'visionneuse': 2, 'radicale': 3, 'baveuse': 9, 'superlégère': 6, 'ouateuse': 9, 'tombée': 0, 'chassieuse': 9, 'partiale': 3, 'lésineuse': 2, 'sous-maitresse': 16, 'osculatrice': 1, 'octale': 3, 'morfale': 0, 'daubeuse': 2, 'intracontinentale': 3, 'cupro-ammoniacale': 3, 'notionnelle': 4, 'productrice': 1, 'hydrominérale': 3, 'huronne': 4, 'bichonneuse': 2, 'imminente': 0, 'pontifiante': 0, 'contingente': 0, 'irréalisée': 0, 'astrophysicienne': 4, 'incongrue': 0, 'rubescente': 0, 'démerdarde': 0, 'membrue': 0, 'employeuse': 2, 'croupissante': 0, 'épagneule': 0, 'tokharienne': 4, 'exténuante': 0, 'panseuse': 2, 'défigurée': 0, 'froufrouteuse': 9, 'australe': 3, 'moyenâgeuse': 9, 'larvée': 0, 'appétitive': 7, 'cartusienne': 4, 'certificatrice': 1, 'snipeuse': 2, 'verdoyante': 0, 'labiale': 3, 'immunodéprimée': 0, 'géotechnicienne': 4, 'grammaticale': 3, 'acadienne': 4, 'intéressante': 0, 'exténuée': 0, 'tracassière': 6, 'vénusienne': 4, 'dégraissante': 0, 'démoralisatrice': 1, 'hastée': 0, 'rémittente': 0, 'énumérative': 7, 'intérieure': 0, 'municipale': 3, 'coprésente': 0, 'staffeuse': 2, 'virale': 3, 'indicatrice': 1, 'bonne': 4, 'surveillante': 0, 'clairette': 4, 'limonadière': 6, 'nancéienne': 4, 'responsoriale': 3, 'terrière': 6, 'enrhumée': 0, 'déflagrante': 0, 'adaptatrice': 1, 'hardeuse': 2, 'gouvernante': 0, 'unisexuelle': 4, 'retraitante': 0, 'globalisante': 0, 'imaginale': 3, 'éléphante': 0, 'troyenne': 4, 'loupiote': 0, 'éloquente': 0, 'émotteuse': 2, 'dotale': 3, 'passionnée': 0, 'uvale': 3, 'nominée': 0, 'interventionnelle': 4, 'perruquière': 6, 'intermodale': 3, 'fabricante': 0, 'infraliminale': 3, 'scabieuse': 9, 'injectrice': 1, 'cardiale': 3, 'armoriale': 3, 'américano-européenne': 4, 'supranationale': 3, 'provençale': 3, 'veuve': 7, 'retrayante': 0, 'saillante': 0, 'scabreuse': 9, 'dépeceuse': 2, 'primodélinquante': 0, 'bousilleuse': 2, 'euphorisante': 0, 'dodécagonale': 3, 'énervée': 0, 'précordiale': 3, 'valencienne': 4, 'prometteuse': 2, 'sacrificatrice': 1, 'indécente': 0, 'aéropostale': 3, 'blessée': 0, 'bruleuse': 2, 'cordonnière': 6, 'petite': 0, 'bédouine': 0, 'bufflesse': 16, 'inéprouvée': 0, 'crémée': 0, 'ellipsoïdale': 3, 'proximale': 3, 'meurtrissante': 0, 'exacte': 0, 'tamponneuse': 2, 'principale': 3, 'endettée': 0, 'tragédienne': 4, 'fraîche': 27, 'alezane': 0, 'situationnelle': 4, 'planquée': 0, 'consortiale': 3, 'saure': 0, 'cérémonielle': 4, 'alitée': 0, 'babylonienne': 4, 'crapuleuse': 9, 'traînarde': 0, 'montagnarde': 0, 'taularde': 0, 'chaudronnée': 0, 'soupeuse': 2, 'répressive': 7, 'classieuse': 9, 'multiculturelle': 4, 'méprisante': 0, 'fendante': 0, 'paroissiale': 3, 'billetée': 0, 'ventée': 0, 'parlante': 0, 'athénienne': 4, 'déléguée': 0, 'médico-légale': 3, 'désodorisante': 0, 'néo-conservatrice': 1, 'ostentatrice': 1, 'mentonnière': 6, 'astreignante': 0, 'renforçatrice': 1, 'indifférente': 0, 'associée': 0, 'plombière': 6, 'freinatrice': 1, 'lagrangienne': 4, 'fermentante': 0, 'débaucheuse': 2, 'astrale': 3, 'malintentionnée': 0, 'bégayeuse': 2, 'journalière': 6, 'extra-conjugale': 3, 'nécromante': 0, 'insoupçonnée': 0, 'insulino-dépendante': 0, 'supportrice': 1, 'renchérisseuse': 2, 'psychosociale': 3, 'consécutive': 7, 'zénithale': 3, 'corrodante': 0, 'câbleuse': 2, 'nigéro-congolaise': 0, 'immunostimulante': 0, 'réductive': 7, 'encadreuse': 2, 'invalidante': 0, 'théoricienne': 4, 'raffineuse': 2, 'inhabituelle': 4, 'indéhiscente': 0, 'organisatrice': 1, 'hautelissière': 6, 'dégoutante': 0, 'bipennée': 0, 'soufflée': 0, 'polyvalente': 0, 'spirante': 0, 'discursive': 7, 'multilobée': 0, 'traumatisée': 0, 'engagée': 0, 'mal-baisée': 0, 'sri-lankaise': 0, 'approbatrice': 1, 'scrupuleuse': 9, 'décolorante': 0, 'huppée': 0, 'obtuse': 0, 'stercorale': 3, 'tortueuse': 9, 'confondante': 0, 'infirmative': 7, 'frappeuse': 2, 'coulante': 0, 'spatulée': 0, 'agrammaticale': 3, 'post-doctorale': 3, 'transamazonienne': 4, 'radioactive': 7, 'goitreuse': 9, 'manquante': 0, 'expectative': 7, 'dijonnaise': 0, 'capitalisante': 0, 'smicarde': 0, 'skippeuse': 2, 'levée': 0, 'affectueuse': 9, 'taboue': 0, 'susdite': 0, 'crollée': 0, 'rhizomateuse': 9, 'superviseuse': 2, 'antiministérielle': 4, 'exceptionnelle': 4, 'transfrontalière': 6, 'voyante': 0, 'trapue': 0, 'musculeuse': 9, 'profileuse': 2, 'équatorienne': 4, 'flottante': 0, 'fonctionnelle': 4, 'non-euclidienne': 4, 'micacée': 0, 'caverneuse': 9, 'bruyante': 0, 'prostrée': 0, 'fumante': 0, 'doucheuse': 2, 'dépensière': 6, 'phocéenne': 4, 'footballeuse': 2, 'extraprofessionnelle': 4, 'néoromane': 0, 'collégienne': 4, 'ravaudeuse': 2, 'cutanée': 0, 'connecticienne': 4, 'moucharde': 0, 'pavimenteuse': 9, 'timbrée': 0, 'suboptimale': 3, 'composeuse': 2, 'transcendantale': 3, 'quilleuse': 2, 'équipementière': 6, 'glandeuse': 2, 'torrentueuse': 9, 'ourlienne': 4, 'vertébrale': 3, 'cooccupante': 0, 'néorurale': 3, 'sémillante': 0, 'râleuse': 2, 'électrisante': 0, 'squirrheuse': 9, 'admise': 0, 'guerroyeuse': 2, 'maïsicultrice': 1, 'messine': 0, 'nerveuse': 9, 'liante': 0, 'vasodilatatrice': 1, 'grosse': 4, 'ferrugineuse': 9, 'neuroendocrinienne': 4, 'nettoyante': 0, 'auto-référentielle': 4, 'érythréenne': 4, 'affleurante': 0, 'bicamérale': 3, 'ambroisienne': 4, 'télévendeuse': 2, 'revitalisante': 0, 'tourbière': 6, 'autodestructrice': 1, 'romanichelle': 4, 'mauricienne': 4, 'droguée': 0, 'prussienne': 4, 'arboricultrice': 1, 'préjudicielle': 4, 'inapprivoisée': 0, 'définitive': 7, 'ergotée': 0, 'pansue': 0, 'kanake': 0, 'ourdoue': 0, 'plaignante': 0, 'mahométane': 0, 'théologale': 3, 'vermineuse': 9, 'fastueuse': 9, 'importante': 0, 'amie': 0, 'conductrice': 1, 'malfamée': 0, 'centésimale': 3, 'psychosensorielle': 4, 'obscure': 0, 'vitrificative': 7, 'destructive': 7, 'agrégée': 0, 'rabouilleuse': 2, 'massacrante': 0, 'grillette': 4, 'négociatrice': 1, 'autosuffisante': 0, 'chronométreuse': 2, 'inégalée': 0, 'stayeuse': 2, 'lamelleuse': 9, 'inverseuse': 2, 'crétacée': 0, 'coréalisatrice': 1, 'éminente': 0, 'mammalienne': 4, 'envoutée': 0, 'circonstancielle': 4, 'contre-maîtresse': 16, 'facultative': 7, 'chialeuse': 2, 'coulombienne': 4, 'lionne': 4, 'furonculeuse': 9, 'disjonctive': 7, 'mutilatrice': 1, 'concomitante': 0, 'modératrice': 1, 'défectueuse': 9, 'dissuasive': 7, 'sniffeuse': 2, 'galopeuse': 2, 'gabonaise': 0, 'malaisienne': 4, 'super-légère': 6, 'enchainée': 0, 'importune': 0, 'occlusale': 3, 'libidinale': 3, 'condruzienne': 4, 'justificative': 7, 'dupeuse': 2, 'opérée': 0, 'corporative': 7, 'stimulante': 0, 'inoffensive': 7, 'bégüe': 12, 'caucasienne': 4, 'blafarde': 0, 'versificatrice': 1, 'hypotensive': 7, 'diffuseuse': 2, 'zaïroise': 0, 'parodontale': 3, 'démystificatrice': 1, 'sourcilière': 6, 'puînée': 0, 'sous-préfète': 25, 'haussière': 6, 'génitale': 3, 'superficielle': 4, 'essoreuse': 2, 'régulatrice': 1, 'potinière': 6, 'précancéreuse': 9, 'coadaptatrice': 1, 'végétative': 7, 'vendeuse': 2, 'capée': 0, 'houblonnière': 6, 'rouette': 4, 'gageuse': 2, 'incultivée': 0, 'effrayante': 0, 'subsaharienne': 4, 'précautionneuse': 9, 'pédieuse': 9, 'érubescente': 0, 'inaccoutumée': 0, 'ouest-allemande': 0, 'exploitée': 0, 'païenne': 4, 'fatigante': 0, 'agro-environnementale': 3, 'illustrative': 7, 'pyroxylée': 0, 'excavatrice': 1, 'centralisatrice': 1, 'agitée': 0, 'bivitelline': 0, 'kalmouke': 0, 'rétroéclairée': 0, 'média-planneuse': 2, 'lingère': 6, 'absorptive': 7, 'manufacturière': 6, 'boursière': 6, 'oppressante': 0, 'anti-aérienne': 4, 'pesteuse': 9, 'zappeuse': 2, 'normalisatrice': 1, 'révélatrice': 1, 'rwandaise': 0, 'batracienne': 4, 'tutorielle': 4, 'shampouineuse': 2, 'diadémée': 0, 'aptienne': 4, 'incandescente': 0, 'bronzante': 0, 'électroacousticienne': 4, 'paroissienne': 4, 'mytilicultrice': 1, 'dirimante': 0, 'concédante': 0, 'hospitalière': 6, 'fransquillonne': 4, 'gisante': 0, 'consanguine': 0, 'environnante': 0, 'fibromateuse': 9, 'locative': 7, 'botoxée': 0, 'ascensionnelle': 4, 'flétrissante': 0, 'angolaise': 0, 'ci-jointe': 0, 'rappelée': 0, 'défiante': 0, 'rarescente': 0, 'franchisée': 0, 'frangeante': 0, 'dialectale': 3, 'ritale': 0, 'récurrente': 0, 'concrescente': 0, 'crieuse': 2, 'mobilisatrice': 1, 'téléconduite': 0, 'inactive': 7, 'saurisseuse': 2, 'conceptuelle': 4, 'dépoussiérante': 0, 'nomenclatrice': 1, 'goudronneuse': 9, 'anthraciteuse': 9, 'puante': 0, 'révulsive': 7, 'machinale': 3, 'géopotentielle': 4, 'acrimonieuse': 9, 'goulue': 0, 'avantagée': 0, 'serpentine': 0, 'archaïsante': 0, 'subséquente': 0, 'finnoise': 0, 'déplaisante': 0, 'sous-calibrée': 0, 'hexadécimale': 3, 'lasse': 4, 'prétoriale': 3, 'pétrée': 0, 'gangreneuse': 9, 'gentille': 4, 'inconsidérée': 0, 'brutale': 3, 'estimative': 7, 'moyée': 0, 'résolvante': 0, 'substantielle': 4, 'traditionnelle': 4, 'lamineuse': 2, 'zende': 0, 'pertinente': 0, 'pèlerine': 0, 'éperdue': 0, 'mélaminée': 0, 'fouinarde': 0, 'céréalière': 6, 'outragée': 0, 'traqueuse': 2, 'cosméticienne': 4, 'axonaise': 0, 'inappropriée': 0, 'frottante': 0, 'truande': 0, 'monoclonale': 3, 'uxorilocale': 3, 'nasale': 3, 'médiévale': 3, 'piétonne': 4, 'apéritive': 7, 'diamétrale': 3, 'avalancheuse': 9, 'merdeuse': 9, 'ignifugeante': 0, 'lépreuse': 9, 'prochaine': 0, 'phylloxérienne': 4, 'contrite': 0, 'mielleuse': 9, 'carburière': 6, 'irradiante': 0, 'bluette': 4, 'inépuisée': 0, 'dodelinante': 0, 'vineuse': 9, 'sous-vireuse': 2, 'dégradante': 0, 'choupinette': 4, 'soufreuse': 2, 'seconde': 0, 'cervicale': 3, 'pluripotente': 0, 'revigorante': 0, 'berlinoise': 0, 'papillotante': 0, 'privilégiée': 0, 'nippone': 0, 'zwanzeuse': 2, 'craquante': 0, 'malawienne': 4, 'surfondue': 0, 'toxiinfectieuse': 9, 'antimorale': 3, 'rouquine': 0, 'fédérale': 3, 'huîtrière': 6, 'carbonée': 0, 'croupie': 0, 'fontainière': 6, 'cisailleuse': 2, 'déchaumeuse': 2, 'saint-simonienne': 4, 'palpitante': 0, 'rééducatrice': 1, 'postérieure': 0, 'découvreuse': 2, 'retourneuse': 2, 'vicariante': 0, 'coadministratrice': 1, 'prête': 0, 'armoricaine': 0, 'haute': 0, 'fleuronnée': 0, 'sorteuse': 2, 'anguleuse': 9, 'littorale': 3, 'brunisseuse': 2, 'rappée': 0, 'donneuse': 2, 'marmoréenne': 4, 'hurleuse': 2, 'barbante': 0, 'finasseuse': 2, 'gambadante': 0, 'pilosébacée': 0, 'mobilière': 6, 'furette': 4, 'hyperémotive': 7, 'affineuse': 2, 'écocitoyenne': 4, 'croupière': 6, 'papetière': 6, 'rivale': 3, 'surbookée': 0, 'flosculeuse': 9, 'métricienne': 4, 'vitrioleuse': 2, 'exportatrice': 1, 'semeuse': 2, 'régalienne': 4, 'minimisante': 0, 'bénissante': 0, 'fripière': 6, 'piétonnière': 6, 'affuteuse': 2, 'parachutée': 0, 'dérégulatrice': 1, 'structurante': 0, 'rockeuse': 2, 'surhumaine': 0, 'alevinière': 6, 'perpétuelle': 4, 'gravettienne': 4, 'hachischée': 0, 'stomisée': 0, 'denteleuse': 2, 'désinsectiseuse': 2, 'stoppeuse': 2, 'soussignée': 0, 'multilatérale': 3, 'ergative': 7, 'pénicillée': 0, 'sélecte': 0, 'dorienne': 4, 'muscardine': 0, 'suppliante': 0, 'duale': 3, 'botteleuse': 2, 'appalachienne': 4, 'cristalline': 0, 'clinicienne': 4, 'futée': 0, 'renversante': 0, 'artinienne': 4, 'convoquée': 0, 'liégeuse': 9, 'heptagonale': 3, 'récidivante': 0, 'planificatrice': 1, 'ligneuse': 9, 'subaérienne': 4, 'verglaçante': 0, 'apaisante': 0, 'pliante': 0, 'crêpelée': 0, 'odieuse': 9, 'suffisante': 0, 'sucrante': 0, 'vultueuse': 9, 'parastatale': 3, 'inaboutie': 0, 'israélo-palestinienne': 4, 'ethnoculturelle': 4, 'oulipienne': 4, 'érectrice': 1, 'crucifiante': 0, 'agropastorale': 3, 'anti-sous-marine': 0, 'éprouvante': 0, 'tartreuse': 9, 'esclavonne': 4, 'fourvoyante': 0, 'turbocompressée': 0, 'ineffective': 7, 'ostrogothe': 0, 'septale': 3, 'peule': 0, 'japonaise': 0, 'fortifiante': 0, 'écossaise': 0, 'bruiteuse': 2, 'orbitale': 3, 'cacaoyère': 6, 'affranchisseuse': 2, 'neurochirurgicale': 3, 'balisticienne': 4, 'sanctionnée': 0, 'bretessée': 0, 'confusionnelle': 4, 'dodue': 0, 'impulsionnelle': 4, 'adulatrice': 1, 'interconfessionnelle': 4, 'arrangeante': 0, 'trayeuse': 2, 'triumvirale': 3, 'priseuse': 2, 'détectrice': 1, 'amère': 6, 'mocharde': 0, 'façadière': 6, 'snobinarde': 0, 'amnistiée': 0, 'bocagère': 6, 'officière': 6, 'afférente': 0, 'rhénane': 0, 'soupière': 6, 'intracrânienne': 4, 'clignotante': 0, 'albigeoise': 0, 'épinglière': 6, 'gliale': 3, 'surprenante': 0, 'distractive': 7, 'éolienne': 4, 'civile': 0, 'intervenante': 0, 'balafrée': 0, 'solennelle': 4, 'censière': 6, 'immunocompétente': 0, 'préférentielle': 4, 'italianisante': 0, 'brulée': 0, 'prudente': 0, 'coauteure': 0, 'idéalisatrice': 1, 'audiovisuelle': 4, 'détacheuse': 2, 'israélienne': 4, 'zonarde': 0, 'insolente': 0, 'suédoise': 0, 'décérébrante': 0, 'méplate': 0, 'pédante': 0, 'plurivalente': 0, 'immédiate': 0, 'binomiale': 3, 'dodécaphasée': 0, 'loculeuse': 9, 'quincaillière': 6, 'défaillante': 0, 'dribbleuse': 2, 'hernieuse': 9, 'putative': 7, 'baratineuse': 2, 'disséqueuse': 2, 'bichromatée': 0, 'gêneuse': 2, 'tubulée': 0, 'sémanticienne': 4, 'récitante': 0, 'dialecticienne': 4, 'intraartérielle': 4, 'séduisante': 0, 'kidnappeuse': 2, 'méliorative': 7, 'douloureuse': 9, 'pubescente': 0, 'maquilleuse': 2, 'agroenvironnementale': 3, 'rapeuse': 2, 'non-combattante': 0, 'sous-traitante': 0, 'gerbeuse': 2, 'suicidée': 0, 'cuisinière': 6, 'vaccinée': 0, 'auvergnate': 0, 'tatare': 0, 'interpelée': 0, 'adoptante': 0, 'tripatouilleuse': 2, 'époustouflante': 0, 'autocentrée': 0, 'géospatiale': 3, 'québécoise': 0, 'antiamarile': 0, 'tubéreuse': 9, 'flagellante': 0, 'guyanaise': 0, 'maricultrice': 1, 'poissonneuse': 9, 'casquante': 0, 'payeuse': 2, 'éparse': 0, 'éventuelle': 4, 'néo-calédonienne': 4, 'irienne': 4, 'bustière': 6, 'puritaine': 0, 'hiatale': 3, 'épuisante': 0, 'légumière': 6, 'démarcative': 7, 'rafraichissante': 0, 'définitionnelle': 4, 'arlésienne': 4, 'chondrocostale': 3, 'veineuse': 9, 'jacassière': 6, 'humorale': 3, 'exaspérée': 0, 'dribleuse': 2, 'inharmonieuse': 9, 'conceptrice': 1, 'désinfectrice': 1, 'commerciale': 3, 'sous-directrice': 1, 'délurée': 0, 'récriminatrice': 1, 'quadrisaïeule': 0, 'enculée': 0, 'goguenarde': 0, 'ramoneuse': 2, 'plurinominale': 3, 'homofocale': 3, 'argilosiliceuse': 9, 'lutteuse': 2, 'sous-pubienne': 4, 'spinale': 3, 'pinéale': 3, 'alcyonienne': 4, 'acoquinante': 0, 'pénitentiale': 3, 'glucosée': 0, 'moraliseuse': 2, 'rempailleuse': 2, 'inguinale': 3, 'murine': 0, 'canoniale': 3, 'cartésienne': 4, 'palefrenière': 6, 'mollassonne': 4, 'benoite': 0, 'antigouvernementale': 3, 'primale': 3, 'abêtifiée': 0, 'sémioticienne': 4, 'nîmoise': 0, 'immunisante': 0, 'fileuse': 2, 'extérieure': 0, 'grimacière': 6, 'quarteronne': 4, 'lignarde': 0, 'chainière': 6, 'fermentée': 0, 'civette': 4, 'recasquante': 0, 'raquettière': 6, 'ostrogote': 0, 'brancardière': 6, 'aïeule': 0, 'fouineuse': 2, 'inobservée': 0, 'trochléenne': 4, 'décagonale': 3, 'braseuse': 2, 'bodybuildée': 0, 'candidate': 0, 'vert-de-grisée': 0, 'foulante': 0, 'fléchissante': 0, 'gribouilleuse': 2, 'pourchassée': 0, 'efféminée': 0, 'flingueuse': 2, 'assurée': 0, 'pipière': 6, 'méridienne': 4, 'hautaine': 0, 'inimitée': 0, 'soucieuse': 9, 'subalpine': 0, 'antinazie': 0, 'rubanière': 6, 'dispendieuse': 9, 'auteure': 0, 'fermante': 0, 'égorgeuse': 2, 'prospective': 7, 'égrotante': 0, 'protectrice': 1, 'argilacée': 0, 'parqueteuse': 2, 'attentionnée': 0, 'parfumeuse': 2, 'haillonneuse': 9, 'butineuse': 2, 'finno-ougrienne': 4, 'cribleuse': 2, 'extrovertie': 0, 'professante': 0, 'palissonneuse': 2, 'barreuse': 2, 'estivale': 3, 'quadrivalente': 0, 'intercotidale': 3, 'affolante': 0, 'philosophale': 0, 'dépendante': 0, 'dernière': 6, 'costaricienne': 4, 'exemplative': 7, 'faustienne': 4, 'tondue': 0, 'opulente': 0, 'vicieuse': 9, 'initiatrice': 1, 'embaumeuse': 2, 'argentine': 0, 'badaude': 0, 'swahilie': 0, 'oxycoupeuse': 2, 'rancuneuse': 9, 'copulative': 7, 'rassembleuse': 2, 'indéchiffrée': 0, 'sahélienne': 4, 'évangélisatrice': 1, 'trembleuse': 2, 'adjuvante': 0, 'historisante': 0, 'restante': 0, 'concordante': 0, 'multivariée': 0, 'feutrante': 0, 'postdoctorale': 3, 'anabolisante': 0, 'rubéfiante': 0, 'uligineuse': 9, 'douée': 0, 'outrageante': 0, 'coutante': 0, 'céphalée': 0, 'faubourienne': 4, 'ovoïdale': 3, 'alumineuse': 9, 'inexprimée': 0, 'uruguayenne': 4, 'embue': 0, 'opératrice': 1, 'pluvio-nivale': 3, 'finisseuse': 2, 'féodale': 3, 'nivernaise': 0, 'endormante': 0, 'idiote': 0, 'gazière': 6, 'numérale': 3, 'ovée': 0, 'bêtifiante': 0, 'mathématicienne': 4, 'laide': 0, 'inexercée': 0, 'bêcheuse': 2, 'judéo-chrétienne': 4, 'reproductrice': 1, 'illuminée': 0, 'envieuse': 9, 'emboutisseuse': 2, 'andine': 0, 'coordonnatrice': 1, 'amodiatrice': 1, 'encourageante': 0, 'péruvienne': 4, 'cristallophyllienne': 4, 'gutturale': 3, 'cégésimale': 3, 'approvisionneuse': 2, 'hexagonale': 3, 'manageuse': 2, 'partouzeuse': 2, 'levronne': 4, 'déserteuse': 2, 'alourdissante': 0, 'sinapisée': 0, 'matineuse': 9, 'velouteuse': 9, 'locorégionale': 3, 'incoordonnée': 0, 'nauséeuse': 9, 'inassouvie': 0, 'insurrectionnelle': 4, 'fractale': 0, 'nutritive': 7, 'dipneumonée': 0, 'probante': 0, 'autocaravanière': 6, 'acheteuse': 2, 'imparfaite': 0, 'désapprobatrice': 1, 'enfourneuse': 2, 'germanopratine': 0, 'moutonneuse': 9, 'dalembertienne': 4, 'électorale': 3, 'berneuse': 2, 'organomagnésienne': 4, 'taiseuse': 9, 'butanée': 0, 'inespérée': 0, 'tiquetée': 0, 'excellente': 0, 'panière': 6, 'îlienne': 4, 'pateline': 0, 'ringarde': 0, 'complaisante': 0, 'sourde': 0, 'hongroyeuse': 2, 'franco-néerlandaise': 0, 'post-natale': 0, 'sénatoriale': 3, 'encadrante': 0, 'projectivisée': 0, 'coticée': 0, 'carmélitaine': 0, 'rectifieuse': 2, 'trafiqueuse': 2, 'pénienne': 4, 'louchonne': 4, 'non-alignée': 0, 'immanente': 0, 'tallée': 0, 'angoisseuse': 9, 'raciale': 3, 'pensive': 7, 'électricienne': 4, 'imbrûlée': 0, 'grandiloquente': 0, 'néonazie': 0, 'hurdleuse': 2, 'consubstantielle': 4, 'pyrograveuse': 2, 'photocompositrice': 1, 'payse': 0, 'dormitive': 7, 'flacheuse': 9, 'chapardeuse': 2, 'rétrosternale': 3, 'pétante': 0, 'coulissante': 0, 'wisigothe': 0, 'utérine': 0, 'évasive': 7, 'volailleuse': 2, 'bismuthée': 0, 'concessive': 7, 'sous-intendante': 0, 'connective': 7, 'anthropisée': 0, 'volitionnelle': 4, 'suturale': 3, 'vaticinatrice': 1, 'ultraplate': 0, 'thessalonicienne': 4, 'pectinée': 0, 'optative': 7, 'pocharde': 0, 'gibeline': 0, 'jouissive': 7, 'antivirale': 3, 'populacière': 6, 'transculturelle': 4, 'sportive': 7, 'tanzanienne': 4, 'unipotente': 0, 'franco-finlandaise': 0, 'bijoutière': 6, 'bien-aimée': 0, 'médicale': 3, 'nycthémérale': 3, 'manadière': 6, 'laminale': 3, 'scandalisée': 0, 'bondieusarde': 0, 'araméenne': 4, 'bilabiée': 0, 'brasseuse': 2, 'koweïtienne': 4, 'strombolienne': 4, 'terrifiante': 0, 'vivante': 0, 'élégante': 0, 'traductionnelle': 4, 'rançonneuse': 2, 'écotée': 0, 'bâcleuse': 2, 'corticosurrénale': 3, 'perspective': 7, 'retoucheuse': 2, 'sonnante': 0, 'purgative': 7, 'déchiqueteuse': 2, 'cloisonnante': 0, 'huilière': 6, 'implanteuse': 2, 'vérolée': 0, 'anorectale': 3, 'salinière': 6, 'aveuglante': 0, 'débrouillarde': 0, 'gravillonneuse': 2, 'précitée': 0, 'manchote': 0, 'hindie': 0, 'cristallière': 6, 'fusilière': 6, 'calédonienne': 4, 'nette': 4, 'saônoise': 0, 'déviatrice': 1, 'tanneuse': 2, 'givreuse': 9, 'périœsophagienne': 4, 'annonciatrice': 1, 'auto-évaluante': 0, 'impuissante': 0, 'catarrheuse': 9, 'marneuse': 9, 'prémenstruelle': 4, 'languée': 0, 'paonne': 4, 'enjôleuse': 2, 'transfinie': 0, 'pentagonale': 3, 'structurelle': 4, 'intruse': 0, 'maraichine': 0, 'dateuse': 2, 'perverse': 0, 'ligueuse': 2, 'canotière': 6, 'caillouteuse': 9, 'délibérante': 0, 'scripturale': 3, 'animalière': 6, 'exciseuse': 2, 'condylienne': 4, 'contractante': 0, 'allumeuse': 2, 'inusitée': 0, 'donatrice': 1, 'dynamiteuse': 2, 'cohéritière': 6, 'fructicultrice': 1, 'sécheuse': 2, 'codébitrice': 1, 'zazoue': 0, 'infondée': 0, 'frontale': 3, 'sud-vietnamienne': 4, 'pantouflière': 6, 'puinée': 0, 'épidurale': 3, 'patrouilleuse': 2, 'caissière': 6, 'soulante': 0, 'courante': 0, 'automaticienne': 4, 'invendue': 0, 'microlocale': 3, 'restrictive': 7, 'ultraviolette': 4, 'narbonnaise': 0, 'savoyarde': 0, 'parisienne': 4, 'moutardière': 6, 'bancheuse': 2, 'mordue': 0, 'uniovulée': 0, 'déformatrice': 1, 'utilisatrice': 1, 'cymbalière': 6, 'sternale': 3, 'unguéale': 3, 'contrastive': 7, 'récoltante': 0, 'garnisseuse': 2, 'malfaisante': 0, 'résultante': 0, 'coupeuse': 2, 'cancanière': 6, 'coronale': 3, 'vigésimale': 3, 'cracovienne': 4, 'mendigote': 0, 'saturante': 0, 'diocésaine': 0, 'axiale': 3, 'calculatrice': 1, 'corporelle': 4, 'gastroœsophagienne': 4, 'stalinienne': 4, 'cybersquatteuse': 2, 'oppositionnelle': 4, 'présentielle': 4, 'improbative': 7, 'photoréceptrice': 1, 'envahisseuse': 2, 'éburonne': 4, 'prélatine': 0, 'native': 7, 'sylvicultrice': 1, 'salésienne': 4, 'garçonnière': 6, 'grisonne': 4, 'assourdissante': 0, 'lieuse': 2, 'chapée': 0, 'paraxiale': 3, 'justifiante': 0, 'asservissante': 0, 'fréquentative': 7, 'résonnante': 0, 'relectrice': 1, 'tradeuse': 2, 'phrygienne': 4, 'proprioceptive': 7, 'gérante': 0, 'loseuse': 2, 'avoisinante': 0, 'chaudronnière': 6, 'balbutiante': 0, 'gravitante': 0, 'réformatrice': 1, 'préfectorale': 3, 'bonzesse': 16, 'galante': 0, 'causale': 3, 'concitoyenne': 4, 'prédatée': 0, 'mitrée': 0, 'vasouillarde': 0, 'tamile': 0, 'indonésienne': 4, 'essentielle': 4, 'plumetée': 0, 'banqueroutière': 6, 'agitatrice': 1, 'inhalatrice': 1, 'colloïdale': 3, 'essonnienne': 4, 'appétissante': 0, 'betteravière': 6, 'ressemblante': 0, 'coparticipante': 0, 'anglo-japonaise': 0, 'préformatée': 0, 'tentante': 0, 'proclamatrice': 1, 'cantonale': 3, 'compassionnelle': 4, 'concernée': 0, 'fluorescente': 0, 'ultra-plate': 0, 'massicotière': 6, 'hertzienne': 4, 'postulante': 0, 'quiète': 25, 'intouchée': 0, 'pareille': 4, 'renonciatrice': 1, 'franco-afghane': 0, 'antédiluvienne': 4, 'pulsante': 0, 'phalangienne': 4, 'criante': 0, 'namibienne': 4, 'veilleuse': 2, 'neigeuse': 9, 'quiescente': 0, 'examinatrice': 1, 'ingrate': 0, 'diseuse': 2, 'relictuelle': 4, 'secoureuse': 2, 'monodirectionnelle': 4, 'charronne': 4, 'boutante': 0, 'noblaillonne': 4, 'galloise': 0, 'oreillarde': 0, 'usagée': 0, 'allumettière': 6, 'assistante': 0, 'diplômée': 0, 'audoise': 0, 'enregistreuse': 2, 'lissante': 0, 'placeuse': 2, 'asinienne': 4, 'drômoise': 0, 'inhabitée': 0, 'calmante': 0, 'boulote': 0, 'enthousiasmante': 0, 'temporale': 3, 'prévisionnelle': 4, 'égreneuse': 2, 'vergetière': 6, 'chalande': 0, 'siliceuse': 9, 'malletière': 6, 'truitée': 0, 'conformationnelle': 4, 'gémissante': 0, 'bissexuée': 0, 'trottinante': 0, 'babysitteuse': 2, 'recombinante': 0, 'dispose': 0, 'confirmande': 0, 'circulante': 0, 'léonine': 0, 'émissive': 7, 'abréviative': 7, 'grandette': 4, 'tailleuse': 2, 'innée': 0, 'fumerolienne': 4, 'grognarde': 0, 'niaiseuse': 9, 'focale': 3, 'lourdaude': 0, 'plurilatérale': 3, 'vétillarde': 0, 'ablative': 7, 'ludoéducative': 7, 'milanaise': 0, 'paralysée': 0, 'revenante': 0, 'pro-active': 7, 'bismarckienne': 4, 'rancunière': 6, 'présidiale': 3, 'marquante': 0, 'cumulatrice': 1, 'empalée': 0, 'tympanale': 3, 'tapineuse': 2, 'entrainante': 0, 'herbue': 0, 'maltaise': 0, 'familière': 6, 'sabine': 0, 'cofondatrice': 1, 'justicière': 6, 'fériée': 0, 'antibrouillée': 0, 'cabotine': 0, 'extensive': 7, 'coxofémorale': 3, 'licière': 6, 'prescriptive': 7, 'dominicaine': 0, 'parfaite': 0, 'théâtreuse': 9, 'avilissante': 0, 'luronne': 4, 'baptiseuse': 2, 'ultramontaine': 0, 'travailleuse': 2, 'corinthienne': 4, 'coépouse': 9, 'teufeuse': 2, 'surrénale': 3, 'ampliative': 7, 'mécheuse': 9, 'naufrageuse': 2, 'gélifiante': 0, 'bluffante': 0, 'faiblissante': 0, 'répugnante': 0, 'adragante': 0, 'hispano-américaine': 0, 'manœuvrière': 6, 'addictive': 7, 'impétigineuse': 9, 'eurafricaine': 0, 'germaine': 0, 'grenue': 0, 'buvetière': 6, 'bancale': 0, 'spontanée': 0, 'providentielle': 4, 'tropho-microbienne': 4, 'blanche': 4, 'libéro-ligneuse': 9, 'maffieuse': 9, 'acidifiante': 0, 'nipponne': 4, 'interlocutrice': 1, 'halitueuse': 9, 'interpariétale': 3, 'rocheuse': 9, 'mémorielle': 4, 'grippale': 3, 'basse': 4, 'tarotée': 0, 'antinaturelle': 4, 'touranienne': 4, 'protéinée': 0, 'gagneuse': 2, 'prématurée': 0, 'dévote': 0, 'aligneuse': 2, 'souriante': 0, 'testacée': 0, 'noyauteuse': 2, 'autoentrepreneuse': 2, 'bretteuse': 2, 'vomérienne': 4, 'converse': 0, 'collante': 0, 'lobotomisante': 0, 'hiémale': 3, 'renégate': 0, 'inexpiée': 0, 'millerandée': 0, 'lamifiée': 0, 'achéenne': 4, 'bambocheuse': 2, 'thermodynamicienne': 4, 'calorifugeuse': 2, 'würmienne': 4, 'argilo-siliceuse': 9, 'hyoïdienne': 4, 'additionneuse': 2, 'prestigieuse': 9, 'cistercienne': 4, 'libertarienne': 4, 'fastidieuse': 9, 'vigoureuse': 9, 'feinteuse': 2, 'franco-allemande': 0, 'tuberculeuse': 9, 'codétenue': 0, 'bâtonnière': 6, 'maroquinière': 6, 'rugissante': 0, 'multinationale': 3, 'coalescente': 0, 'gesticulante': 0, 'grévicultrice': 1, 'onctueuse': 9, 'commutatrice': 1, 'équilibrante': 0, 'bien-voulue': 0, 'sensorimotrice': 1, 'hennissante': 0, 'orgueilleuse': 9, 'acineuse': 9, 'iranienne': 4, 'vitaminée': 0, 'homogénéisatrice': 1, 'arminienne': 4, 'plaidante': 0, 'surannée': 0, 'inductive': 7, 'quadridimensionnelle': 4, 'oscillo-battante': 0, 'cortico-spinale': 3, 'extrarénale': 3, 'gloussante': 0, 'posturale': 3, 'saliveuse': 9, 'résonatrice': 1, 'famennoise': 0, 'lozérienne': 4, 'balzane': 0, 'bronchodilatatrice': 1, 'marginale': 3, 'descriptive': 7, 'débourreuse': 2, 'émotionnante': 0, 'tripartie': 0, 'paqueteuse': 2, 'pendarde': 0, 'oscillobattante': 0, 'rhumatismale': 3, 'future': 0, 'achemineuse': 2, 'gauchisante': 0, 'soudanaise': 0, 'délicieuse': 9, 'spitante': 0, 'frauduleuse': 9, 'équisingulière': 6, 'déstabilisante': 0, 'défonceuse': 2, 'sanguine': 0, 'franco-luxembourgeoise': 0, 'flamande': 0, 'spéciale': 3, 'artésienne': 4, 'germinatrice': 1, 'gardienne': 4, 'traquée': 0, 'comportementale': 3, 'déguenillée': 0, 'internée': 0, 'coloniale': 3, 'cérémonieuse': 9, 'nutritionnelle': 4, 'sino-japonaise': 0, 'castrale': 3, 'bricoleuse': 2, 'gâcheuse': 2, 'entérorénale': 3, 'malvenue': 0, 'stressante': 0, 'manipulatrice': 1, 'interviewée': 0, 'vulcanienne': 4, 'violeuse': 2, 'trilobée': 0, 'bichonne': 4, 'gréseuse': 9, 'fournisseuse': 2, 'radio-amatrice': 1, 'embarrassante': 0, 'frumentacée': 0, 'joyeuse': 9, 'peigneuse': 2, 'ronchonne': 4, 'plâtreuse': 9, 'batifolante': 0, 'licencieuse': 9, 'reconquérante': 0, 'compétitive': 7, 'syrienne': 4, 'dénaturante': 0, 'agencière': 6, 'phlegmoneuse': 9, 'cuissarde': 0, 'fabricatrice': 1, 'esquichée': 0, 'thermorégulatrice': 1, 'tordue': 0, 'furibarde': 0, 'chargée': 0, 'couarde': 0, 'discoïdale': 3, 'polluante': 0, 'épileuse': 2, 'potière': 6, 'albuminée': 0, 'papillonneuse': 2, 'cévenole': 0, 'lamarckienne': 4, 'cursive': 7, 'crapoteuse': 9, 'méniscale': 3, 'bourdonneuse': 2, 'opérative': 7, 'subtropicale': 3, 'archétypale': 3, 'gesticulée': 0, 'leveuse': 2, 'sauveuse': 2, 'stibiée': 0, 'planeuse': 2, 'vocationnelle': 4, 'bitumeuse': 9, 'informelle': 4, 'barbouilleuse': 2, 'inconséquente': 0, 'limousine': 0, 'blagueuse': 2, 'maousse': 4, 'nuncupative': 7, 'excitante': 0, 'lassante': 0, 'maghrébine': 0, 'lexicale': 3, 'plombante': 0, 'suppurante': 0, 'complète': 25, 'codeuse': 2, 'crépue': 0, 'défileuse': 2, 'sartrienne': 4, 'dérangeante': 0, 'franco-turque': 13, 'contextuelle': 4, 'auto-excitatrice': 1, 'heideggerienne': 4, 'insulinodépendante': 0, 'socioaffective': 7, 'velue': 0, 'chuchotante': 0, 'pasteurisatrice': 1, 'tarsienne': 4, 'correspondante': 0, 'balzacienne': 4, 'irritative': 7, 'burundaise': 0, 'hypersensitive': 7, 'hachichée': 0, 'décimale': 3, 'féminine': 0, 'estropiée': 0, 'durative': 7, 'confidentielle': 4, 'mobilisante': 0, 'persécutrice': 1, 'incontinente': 0, 'haleuse': 2, 'psychométricienne': 4, 'capitularde': 0, 'observationnelle': 4, 'extralégale': 3, 'levantine': 0, 'superordonnée': 0, 'internationale': 3, 'repentie': 0, 'empêcheuse': 2, 'gluante': 0, 'mordeuse': 2, 'jungienne': 4, 'brune': 0, 'tensioactive': 7, 'opticienne': 4, 'préhistorienne': 4, 'dravidienne': 4, 'désuète': 25, 'tamoule': 0, 'jurassienne': 4, 'judaïsante': 0, 'thanatopractrice': 1, 'arachnéenne': 4, 'bombante': 0, 'barbue': 0, 'obsolescente': 0, 'initiée': 0, 'défourneuse': 2, 'mitrale': 3, 'rotative': 7, 'obstinée': 0, 'incirconcise': 0, 'autoréférentielle': 4, 'vendue': 0, 'senestrée': 0, 'envoûtante': 0, 'sororale': 3, 'ahurie': 0, 'crasseuse': 9, 'nivopluviale': 3, 'banale': 3, 'rétentrice': 1, 'inopérante': 0, 'lupercale': 3, 'adipeuse': 9, 'néoplatonicienne': 4, 'acupunctrice': 1, 'sereine': 0, 'gallinacée': 0, 'rurale': 3, 'confédératrice': 1, 'étrangère': 6, 'nippo-américaine': 0, 'infamante': 0, 'tropicale': 3, 'bidimensionnelle': 4, 'épilogueuse': 2, 'tardillonne': 4, 'héliomarine': 0, 'habituelle': 4, 'caudale': 3, 'mateuse': 2, 'impertinente': 0, 'télémétreuse': 2, 'panetière': 6, 'compulsive': 7, 'télémécanicienne': 4, 'non-directive': 7, 'nattière': 6, 'apparente': 0, 'démolisseuse': 2, 'coassante': 0, 'lotisseuse': 2, 'élective': 7, 'diffamante': 0, 'ammoniacale': 3, 'fériale': 3, 'sibilante': 0, 'rageuse': 2, 'bernardine': 0, 'expédiente': 0, 'frétillante': 0, 'irrésolue': 0, 'prorogative': 7, 'bufflonne': 4, 'réitérative': 7, 'médulleuse': 9, 'télédéclarante': 0, 'oscillo-coulissante': 0, 'contemplative': 7, 'amphibienne': 4, 'rosissante': 0, 'bruineuse': 9, 'plastifiante': 0, 'doctrinale': 3, 'amicale': 3, 'javeleuse': 2, 'tressaillante': 0, 'aoûtienne': 4, 'fiancée': 0, 'tellureuse': 9, 'franco-uruguayenne': 4, 'traversière': 6, 'subjuguante': 0, 'matinière': 6, 'oscillocoulissante': 0, 'constituante': 0, 'suiffeuse': 9, 'enveloppeuse': 2, 'lyrée': 0, 'gainière': 6, 'américano-australienne': 4, 'socio-éducative': 7, 'liquidatrice': 1, 'germinative': 7, 'indépassée': 0, 'libérienne': 4, 'faisandière': 6, 'sexuelle': 4, 'boisselière': 6, 'mordante': 0, 'galvaudeuse': 9, 'cananéenne': 4, 'hypercontinentale': 3, 'porracée': 0, 'syncopale': 3, 'littératrice': 1, 'corédactrice': 1, 'bermudienne': 4, 'seuillée': 0, 'affine': 0, 'marchandeuse': 2, 'pasticheuse': 2, 'tchadienne': 4, 'oxydante': 0, 'mécatronicienne': 4, 'lettone': 0, 'paniculée': 0, 'pervertisseuse': 2, 'succenturiée': 0, 'supérieure': 0, 'médicalisante': 0, 'possessive': 7, 'croqueuse': 2, 'inarticulée': 0, 'bredouillante': 0, 'unisexuée': 0, 'préconisatrice': 1, 'crackeuse': 2, 'nestorienne': 4, 'pondéreuse': 9, 'lilliputienne': 4, 'semoulière': 6, 'réfrigérante': 0, 'purulente': 0, 'asturienne': 4, 'communicatrice': 1, 'zélandaise': 0, 'lampassée': 0, 'magistrate': 0, 'expressive': 7, 'balancière': 6, 'affligeante': 0, 'gibbeuse': 9, 'exploiteuse': 2, 'francilienne': 4, 'antiliante': 0, 'monnayeuse': 2, 'franco-surinamaise': 0, 'gardoise': 0, 'cycloïdale': 3, 'imageuse': 2, 'niaise': 0, 'vacancière': 6, 'factorielle': 4, 'monoflorale': 3, 'ébaucheuse': 2, 'ponctuelle': 4, 'embouteilleuse': 2, 'vacante': 0, 'détentrice': 1, 'reportrice': 1, 'antioxydante': 0, 'béquillarde': 0, 'tridimensionnelle': 4, 'haute-lissière': 6, 'théologienne': 4, 'biscottière': 6, 'ruminante': 0, 'radicante': 0, 'séraphine': 0, 'autoréalisatrice': 1, 'haveuse': 2, 'carillonnante': 0, 'renaissante': 0, 'irakienne': 4, 'coiffeuse': 2, 'disgracieuse': 9, 'péripatéticienne': 4, 'variante': 0, 'feuillardière': 6, 'crétine': 0, 'migrante': 0, 'séparatrice': 1, 'giletière': 6, 'périnatale': 0, 'liliacée': 0, 'affligée': 0, 'démobilisatrice': 1, 'féale': 3, 'frémissante': 0, 'nord-américaine': 0, 'signalisatrice': 1, 'brésilienne': 4, 'assomptive': 7, 'jambière': 6, 'volumineuse': 9, 'formatrice': 1, 'indigente': 0, 'fringante': 0, 'monodimensionnelle': 4, 'calleuse': 9, 'vomitive': 7, 'vendangeuse': 2, 'postprandiale': 3, 'caloporteuse': 2, 'hérissonne': 4, 'interdépartementale': 3, 'bimensuelle': 4, 'inaccentuée': 0, 'archi-fausse': 15, 'baronne': 4, 'demandeuse': 2, 'plaqueuse': 2, 'périurbaine': 0, 'dandinante': 0, 'défilante': 0, 'effileuse': 2, 'losangée': 0, 'meurtrière': 6, 'turque': 13, 'greffière': 6, 'restauratrice': 1, 'vocifératrice': 1, 'arriérée': 0, 'cordée': 0, 'mal-famée': 0, 'ambrosienne': 4, 'stanneuse': 9, 'flatteuse': 2, 'tripière': 6, 'intertextuelle': 4, 'rouanne': 4, 'emmerdeuse': 2, 'russienne': 4, 'organicienne': 4, 'palléale': 3, 'sidérante': 0, 'ciseleuse': 2, 'montante': 0, 'opportune': 0, 'révoquée': 0, 'ultradienne': 4, 'beuglante': 0, 'programmeuse': 2, 'crooneuse': 2, 'perquisitionnée': 0, 'baigneuse': 2, 'visigothe': 0, 'ferromagnésienne': 4, 'herminée': 0, 'poulaine': 0, 'batailleuse': 2, 'éléphantine': 0, 'sardinière': 6, 'somalienne': 4, 'furfuracée': 0, 'parleuse': 2, 'contemplatrice': 1, 'teinte': 0, 'mandchoue': 0, 'abeillère': 6, 'tangentielle': 4, 'glaireuse': 9, 'himalayenne': 4, 'abiétine': 0, 'nord-vietnamienne': 4, 'inviteuse': 2, 'inappliquée': 0, 'mignonnette': 4, 'involutée': 0, 'cellérière': 6, 'papouasienne': 4, 'propulsive': 7, 'subtile': 0, 'ocreuse': 9, 'cirière': 6, 'gréco-latine': 0, 'rouleautée': 0, 'résomptive': 7, 'émolliente': 0, 'auxiliatrice': 1, 'invaincue': 0, 'arracheuse': 2, 'réceptive': 7, 'péritonéale': 3, 'dorée': 0, 'bolivienne': 4, 'amarile': 0, 'salvatrice': 1, 'vinificatrice': 1, 'circonférentielle': 4, 'urgonienne': 4, 'émondeuse': 2, 'conquise': 0, 'texane': 0, 'décanteuse': 2, 'cap-verdienne': 4, 'affadissante': 0, 'socioéducative': 7, 'démoralisante': 0, 'frioulane': 0, 'fouisseuse': 2, 'germinale': 3, 'sensorielle': 4, 'stendhalienne': 4, 'plisseuse': 2, 'questionneuse': 2, 'caresseuse': 2, 'entêtante': 0, 'vielleuse': 9, 'carabinée': 0, 'ergoteuse': 2, 'inséminée': 0, 'bisexuelle': 4, 'furibonde': 0, 'escaliéteuse': 2, 'accoucheuse': 2, 'aréneuse': 9, 'néolamarckienne': 4, 'proliférante': 0, 'pénétrante': 0, 'stockeuse': 2, 'cohésive': 7, 'minutieuse': 9, 'unitarienne': 4, 'migraineuse': 9, 'pentathlonienne': 4, 'modeleuse': 2, 'vaniteuse': 9, 'mercurielle': 4, 'laborieuse': 9, 'bourlingueuse': 2, 'intersexuelle': 4, 'poreuse': 9, 'foxée': 0, 'dénoyauteuse': 2, 'conormale': 3, 'bienvoulue': 0, 'rhino-pharyngée': 0, 'toscane': 0, 'camarguaise': 0, 'débosseleuse': 2, 'insoumise': 0, 'irrévérencieuse': 9, 'suffragante': 0, 'kiosquière': 6, 'euclidienne': 4, 'caissonnée': 0, 'semainière': 6, 'conventionnelle': 4, 'horlogère': 6, 'contributrice': 1, 'interhumaine': 0, 'gigotante': 0, 'carpicultrice': 1, 'handicapée': 0, 'maudite': 0, 'mystérieuse': 9, 'camouflante': 0, 'bouchère': 6, 'infatuée': 0, 'sternocléidomastoïdienne': 4, 'fumerollienne': 4, 'cylindro-ogivale': 3, 'déliquescente': 0, 'évaluatrice': 1, 'accréditive': 7, 'décodeuse': 2, 'gouailleuse': 2, 'surréservée': 0, 'pistarde': 0, 'anoblissante': 0, 'oblative': 7, 'permutante': 0, 'tuniquée': 0, 'soignante': 0, 'canulante': 0, 'paysanne': 4, 'muqueuse': 9, 'intimidante': 0, 'cinghalaise': 0, 'confédérée': 0, 'iroquoise': 0, 'scribouilleuse': 2, 'sarrasine': 0, 'médicosociale': 3, 'coéditrice': 1, 'équatoguinéenne': 4, 'inébranlée': 0, 'franco-hongroise': 0, 'équidistante': 0, 'barbotine': 0, 'pétrarquisante': 0, 'penaude': 0, 'potestative': 7, 'soularde': 0, 'intercostale': 3, 'inopinée': 0, 'aménageuse': 2, 'gouverneure': 0, 'éthiopienne': 4, 'embêtante': 0, 'extravagante': 0, 'meublante': 0, 'privée': 0, 'culturale': 3, 'obtentrice': 1, 'sableuse': 9, 'guignarde': 0, 'liquéfiante': 0, 'greneuse': 2, 'marmotteuse': 2, 'souffleuse': 2, 'désinfectante': 0, 'vanisée': 0, 'médicosportive': 7, 'hypernerveuse': 9, 'pauvrette': 4, 'bavaroise': 0, 'berrichonne': 4, 'menaçante': 0, 'ombellée': 0, 'pleurnicheuse': 2, 'remplaçante': 0, 'modulante': 0, 'bonnetière': 6, 'fuégienne': 4, 'prodigieuse': 9, 'gigantale': 3, 'psychosomaticienne': 4, 'saccarinée': 0, 'massière': 6, 'contremaîtresse': 16, 'rimailleuse': 2, 'funérale': 3, 'verdissante': 0, 'débardeuse': 2, 'votante': 0, 'costaude': 0, 'railleuse': 2, 'galvaniseuse': 2, 'passagère': 6, 'interurbaine': 0, 'arabo-palestinienne': 4, 'miséricordieuse': 9, 'pomicultrice': 1, 'usurière': 6, 'sinistrée': 0, 'malaise': 0, 'fromagère': 6, 'droite': 0, 'métacarpienne': 4, 'paripennée': 0, 'affixale': 3, 'espagnole': 0, 'illimitée': 0, 'hésitante': 0, 'introspective': 7, 'orientatrice': 1, 'mignarde': 0, 'psycho-affective': 7, 'illuviale': 3, 'grassouillette': 4, 'isolatrice': 1, 'algéroise': 0, 'émulatrice': 1, 'nue': 0, 'oubliée': 0, 'coutumière': 6, 'dégraisseuse': 2, 'fournière': 6, 'baptismale': 3, 'divergente': 0, 'cordière': 6, 'fluviale': 3, 'ébavureuse': 2, 'estroprogestative': 7, 'obstructive': 7, 'mastoïdienne': 4, 'consciente': 0, 'stimulatrice': 1, 'façonneuse': 2, 'soustractive': 7, 'népérienne': 4, 'franco-brésilienne': 4, 'confidente': 0, 'fumeuse': 9, 'tondeuse': 2, 'richarde': 0, 'effusive': 7, 'évacuante': 0, 'chelléenne': 4, 'teilleuse': 2, 'assembleuse': 2, 'dissociative': 7, 'laciniée': 0, 'salariale': 3, 'déductive': 7, 'pigeonne': 4, 'luthérienne': 4, 'geignarde': 0, 'superfine': 0, 'éboueuse': 2, 'intuitive': 7, 'fendeuse': 2, 'gaullienne': 4, 'vicinale': 3, 'coordinatrice': 1, 'suggestive': 7, 'bookmakeuse': 2, 'vieillarde': 0, 'mexico-américaine': 0, 'autobloquante': 0, 'chevalière': 6, 'folichonne': 4, 'déverse': 0, 'ignorante': 0, 'ensorcelante': 0, 'oscillante': 0, 'épineuse': 9, 'électroportative': 7, 'contrefactrice': 1, 'distante': 0, 'civilisatrice': 1, 'bilabiale': 3, 'multivalente': 0, 'renardée': 0, 'entraîneuse': 2, 'guyanienne': 4, 'fleurissante': 0, 'méchante': 0, 'malienne': 4, 'nonchalante': 0, 'photoémettrice': 1, 'zonale': 3, 'suspicieuse': 9, 'proprette': 4, 'tarpéienne': 4, 'séditieuse': 9, 'conjuratrice': 1, 'substantive': 7, 'issante': 0, 'charretière': 6, 'rôtie': 0, 'écoutante': 0, 'involutive': 7, 'archéenne': 4, 'immunotolérante': 0, 'carotteuse': 2, 'cotonnière': 6, 'cryoconductrice': 1, 'turgescente': 0, 'métatarsienne': 4, 'commutative': 7, 'terre-neuvienne': 4, 'masseuse': 2, 'modifiante': 0, 'boscotte': 4, 'supermassive': 7, 'régleuse': 2, 'infréquentée': 0, 'cordiale': 3, 'réflexive': 7, 'ambivalente': 0, 'méditante': 0, 'médiopalatale': 3, 'naissante': 0, 'distinctive': 7, 'électroménagère': 6, 'camarde': 0, 'lustreuse': 2, 'élagueuse': 2, 'avaliseuse': 2, 'monocomposante': 0, 'parafiscale': 3, 'gobeletière': 6, 'humiliée': 0, 'indirecte': 0, 'orthogonale': 3, 'havanaise': 0, 'bordée': 0, 'démêlante': 0, 'boraine': 0, 'viveuse': 2, 'étouffante': 0, 'surenchérisseuse': 2, 'bétonnière': 6, 'divise': 0, 'schwarzienne': 4, 'artérioscléreuse': 9, 'imprévoyante': 0, 'trépassée': 0, 'tamiseuse': 2, 'endoctrinée': 0, 'chevauchante': 0, 'prôneuse': 2, 'anversoise': 0, 'viennoise': 0, 'moins-disante': 0, 'harponneuse': 2, 'électronégative': 7, 'galopante': 0, 'tubérisée': 0, 'ombreuse': 9, 'grondante': 0, 'anglo-normande': 0, 'télé-actrice': 1, 'présidentielle': 4, 'enjambeuse': 2, 'arsénieuse': 9, 'amérindienne': 4, 'inexperte': 0, 'infernale': 3, 'interloquée': 0, 'composteuse': 2, 'éclaireuse': 2, 'criailleuse': 2, 'rafraîchissante': 0, 'gauchère': 6, 'bêtatesteuse': 2, 'béguine': 0, 'mal-aimée': 0, 'médicinale': 3, 'ricanante': 0, 'binominale': 3, 'transhumante': 0, 'traîneuse': 2, 'abbevillienne': 4, 'faisane': 0, 'corallienne': 4, 'crolée': 0, 'saucissonneuse': 2, 'affective': 7, 'gredine': 0, 'putrescente': 0, 'autonettoyante': 0, 'floue': 0, 'potagère': 6, 'criblière': 6, 'toilière': 6, 'interosseuse': 9, 'grutière': 6, 'méridionale': 3, 'officielle': 4, 'consule': 0, 'crâneuse': 2, 'rituelle': 4, 'longévive': 7, 'étripée': 0, 'jéjunale': 3, 'ligamenteuse': 9, 'bractéale': 3, 'agrarienne': 4, 'maxwellienne': 4, 'systémicienne': 4, 'encroûtante': 0, 'réfringente': 0, 'simpliciale': 3, 'inconquise': 0, 'tumorale': 3, 'thermicienne': 4, 'régente': 0, 'déterreuse': 2, 'mulassière': 6, 'sommatrice': 1, 'tranchante': 0, 'crucifiée': 0, 'abrutie': 0, 'employée': 0, 'ensevelisseuse': 2, 'bhoutanaise': 0, 'acuminée': 0, 'tonitruante': 0, 'chthonienne': 4, 'hallucinée': 0, 'étameuse': 2, 'déséquilibrante': 0, 'fallacieuse': 9, 'interpellatrice': 1, 'applicative': 7, 'malendurante': 0, 'nasarde': 0, 'pêcheuse': 2, 'décortiqueuse': 2, 'temporelle': 4, 'miroitière': 6, 'recercelée': 0, 'hussarde': 0, 'sclérosante': 0, 'américano-israélienne': 4, 'aînée': 0, 'déclinante': 0, 'matheuse': 9, 'chaloupée': 0, 'salonnarde': 0, 'dissolvante': 0, 'nicaraguayenne': 4, 'novatrice': 1, 'solsticiale': 3, 'remblayeuse': 2, 'imaginative': 7, 'mâcheuse': 2, 'bondissante': 0, 'demi-entière': 6, 'blasphématrice': 1, 'grainetière': 6, 'aimante': 0, 'épaisse': 4, 'floconneuse': 9, 'bucheronne': 4, 'maligne': 24, 'chevaucheuse': 2, 'suppléante': 0, 'rigolarde': 0, 'charbonnière': 6, 'enguichée': 0, 'mosellane': 0, 'drapière': 6, 'avare': 0, 'archiépiscopale': 3, 'psychophysicienne': 4, 'ilienne': 4, 'discrète': 25, 'vénale': 3, 'conspiratrice': 1, 'expulsée': 0, 'afghane': 0, 'accidentée': 0, 'peloteuse': 2, 'susnommée': 0, 'festivalière': 6, 'chocolatée': 0, 'copernicienne': 4, 'celtisante': 0, 'brûleuse': 2, 'remontante': 0, 'commise': 0, 'antiaméricaine': 0, 'indéfinie': 0, 'recluse': 0, 'ourleuse': 2, 'étrangleuse': 2, 'fascinatrice': 1, 'homosexuelle': 4, 'érysipélateuse': 9, 'dameuse': 2, 'tubéracée': 0, 'ambisexuée': 0, 'gaumaise': 0, 'mariée': 0, 'incontestée': 0, 'poinçonneuse': 2, 'dévonienne': 4, 'accouveuse': 2, 'doreuse': 2, 'mutuelle': 4, 'intransitive': 7, 'intervertébrale': 3, 'délibérative': 7, 'varioleuse': 9, 'préceptrice': 1, 'toupilleuse': 2, 'lilloise': 0, 'épiscopalienne': 4, 'cartomancienne': 4, 'joggeuse': 2, 'hypnotiseuse': 2, 'abdomino-génitale': 3, 'adoucissante': 0, 'alpine': 0, 'regrattière': 6, 'profuse': 0, 'surpeuplée': 0, 'instante': 0, 'ancienne': 4, 'contentieuse': 9, 'impériale': 3, 'mousseuse': 9, 'anévrysmale': 3, 'nourricière': 6, 'démoulante': 0, 'piégeuse': 9, 'gastroduodénale': 3, 'malouine': 0, 'adjectivale': 3, 'interdigitale': 3, 'fibrilleuse': 9, 'logicielle': 4, 'américano-iranienne': 4, 'sous-occipitale': 3, 'alvine': 0, 'découverte': 0, 'immunodéficiente': 0, 'gestante': 0, 'marguillère': 6, 'papesse': 16, 'arborescente': 0, 'agressive': 7, 'stomacale': 3, 'toarcienne': 4, 'présentatrice': 1, 'caveuse': 2, 'guadeloupéenne': 4, 'morfondue': 0, 'nantie': 0, 'compatissante': 0, 'allumetière': 6, 'inattentive': 7, 'assassine': 0, 'exigüe': 12, 'expatriée': 0, 'burelée': 0, 'totalisante': 0, 'recéleuse': 2, 'musarde': 0, 'hongroise': 0, 'désespérée': 0, 'laxative': 7, 'humérale': 3, 'cousine': 0, 'concupiscente': 0, 'ozonée': 0, 'équatoriale': 3, 'levageuse': 2, 'évocatrice': 1, 'suraigüe': 12, 'interraciale': 3, 'transpirante': 0, 'engageante': 0, 'lesbienne': 4, 'couseuse': 2, 'actionnariale': 3, 'indicative': 7, 'transitionnelle': 4, 'jeunette': 4, 'entreprenante': 0, 'vénitienne': 4, 'divalente': 0, 'bordière': 6, 'hindoue': 0, 'implosée': 0, 'kidnappée': 0, 'charcutière': 6, 'ingénieuse': 9, 'gouacheuse': 2, 'déchétarienne': 4, 'unilatérale': 3, 'multiconductrice': 1, 'malsonnante': 0, 'univitelline': 0, 'insoucieuse': 9, 'polytechnicienne': 4, 'sterno-cléido-mastoïdienne': 4, 'immodérée': 0, 'fouilleuse': 2, 'colonelle': 4, 'fesseuse': 2, 'présente': 0, 'expansive': 7, 'relative': 7, 'définissante': 0, 'bahamienne': 4, 'inintelligente': 0, 'absconse': 0, 'guignole': 0, 'rouennière': 6, 'bifurquée': 0, 'transmutatrice': 1, 'illuminatrice': 1, 'drummeuse': 2, 'perturbatrice': 1, 'poursuiteuse': 2, 'montoise': 0, 'relanceuse': 2, 'stuporeuse': 9, 'bifocale': 3, 'équivalente': 0, 'dépenaillée': 0, 'graduée': 0, 'verruqueuse': 9, 'nitrifiante': 0, 'parurière': 6, 'joaillère': 6, 'accusée': 0, 'bienveillante': 0, 'testimoniale': 3, 'bêtabloquante': 0, 'piquée': 0, 'simienne': 4, 'vexante': 0, 'galbante': 0, 'révérende': 0, 'sous-lieutenante': 0, 'programmatrice': 1, 'slalomeuse': 2, 'persulfurée': 0, 'bissextile': 0, 'coïnculpée': 0, 'renouvelante': 0, 'radioélectricienne': 4, 'ambiguë': 0, 'partisane': 0, 'déwattée': 0, 'arrogante': 0, 'rhétoricienne': 4, 'cagnarde': 0, 'juridictionnelle': 4, 'soudeuse': 2, 'lorgneuse': 2, 'neuro-endocrinienne': 4, 'griffonneuse': 2, 'comtoise': 0, 'pestilentielle': 4, 'électrice': 1, 'banqueteuse': 2, 'tatoueuse': 2, 'investisseuse': 2, 'occitane': 0, 'onciale': 3, 'citrine': 0, 'germée': 0, 'estampeuse': 2, 'hallucinante': 0, 'microsomiale': 3, 'glisseuse': 2, 'gente': 0, 'génuflectrice': 1, 'pékinée': 0, 'tridentine': 0, 'expérimentale': 3, 'nasillarde': 0, 'chagrinante': 0, 'lectrice': 1, 'délicate': 0, 'suffixale': 3, 'débitante': 0, 'allemande': 0, 'comparante': 0, 'ouvreuse': 2, 'écrasante': 0, 'extraforte': 0, 'cyclonale': 3, 'coquette': 4, 'laponne': 4, 'raquetteuse': 2, 'dispatcheuse': 2, 'boyaudière': 6, 'pétrifiante': 0, 'pétanqueuse': 2, 'clémente': 0, 'carentielle': 4, 'gueularde': 0, 'grattante': 0, 'intensive': 7, 'exigeante': 0, 'habituée': 0, 'référentielle': 4, 'dénigreuse': 2, 'perdante': 0, 'conversive': 7, 'béotienne': 4, 'bengalie': 0, 'lydienne': 4, 'opposée': 0, 'claire': 0, 'tonnante': 0, 'réductrice': 1, 'assonante': 0, 'libératrice': 1, 'prescriptrice': 1, 'rampante': 0, 'cachottière': 6, 'saharienne': 4, 'phosphorescente': 0, 'nageuse': 2, 'multiconfessionnelle': 4, 'clicheuse': 2, 'grisante': 0, 'intersexuée': 0, 'superflue': 0, 'cabocharde': 0, 'badine': 0, 'saupoudreuse': 2, 'marrante': 0, 'fourreuse': 2, 'comtale': 3, 'aquicultrice': 1, 'divagatrice': 1, 'cordelière': 6, 'rescindante': 0, 'embaucheuse': 2, 'hétérosexuelle': 4, 'parachutale': 3, 'comédienne': 4, 'capiteuse': 9, 'anglo-indienne': 4, 'imitative': 7, 'attristante': 0, 'lapine': 0, 'coûtante': 0, 'diagnostiqueuse': 2, 'broussarde': 0, 'étancheuse': 2, 'pyrrhonienne': 4, 'resplendissante': 0, 'expectorante': 0, 'saturnienne': 4, 'subrogative': 7, 'fidjienne': 4, 'impotente': 0, 'injustifiée': 0, 'lunettière': 6, 'foisonnante': 0, 'marchante': 0, 'ultralibérale': 3, 'savante': 0, 'gâteuse': 9, 'certifiante': 0, 'ricinée': 0, 'foudroyante': 0, 'imbrulée': 0, 'affamante': 0, 'flasheuse': 2, 'aristotélicienne': 4, 'semi-marathonienne': 4, 'ricaneuse': 2, 'téléprospectrice': 1, 'footeuse': 9, 'patineuse': 2, 'lombricultrice': 1, 'statisticienne': 4, 'vive': 7, 'entière': 6, 'poupine': 0, 'vestigiale': 3, 'canonnière': 6, 'monopolisatrice': 1, 'communisante': 0, 'primo-délinquante': 0, 'hémorroïdale': 3, 'écorcheuse': 2, 'mondiale': 3, 'lascive': 7, 'personnelle': 4, 'cognitive': 7, 'échauffante': 0, 'gallo-romaine': 0, 'antipaludéenne': 4, 'délassante': 0, "prud'homale": 3, 'poltronne': 4, 'algérienne': 4, 'mérovingienne': 4, 'regardante': 0, 'couturière': 6, 'franco-lettonne': 4, 'accoupleuse': 2, 'engreneuse': 2, 'pyriteuse': 9, 'amasseuse': 2, 'illégale': 3, 'harcelante': 0, 'bénédictine': 0, 'patriciale': 3, 'spirale': 3, 'partouzarde': 0, 'famée': 0, 'adhésive': 7, 'dégivrante': 0, 'céphalo-rachidienne': 4, 'sénégalaise': 0, 'extractrice': 1, 'chaleureuse': 9, 'antidépressive': 7, 'controlatérale': 3, 'taïwanaise': 0, 'décontractante': 0, 'pousseuse': 2, 'importatrice': 1, 'teinturière': 6, 'ventrue': 0, 'demie': 0, 'flâneuse': 2, 'bananière': 6, 'incisive': 7, 'exaltée': 0, 'palière': 6, 'conne': 4, 'plénière': 6, 'valentine': 0, 'algonquine': 0, 'augmentative': 7, 'dénotationnelle': 4, 'concubine': 0, 'géophysicienne': 4, 'chicanière': 6, 'crayeuse': 9, 'quercitrine': 0, 'transpyrénéenne': 4, 'coquebine': 0, 'gringolée': 0, 'prépositionnelle': 4, 'contente': 0, 'insinuante': 0, 'galetteuse': 9, 'sempiternelle': 4, 'communale': 3, 'cocréatrice': 1, 'malvoyante': 0, 'incitative': 7, 'noethérienne': 4, 'expéditive': 7, 'subéreuse': 9, 'patoisante': 0, 'révolue': 0, 'laitière': 6, 'licenciée': 0, 'décrocheuse': 2, 'lobuleuse': 9, 'dentelière': 6, 'dangereuse': 9, 'cérébrospinale': 3, 'alluviale': 3, 'sursalée': 0, 'caoutchouteuse': 9, 'calandreuse': 2, 'savonnière': 6, 'colistière': 6, 'rhomboïdale': 3, 'imposeuse': 2, 'accordée': 0, 'translationnelle': 4, 'rêveuse': 2, 'ambianceuse': 2, 'exterminatrice': 1, 'fouleuse': 2, 'sure': 0, 'édificatrice': 1, 'casseuse': 2, 'revendeuse': 2, 'irrespectueuse': 9, 'vue': 0, 'résurrectionnelle': 4, 'constructive': 7, 'surplombante': 0, 'antécédente': 0, 'éclaboussante': 0, 'pro-européenne': 4, 'glosso-pharyngienne': 4, 'semi-conductrice': 1, 'harkie': 0, 'franco-iranienne': 4, 'psychoéducative': 7, 'démineuse': 2, 'frisottante': 0, 'pulpeuse': 9, 'inconditionnée': 0, 'dénonciatrice': 1, 'stérilisante': 0, 'bimestrielle': 4, 'mafflue': 0, 'haschischine': 0, 'pelliculeuse': 9, 'rechignée': 0, 'dessinatrice': 1, 'dorsale': 3, 'hydrocarbonée': 0, 'triathlonienne': 4, 'contremanifestante': 0, 'conduiseuse': 2, 'immobilière': 6, 'omnisciente': 0, 'abrupte': 0, 'autosomale': 3, 'rébarbative': 7, 'injuriée': 0, 'proviseure': 0, 'dominotière': 6, 'audiencière': 6, 'priante': 0, 'mienne': 4, 'tomenteuse': 9, 'attrayante': 0, 'orchestratrice': 1, 'sainte': 0, 'incapacitante': 0, 'vexatrice': 1, 'marbreuse': 2, 'iridiée': 0, 'pétéchiale': 3, 'telle': 4, 'processionnelle': 4, 'pulvérulente': 0, 'seyante': 0, 'législatrice': 1, 'fracasseuse': 2, 'bollywoodienne': 4, 'révérencieuse': 9, 'verdelette': 4, 'alkylante': 0, 'quadrilatérale': 3, 'lupuline': 0, 'coqueleuse': 9, 'bénisseuse': 2, 'littérale': 3, 'écorchée': 0, 'perdue': 0, 'mesmérienne': 4, 'mozambicaine': 0, 'flagorneuse': 2, 'corruptrice': 1, 'mirobolante': 0, 'consultative': 7, 'salpêtreuse': 9, 'féringienne': 4, 'guetteuse': 2, 'surette': 4, 'devancière': 6, 'polyfonctionnelle': 4, 'lavandicultrice': 1, 'animatrice': 1, 'franco-tunisienne': 4, 'ronfleuse': 2, 'bouseuse': 9, 'pisteuse': 2, 'abornée': 0, 'bienpensante': 0, 'éveillée': 0, 'blanchissante': 0, 'moralisante': 0, 'zoroastrienne': 4, 'socio-affective': 7, 'nominale': 3, 'profiteuse': 2, 'fascée': 0, 'carreleuse': 2, 'fibrineuse': 9, 'résistante': 0, 'mensuelle': 4, 'affaiblissante': 0, 'clonale': 3, 'luciférienne': 4, 'bulleuse': 9, 'stéréosélective': 7, 'aquacultrice': 1, 'areligieuse': 9, 'superchampionne': 4, 'malséante': 0, 'finistérienne': 4, 'sudorale': 3, 'hessienne': 4, 'haïe': 0, 'routeuse': 2, 'syncytiale': 3, 'réunionnaise': 0, 'abréviatrice': 1, 'locomotrice': 1, 'turco-mongole': 0, 'tapante': 0, 'abonnée': 0, 'afocale': 3, 'amollissante': 0, 'meuleuse': 2, 'inopportune': 0, 'empaffée': 0, 'exclamative': 7, 'hyposodée': 0, 'contrefaisante': 0, 'heaumière': 6, 'obéissante': 0, 'tribale': 3, 'montueuse': 9, 'annotatrice': 1, 'auto-immune': 0, 'évadée': 0, 'dépassante': 0, 'sarmenteuse': 9, 'jouteuse': 2, 'tôlière': 6, 'sociale': 3, 'indolente': 0, 'ragréeuse': 2, 'sécrétrice': 1, 'dragueuse': 2, 'dérouleuse': 2, 'trainarde': 0, 'gélive': 7, 'distrayante': 0, 'stertoreuse': 9, 'trochantérienne': 4, 'affileuse': 2, 'délictuelle': 4, 'primesautière': 6, 'roussillonnaise': 0, 'glaiseuse': 9, 'pinçarde': 0, 'microfibrée': 0, 'interministérielle': 4, 'psycho-éducatrice': 1, 'envouteuse': 2, 'causeuse': 2, 'forte': 0, 'interférentielle': 4, 'figurante': 0, 'attractive': 7, 'horizontale': 3, 'fouettarde': 0, 'avenue': 0, 'inscrite': 0, 'italienne': 4, 'voiturière': 6, 'énergisante': 0, 'fécondatrice': 1, 'buissonnière': 6, 'préromane': 0, 'pélagienne': 4, 'magnésienne': 4, 'cardeuse': 2, 'apostrophée': 0, 'sûre': 0, 'cloueuse': 2, 'louvoyante': 0, 'facétieuse': 9, 'installatrice': 1, 'ménine': 0, 'monténégrine': 0, 'ci-incluse': 0, 'avaricieuse': 9, 'vérificatrice': 1, 'outrageuse': 9, 'baragouineuse': 2, 'boulevardière': 6, 'baby-boomeuse': 2, 'antituberculeuse': 9, 'ébouriffante': 0, 'coexistante': 0, 'remémorative': 7, 'anticonstitutionnelle': 4, 'sanskrite': 0, 'rochassière': 6, 'synodale': 3, 'répondeuse': 2, 'baie': 0, 'régénérative': 7, 'tibio-tarsienne': 4, 'immunosupprimée': 0, 'hydroxylée': 0, 'rachidienne': 4, 'swahélie': 0, 'torrentielle': 4, 'ambiante': 0, 'multifonctionnelle': 4, 'yvelinoise': 0, 'faunesse': 16, 'tueuse': 2, 'élyséenne': 4, 'lignagère': 6, 'trappeuse': 2, 'jovienne': 4, 'inaugurale': 3, 'flavescente': 0, 'bicipitale': 3, 'administrée': 0, 'lanugineuse': 9, 'museuse': 2, 'attablée': 0, 'nigérienne': 4, 'ardoiseuse': 9, 'palmipartie': 0, 'coupée': 0, 'cardinale': 3, 'péridurale': 3, 'impédante': 0, 'maréchale': 3, 'augustale': 3, 'écopaysagère': 6, 'radiocommandée': 0, 'pronostiqueuse': 2, 'assoiffée': 0, 'fielleuse': 9, 'inconvenante': 0, 'sympathisante': 0, 'cataméniale': 3, 'radine': 0, 'glapissante': 0, 'spectrale': 3, 'bruissante': 0, 'térébrante': 0, 'auto-adaptative': 7, 'imperfective': 7, 'épurative': 7, 'supranormale': 3, 'disputeuse': 2, 'toiletteuse': 2, 'fascinante': 0, 'corrézienne': 4, 'chérie': 0, 'saignante': 0, 'propositionnelle': 4, 'décathlonienne': 4, 'videuse': 2, 'dentée': 0, 'violente': 0, 'fuchsienne': 4, 'explétive': 7, 'annonceuse': 2, 'jeteuse': 2, 'désinentielle': 4, 'trachéotomisée': 0, 'désarmante': 0, 'vasomotrice': 1, 'chiropraticienne': 4, 'nébuleuse': 9, 'glorieuse': 9, 'cespiteuse': 9, 'imprimante': 0, 'newtonienne': 4, 'glaciale': 3, 'argumentative': 7, 'motrice': 1, 'optionnelle': 4, 'triphasée': 0, 'formicante': 0, 'équilatérale': 3, 'québecoise': 0, 'ulcérative': 7, 'énergéticienne': 4, 'asexuelle': 4, 'bi-infinie': 0, 'inauguratrice': 1, 'désavantageuse': 9, 'persifleuse': 2, 'serrurière': 6, 'disqualifiée': 0, 'émouvante': 0, 'prolétarienne': 4, 'cérulée': 0, 'semi-manufacturée': 0, 'moyen-orientale': 3, 'réticuloendothéliale': 3, 'tendineuse': 9, 'pudibonde': 0, 'alépine': 0, 'blondinette': 4, 'vocalisatrice': 1, 'vénérienne': 4, 'illettrée': 0, 'ignominieuse': 9, 'accastilleuse': 2, 'skateuse': 2, 'siennoise': 0, 'itinérante': 0, 'superattractive': 7, 'échiquéenne': 4, 'mystifiante': 0, 'chiropractrice': 1, 'accrocheuse': 2, 'satisfaisante': 0, 'grecque': 28, 'follette': 4, 'indélicate': 0, 'fulminante': 0, 'offensive': 7, 'infortunée': 0, 'ombrienne': 4, 'anodine': 0, 'occipitale': 3, 'indécise': 0, 'pacsée': 0, 'mamelue': 0, 'arillée': 0, 'pivotante': 0, 'hypertextuelle': 4, 'australo-française': 0, 'tristounette': 4, 'pérégrine': 0, 'cotutrice': 1, 'capillicultrice': 1, 'allusive': 7, 'aurignacienne': 4, 'non-fumeuse': 2, 'marocaine': 0, 'crue': 0, 'inapparente': 0, 'roboticienne': 4, 'quinteuse': 9, 'guillerette': 4, 'passionnante': 0, 'performeuse': 2, 'créancière': 6, 'régnante': 0, 'malheureuse': 9, 'préexistante': 0, 'diviseuse': 2, 'incomprise': 0, 'trameuse': 2, 'olécranienne': 4, 'muscinale': 3, 'cléricale': 3, 'championne': 4, 'charentaise': 0, 'embrasseuse': 2, 'pleine': 0, 'ronflante': 0, 'irritée': 0, 'aventurière': 6, 'brocheuse': 2, 'inhibitive': 7, 'bâilleuse': 2, 'pédiculée': 0, 'collaboratrice': 1, 'inefficiente': 0, 'copulatrice': 1, 'agaillardie': 0, 'déclarante': 0, 'jappeuse': 2, 'benjamine': 0, 'autolissante': 0, 'suractive': 7, 'adultérine': 0, 'culturelle': 4, 'bagnarde': 0, 'parpaillote': 0, 'perfective': 7, 'médico-professionnelle': 4, 'fluctuante': 0, 'anormale': 3, 'antithyroïdienne': 4, 'ségrégative': 7, 'tréfileuse': 2, 'vaseuse': 9, 'morveuse': 9, 'paradoxale': 3, 'gaufreuse': 2, 'stadière': 6, 'complétive': 7, 'perlinguale': 3, 'émigrée': 0, 'périorale': 0, 'patiente': 0, 'péribuccale': 3, 'autopsiée': 0, 'décapeuse': 2, 'socialisante': 0, 'plâtrière': 6, 'piailleuse': 2, 'désertifiante': 0, 'altérative': 7, 'multifamiliale': 3, 'neuve': 7, 'tendeuse': 2, 'tambourineuse': 2, 'ressuscitée': 0, 'malapprise': 0, 'panafricaine': 0, 'fourragère': 6, 'manchoise': 0, 'bio-ingénieure': 0, 'ronchonneuse': 2, 'inexploitée': 0, 'idéelle': 4, 'covendeuse': 2, 'exposante': 0, 'norvégienne': 4, 'lavoisienne': 4, 'jurée': 0, 'socio-professionnelle': 4, 'disciplinée': 0, 'logeuse': 2, 'soumise': 0, 'austronésienne': 4, 'délitescente': 0, 'efficiente': 0, 'imprévue': 0, 'coextensive': 7, 'fanfaronne': 4, 'descendeuse': 2, 'tremblante': 0, 'bilobée': 0, 'fortunée': 0, 'scaphandrière': 6, 'limbourgeoise': 0, 'saigneuse': 9, 'actuarielle': 4, 'colombine': 0, 'scintillante': 0, 'gomorrhéenne': 4, 'réanimatrice': 1, 'suédée': 0, 'moutonnée': 0, 'retreinte': 0, 'fossoyeuse': 2, 'palatale': 3, 'extemporanée': 0, 'cristallinienne': 4, 'flambante': 0, 'wagonnière': 6, 'peluchée': 0, 'esquintante': 0, 'légère': 6, 'marchande': 0, 'désobéissante': 0, 'éhontée': 0, 'enculeuse': 2, 'draconienne': 4, 'processuelle': 4, 'flegmoneuse': 9, 'ultraconservatrice': 1, 'protutrice': 1, 'intemporelle': 4, 'militaro-industrielle': 4, 'syntacticienne': 4, 'fibreuse': 9, 'coxale': 3, 'conjonctivale': 3, 'gémisseuse': 2, 'appelante': 0, 'fluette': 4, 'phraseuse': 2, 'lacédémonienne': 4, 'ferro-magnésienne': 4, 'surjective': 7, 'chartraine': 0, 'inexaucée': 0, 'tournoyante': 0, 'saunière': 6, 'aromaticienne': 4, 'iléocæcale': 3, 'régionale': 3, 'escamoteuse': 2, 'daltonienne': 4, 'bourreuse': 2, 'somnolente': 0, 'biquotidienne': 4, 'paniquante': 0, 'incomplète': 25, 'acuponctrice': 1, 'coparentale': 3, 'dure': 0, 'lucrative': 7, 'sifflotante': 0, 'épicentrale': 3, 'layetière': 6, 'électrotechnicienne': 4, 'fluorée': 0, 'pique-niqueuse': 2, 'fouetteuse': 2, 'hâtive': 7, 'cloutière': 6, 'attentionnelle': 4, 'saintongeaise': 0, 'trotteuse': 2, 'altérante': 0, 'antidéflagrante': 0, 'essénienne': 4, 'polytonale': 3, 'déshumanisante': 0, 'sourcière': 6, 'communicationnelle': 4, 'levrettée': 0, 'rentrante': 0, 'arrangeuse': 2, 'sorbonnarde': 0, 'onéreuse': 9, 'franco-française': 0, 'transrhénane': 0, 'désopilante': 0, 'ultralégère': 6, 'méditerranée': 0, 'médisante': 0, 'lotoise': 0, 'adaptative': 7, 'commandeuse': 2, 'représentative': 7, 'pygméenne': 4, 'cocontractante': 0, 'consentante': 0, 'extrudeuse': 2, 'détartrante': 0, 'royale': 3, 'brumale': 3, 'aléoutienne': 4, 'indiscrète': 25, 'cassante': 0, 'généticienne': 4, 'bambocharde': 0, 'fluente': 0, 'frutescente': 0, 'post-soixante-huitarde': 0, 'quartzeuse': 9, 'tabletière': 6, 'basculante': 0, 'hydraulicienne': 4, 'chambreuse': 2, 'drôlesse': 16, 'antirépublicaine': 0, 'latifoliée': 0, 'sphinctérienne': 4, 'dentue': 0, 'antifrançaise': 0, 'étouffeuse': 2, 'fessue': 0, 'viticultrice': 1, 'paperassière': 6, 'bourbeuse': 9, 'hypersustentatrice': 1, 'thaïlandaise': 0, 'malinoise': 0, 'nominante': 0, 'scripte': 0, 'herscheuse': 2, 'cressicultrice': 1, 'technicocommerciale': 3, 'déligneuse': 2, 'matraqueuse': 2, 'financière': 6, 'illuminative': 7, 'siliqueuse': 9, 'bassinante': 0, 'narcotrafiquante': 0, 'sous-durale': 3, 'contre-intuitive': 7, 'onglée': 0, 'décussée': 0, 'plaintive': 7, 'émotive': 7, 'mondaine': 0, 'anticonjoncturelle': 4, 'sautillante': 0, 'babyboumeuse': 2, 'contenante': 0, 'bedonnante': 0, 'interprétatrice': 1, 'sphénoïdale': 3, 'féculente': 0, 'composée': 0, 'moustachue': 0, 'parraineuse': 2, 'quadriennale': 3, 'officinale': 3, 'aubaine': 0, 'antisociale': 3, 'vectrice': 1, 'déclarative': 7, 'réactrice': 1, 'modulatrice': 1, 'peuhle': 0, 'partageuse': 9, 'sensibilisante': 0, 'glaceuse': 9, 'pultacée': 0, 'potelée': 0, 'taulière': 6, 'infirmière': 6, 'célébrante': 0, 'périapicale': 3, 'boycotteuse': 2, 'flexueuse': 9, 'péronière': 6, 'plantureuse': 9, 'couvrante': 0, 'communarde': 0, 'ripailleuse': 2, 'mouillante': 0, 'afghano-pakistanaise': 0, 'grossière': 6, 'glycosylée': 0, 'craintive': 7, 'réveilleuse': 2, 'pectorale': 3, 'chapitrale': 3, 'limonière': 6, 'russo-américaine': 0, 'granuleuse': 9, 'pérennante': 0, 'exhortative': 7, 'transformatrice': 1, 'coalisée': 0, 'adroite': 0, 'khmère': 6, 'legendrienne': 4, 'mareyeuse': 2, 'dalleuse': 2, 'heptathlonienne': 4, 'américano-danoise': 0, 'tremblée': 0, 'perforelieuse': 2, 'mégissière': 6, 'bessonne': 4, 'arienne': 4, 'contemptrice': 1, 'ichoreuse': 9, 'conarde': 0, 'réclamante': 0, 'décentralisatrice': 1, 'huguenote': 0, 'bourrelière': 6, 'esseulée': 0, 'encapuchonnée': 0, 'cléchée': 0, 'irradiée': 0, 'contractuelle': 4, 'contondante': 0, 'effervescente': 0, 'secouante': 0, 'participative': 7, 'managériale': 3, 'éternelle': 4, 'chieuse': 2, 'désinscrite': 0, 'binoclarde': 0, 'poisseuse': 9, 'choquante': 0, 'bronzeuse': 2, 'cornue': 0, 'bégayante': 0, 'adoptive': 7, 'préretraitée': 0, 'provirale': 3, 'absolue': 0, 'graphiteuse': 9, 'cisalpine': 0, 'inventrice': 1, 'inappréciée': 0, 'dominatrice': 1, 'astéroïdale': 3, 'fanatisante': 0, 'malsaine': 0, 'spéculatrice': 1, 'wesleyenne': 4, 'sinusale': 3, 'affriolante': 0, 'fragilisante': 0, 'belgo-néerlandaise': 0, 'rizicultrice': 1, 'océanienne': 4, 'ganguée': 0, 'moelleuse': 9, 'retombante': 0, 'douce': 9, 'kazakhe': 0, 'dilatatrice': 1, 'staphyline': 0, 'envahissante': 0, 'mercaticienne': 4, 'idéomotrice': 1, 'gustative': 7, 'chamane': 0, 'compograveuse': 2, 'logisticienne': 4, 'boucholeuse': 2, 'fantomale': 3, 'amplifiante': 0, 'fugitive': 7, 'confédérative': 7, 'gastro-duodénale': 3, 'désorganisatrice': 1, 'flageolante': 0, 'agissante': 0, 'laqueuse': 9, 'tibétaine': 0, 'éclatante': 0, 'réto-romane': 0, 'pastorienne': 4, 'régénératrice': 1, 'qatarie': 0, 'micronésienne': 4, 'négrière': 6, 'imprudente': 0, 'carottière': 6, 'contestatrice': 1, 'antigivrante': 0, 'lieutenante': 0, 'ravageuse': 2, 'sourcilleuse': 9, 'épieuse': 2, 'rafraîchie': 0, 'exquise': 0, 'graffiteuse': 2, 'vitrière': 6, 'conduite': 0, 'lituanienne': 4, 'méditative': 7, 'bavarde': 0, 'oppressive': 7, 'roncière': 6, 'autobronzante': 0, 'non-violente': 0, 'fraisicultrice': 1, 'cinglée': 0, 'pestiférée': 0, 'châtelaine': 0, 'teutonne': 4, 'albanaise': 0, 'polynésienne': 4, 'légale': 3, 'musulmane': 0, 'autoreproductrice': 1, 'mitochondriale': 3, 'rugueuse': 9, 'milicienne': 4, 'moghole': 0, 'sulfateuse': 2, 'plasticienne': 4, 'infectante': 0, 'coffretière': 6, 'non-belligérante': 0, 'placette': 4, 'avocassière': 6, 'carpienne': 4, 'médicoprofessionnelle': 4, 'pentue': 0, 'lippue': 0, 'incrustatrice': 1, 'malveillante': 0, 'œdémateuse': 9, 'transcaucasienne': 4, 'rouilleuse': 9, 'indicielle': 4, 'inculpée': 0, 'roumaine': 0, 'spumeuse': 9, 'finaude': 0, 'incidentelle': 4, 'contaminante': 0, 'confiseuse': 2, 'chaîneuse': 2, 'hébergeuse': 2, 'immolatrice': 1, 'débitrice': 1, 'prédigérée': 0, 'dirigeante': 0, 'postnatale': 0, 'arêtière': 6, 'bronzière': 6, 'affouagée': 0, 'rougeoleuse': 9, 'gitane': 0, 'messagère': 6, 'abstinente': 0, 'adoptée': 0, 'vésiculeuse': 9, 'charolaise': 0, 'orfévrée': 0, 'rebondissante': 0, 'auditive': 7, 'corrélationnelle': 4, 'chalengeuse': 2, 'structurale': 3, 'assortisseuse': 2, 'idéo-motrice': 1, 'cautérisante': 0, 'slameuse': 2, 'estonienne': 4, 'commençante': 0, 'entrepreneuriale': 3, 'highlandeuse': 2, 'ténorisante': 0, 'innominée': 0, 'changeuse': 2, 'désinhibitrice': 1, 'avicultrice': 1, 'grugeuse': 2, 'glénoïdale': 3, 'chitineuse': 9, 'mexicaine': 0, 'uncinée': 0, 'boiteuse': 9, 'fautrice': 1, 'ultra-courte': 0, 'aiglonne': 4, 'bourdonnante': 0, 'khédiviale': 3, 'sournoise': 0, 'inquiète': 25, 'néerlandaise': 0, 'moulineuse': 2, 'alcoolodépendante': 0, 'complexuelle': 4, 'envoyeuse': 2, 'matonne': 4, 'émailleuse': 2, 'entrepreneuse': 2, 'bredouilleuse': 2, 'conteuse': 2, 'abêtissante': 0, 'formeuse': 2, 'mendélienne': 4, 'demi-fine': 0, 'intelligente': 0, 'ougrienne': 4, 'thyroïdienne': 4, 'antipersonnelle': 4, 'intersectorielle': 4, 'colicitante': 0, 'sinusoïdale': 3, 'mordicante': 0, 'chancelante': 0, 'challengeuse': 2, 'manilleuse': 2, 'sensée': 0, 'ambulante': 0, 'extensionnelle': 4, 'brabançonne': 4, 'équato-guinéenne': 4, 'orléanaise': 0, 'bourgeonnante': 0, 'textuelle': 4, 'apéritrice': 1, 'dorsoventrale': 3, 'dérobeuse': 2, 'intimidatrice': 1, 'défective': 7, 'péri-urbaine': 0, 'rosicrucienne': 4, 'adscrite': 0, 'rentière': 6, 'concluante': 0, 'dépénalisante': 0, 'demeurée': 0, 'magnanière': 6, 'assureuse': 2, 'transocéanienne': 4, 'ferrailleuse': 2, 'conjonctive': 7, 'vadrouilleuse': 2, 'acescente': 0, 'longuette': 4, 'invitée': 0, 'franco-mexicaine': 0, 'annihilante': 0, 'franco-cubaine': 0, 'divagante': 0, 'techniverrière': 6, 'saugrenue': 0, 'corpulente': 0, 'névrosée': 0, 'accompagnante': 0, 'interpersonnelle': 4, 'cadrante': 0, 'mauritanienne': 4, 'stupéfiante': 0, 'constringente': 0, 'franco-pakistanaise': 0, 'carnée': 0, 'indisciplinée': 0, 'suppliciante': 0, 'gargotière': 6, 'monofonctionnelle': 4, 'syndicale': 3, 'sauteuse': 2, 'talqueuse': 9, 'rupine': 0, 'déracinée': 0, 'ligulée': 0, 'cohérente': 0, 'ventrale': 3, 'cocompacte': 0, 'génératrice': 1, 'côtière': 6, 'légitimée': 0, 'minimexée': 0, 'hadale': 3, 'avertisseuse': 2, 'saducéenne': 4, 'trekkeuse': 2, 'quérulente': 0, 'antisudorale': 3, 'translative': 7, 'sino-australienne': 4, 'disparue': 0, 'autoporteuse': 2, 'compteuse': 2, 'sommeilleuse': 9, 'absente': 0, 'saligaude': 0, 'fasciée': 0, 'portante': 0, 'dépourvue': 0, 'agglutinante': 0, 'touffue': 0, 'excédante': 0, 'chambrière': 6, 'gradée': 0, 'bilieuse': 9, 'boulangère': 6, 'échotière': 6, 'vanneuse': 2, 'céphalorachidienne': 4, 'néogrammairienne': 4, 'commissurale': 3, 'cohabitante': 0, 'pharyngienne': 4, 'inviolée': 0, 'conservatrice': 1, 'autocollante': 0, 'préventive': 7, 'bulbeuse': 9, 'inconsciente': 0, 'accablante': 0, 'médullo-surrénale': 0, 'fondeuse': 2, 'caloyère': 6, 'codirectrice': 1, 'transitive': 7, 'pendue': 0, 'assimilante': 0, 'dépravée': 0, 'épinceteuse': 2, 'rhabilleuse': 2, 'évidente': 0, 'maraichère': 6, 'échevinale': 3, 'excrémenteuse': 9, 'décorative': 7, 'ruchée': 0, 'caoutchoutière': 6, 'bordante': 0, 'biostatisticienne': 4, 'samaritaine': 0, 'folkeuse': 9, 'mesureuse': 2, 'rescapée': 0, 'contigüe': 12, 'indéterminée': 0, 'affainéantie': 0, 'navrante': 0, 'instauratrice': 1, 'frisante': 0, 'sous-jacente': 0, 'géante': 0, 'émergée': 0, 'épaississante': 0, 'psychosensorimotrice': 1, 'égarée': 0, 'antivénérienne': 4, 'parieuse': 2, 'tumultueuse': 9, 'riveraine': 0, 'familiale': 3, 'paillarde': 0, 'vaccinatrice': 1, 'melonnée': 0, 'belgo-luxembourgeoise': 0, 'plagale': 3, 'exémateuse': 9, 'percutante': 0, 'roturière': 6, 'pouparde': 0, 'destinatrice': 1, 'entendante': 0, 'déchevelante': 0, 'permienne': 4, 'victorieuse': 9, 'correspondancière': 6, 'mélodieuse': 9, 'désignative': 7, 'extra-fine': 0, 'postformée': 0, 'crochue': 0, 'goûteuse': 9, 'incorporelle': 4, 'rondouillarde': 0, 'australienne': 4, 'soudanienne': 4, 'casanière': 6, 'pelliculée': 0, 'conjointe': 0, 'prohibitive': 7, 'éclusière': 6, 'égale': 3, 'zurichoise': 0, 'antiréflexive': 7, 'laborante': 0, 'franco-espagnole': 0, 'tractive': 7, 'dépurative': 7, 'haïtienne': 4, 'sublinguale': 3, 'escaladeuse': 2, 'canalisatrice': 1, 'soupçonneuse': 9, 'tâcheronne': 4, 'guinéenne': 4, 'explosive': 7, 'biinfinie': 0, 'ravigotante': 0, 'profanatrice': 1, 'frugale': 3, 'cracheuse': 2, 'intercurrente': 0, 'fameuse': 9, 'salissante': 0, 'barakie': 0, 'encroutante': 0, 'servante': 0, 'pharaonne': 4, 'sourceuse': 2, 'décoratrice': 1, 'surexcitante': 0, 'levalloisienne': 4, 'agrandissante': 0, 'poissarde': 0, 'grondeuse': 2, 'besogneuse': 9, 'suppurée': 0, 'chirurgienne': 4, 'hacheuse': 2, 'crépitante': 0, 'sidéenne': 4, 'costumière': 6, 'anticonceptionnelle': 4, 'phonéticienne': 4, 'incertaine': 0, 'ivoirine': 0, 'nitreuse': 9, 'polissonne': 4, 'trifaciale': 3, 'antibiorésistante': 0, 'sanglante': 0, 'probabilisée': 0, 'euscarienne': 4, 'insaturée': 0, 'vascularisée': 0, 'hasardeuse': 9, 'anti-seigneuriale': 3, 'dentellière': 6, 'méditerranéenne': 4, 'américano-néerlandaise': 0, 'socioculturelle': 4, 'braconnière': 6, 'originale': 3, 'refendeuse': 2, 'percutanée': 0, 'glandée': 0, 'francisante': 0, 'morutière': 6, 'grimaude': 0, 'capillotractée': 0, 'wallonne': 4, 'implosive': 7, 'fermentative': 7, 'préposée': 0, 'vrombissante': 0, 'pluvionivale': 3, 'primitive': 7, 'quinaude': 0, 'turonienne': 4, 'surfaceuse': 2, 'honteuse': 9, 'excito-motrice': 1, 'lourde': 0, 'agnate': 0, 'embarrassée': 0, 'actancielle': 4, 'parapharmacienne': 4, 'ordonnatrice': 1, 'draineuse': 2, 'mornée': 0, 'coéternelle': 4, 'prépondérante': 0, 'essorante': 0, 'desservante': 0, 'picturale': 3, 'poivrière': 6, 'vergetée': 0, 'franchiseuse': 2, 'prédicative': 7, 'transuranienne': 4, 'pacificatrice': 1, 'monaurale': 3, 'bienaimée': 0, 'remplisseuse': 2, 'juive': 7, 'franco-anglaise': 0, 'infectieuse': 9, 'forgeronne': 4, 'adéquate': 0, 'discuteuse': 2, 'localisante': 0, 'appréciative': 7, 'sauvagine': 0, 'sculptrice': 1, 'perforante': 0, 'obstétricienne': 4, 'temporisatrice': 1, 'virtuelle': 4, 'archiprêtresse': 16, 'poilante': 0, 'poméranienne': 4, 'anténatale': 0, 'oiseleuse': 2, 'hamiltonienne': 4, 'spirituelle': 4, 'mécréante': 0, 'ornaise': 0, 'îlotière': 6, 'poulotte': 4, 'diffamatrice': 1, 'inférieure': 0, 'aigrie': 0, 'frustrante': 0, 'prénasalisée': 0, 'escompteuse': 2, 'néo-hébridaise': 0, 'allitérative': 7, 'bureauticienne': 4, 'charmante': 0, 'sporulée': 0, 'ultérieure': 0, 'turriculée': 0, 'trisannuelle': 4, 'prosternée': 0, 'apollinienne': 4, 'calvadosienne': 4, 'caféière': 6, 'philippine': 0, 'apostate': 0, 'studieuse': 9, 'pressureuse': 2, 'élingueuse': 2, 'victorienne': 4, 'sélective': 7, 'ariégeoise': 0, 'tacticienne': 4, 'crânienne': 4, 'postière': 6, 'tabatière': 6, 'amputée': 0, 'hawaïenne': 4, 'heureuse': 9, 'unipersonnelle': 4, 'tamisière': 6, 'activatrice': 1, 'concertante': 0, 'genouillée': 0, 'antéropostérieure': 0, 'basse-courière': 6, 'décompteuse': 2, 'spatio-temporelle': 4, 'masticatrice': 1, 'sondagière': 6, 'résineuse': 9, 'trouillarde': 0, 'marcescente': 0, 'brinquebalante': 0, 'peléenne': 4, 'dîneuse': 2, 'rhumatisante': 0, 'introductive': 7, 'bâfreuse': 2, 'ailée': 0, 'possessionnée': 0, 'applicatrice': 1, 'codemanderesse': 20, 'autoévaluante': 0, 'florale': 3, 'plumeuse': 9, 'sumérienne': 4, 'gratteuse': 2, 'modelante': 0, 'triboluminescente': 0, 'marémotrice': 1, 'pompière': 6, 'pyramidée': 0, 'voyageuse': 2, 'brocanteuse': 2, 'grignarde': 0, 'sensitive': 7, 'troublante': 0, 'euthanasiée': 0, 'froussarde': 0, 'feutrière': 6, 'délégante': 0, 'incrémentale': 3, 'subéquatoriale': 3, 'guillotineuse': 2, 'rigoleuse': 2, 'délatrice': 1, 'formalisante': 0, 'défenderesse': 20, 'progestative': 7, 'évènementielle': 4, 'attachée': 0, 'contrevenante': 0, 'ossue': 0, 'grêleuse': 9, 'vaccinale': 3, 'boursicotière': 6, 'poivrote': 0, 'sous-peuplée': 0, 'localisatrice': 1, 'poirée': 0, 'déconnante': 0, 'xiphoïdienne': 4, 'soûlaude': 0, 'vésico-utérine': 0, 'gladiatrice': 1, 'immigrante': 0, 'matricielle': 4, 'bobineuse': 2, 'insensée': 0, 'académicienne': 4, 'précipitée': 0, 'septennale': 3, 'subordonnante': 0, 'peccamineuse': 9, 'pénale': 3, 'armurière': 6, 'japonisante': 0, 'égayante': 0, 'glutineuse': 9, 'diligente': 0, 'pistonnée': 0, 'écrivaillée': 0, 'khalifale': 3, 'désagrégeante': 0, 'scrutatrice': 1, 'obligée': 0, 'népalaise': 0, 'brodeuse': 2, 'retraite': 0, 'rousse': 15, 'laie': 0, 'processive': 7, 'chevelue': 0, 'prairiale': 3, 'une': 0, 'plasmolysée': 0, 'respective': 7, 'purificatrice': 1, 'zozoteuse': 2, 'flatulente': 0, 'flexionnelle': 4, 'systématicienne': 4, 'cambrioleuse': 2, 'mangeuse': 2, 'perçante': 0, 'continuelle': 4, 'réparatrice': 1, 'furieuse': 9, 'accusatrice': 1, 'débineuse': 2, 'fusante': 0, 'cogérante': 0, 'nantaise': 0, 'subulée': 0, 'accorte': 0, 'codante': 0, 'rhétienne': 4, 'jambée': 0, 'soudière': 6, 'hibernale': 3, 'néo-platonicienne': 4, 'vérifieuse': 2, 'arnaqueuse': 2, 'succulente': 0, 'jaunissante': 0, 'puerpérale': 3, 'ébarbeuse': 2, 'agrégative': 7, 'modificative': 7, 'chorale': 0, 'écornifleuse': 2, 'vespérale': 3, 'fondatrice': 1, 'liquidative': 7, 'discoureuse': 2, 'azimutale': 3, 'dansante': 0, 'lanceuse': 2, 'alléchante': 0, 'zootechnicienne': 4, 'gambienne': 4, 'cafteuse': 2, 'taxatrice': 1, 'auriculée': 0, 'consistante': 0, 'lâcheuse': 2, 'fluocompacte': 0, 'résolutive': 7, 'doctorale': 3, 'vivificatrice': 1, 'intentionnelle': 4, 'époussetée': 0, 'adjudante': 0, 'sépulcrale': 3, 'houillère': 6, 'squatteuse': 2, 'paulienne': 4, 'bovine': 0, 'maigrelette': 4, 'requérante': 0, 'caquetante': 0, 'toroïdale': 3, 'maquisarde': 0, 'rageante': 0, 'verte': 0, 'intragénérationnelle': 4, 'mystico-religieuse': 9, 'restringente': 0, 'imperforée': 0, 'commune': 0, 'brossière': 6, 'connivente': 0, 'jolie': 0, 'écorceuse': 2, 'leadeuse': 2, 'payante': 0, 'franco-islandaise': 0, 'autrichienne': 4, 'contre-électromotrice': 1, 'shakespearienne': 4, 'paraguayenne': 4, 'prévenue': 0, 'scandaleuse': 9, 'pitchoune': 0, 'chétive': 7, 'poissonnière': 6, 'soûlonne': 4, 'antibactérienne': 4, 'husserlienne': 4, 'navetteuse': 2, 'amoureuse': 9, 'métamérisée': 0, 'univalente': 0, 'chérifienne': 4, 'saccarine': 0, 'discutante': 0, 'inaltérée': 0, 'secrète': 25, 'élusive': 7, 'coûteuse': 9, 'libertine': 0, 'nécessitante': 0, 'ralliée': 0, 'bêta-testeuse': 2, 'lamartinienne': 4, 'grainière': 6, 'distillatrice': 1, 'suppliciée': 0, 'gothe': 0, 'trinervée': 0, 'sous-marine': 0, 'antiaérienne': 4, 'toxicodépendante': 0, 'séquestrante': 0, 'bienfaitrice': 1, 'baraquée': 0, 'maorie': 0, 'individuelle': 4, 'transnationale': 3, 'toxi-infectieuse': 9, 'première': 6, 'éducative': 7, 'centrifugeuse': 2, 'alsacienne': 4, 'pédégée': 0, 'éruptive': 7, 'débordante': 0, 'transcriptionnelle': 4, 'rhodienne': 4, 'sus-jacente': 0, 'meneuse': 2, 'particulière': 6, 'enchérisseuse': 2, 'trifouilleuse': 2, 'absidale': 3, 'éphésienne': 4, 'suroxygénée': 0, 'spacieuse': 9, 'frisotante': 0, 'susurrante': 0, 'discriminatrice': 1, 'skiffeuse': 2, 'paralysante': 0, 'ballante': 0, 'piscicultrice': 1, 'vernisseuse': 2, 'innocente': 0, 'potencée': 0, 'argumentatrice': 1, 'calomnieuse': 9, 'enfançonne': 4, 'lustrante': 0, 'anecdotière': 6, 'rubéoleuse': 9, 'timonière': 6, 'connarde': 0, 'transsaharienne': 4, 'béate': 0, 'mourante': 0, 'révolutée': 0, 'goémonière': 6, 'valaisanne': 4, 'utriculeuse': 9, 'varoise': 0, 'présomptive': 7, 'buveuse': 2, 'catégoriale': 0, 'grogneuse': 2, 'doucette': 4, 'perceuse': 2, 'croissantière': 6, 'conchylicultrice': 1, 'désolante': 0, 'conseillère': 6, 'valeureuse': 9, 'empailleuse': 2, 'bienheureuse': 9, 'prédiffusée': 0, 'vitruvienne': 4, 'interinstitutionnelle': 4, 'sommitale': 3, 'trapézoïdale': 3, 'racleuse': 2, 'annoncière': 6, 'pyroligneuse': 9, 'poudreuse': 9, 'tchatcheuse': 2, 'abrasive': 7, 'vile': 0, 'sermonneuse': 2, 'maraude': 0, 'normande': 0, 'dative': 7, 'quotidienne': 4, 'austro-française': 0, 'étalière': 6, 'exponentielle': 4, 'grimpeuse': 2, 'aérienne': 4, 'délégatrice': 1, 'râlante': 0, 'sarroise': 0, 'racheteuse': 2, 'fraiseuse': 2, 'accommodante': 0, 'innomée': 0, 'baptisée': 0, 'sauvée': 0, 'perceptive': 7, 'oblitératrice': 1, 'briseuse': 2, 'coquine': 0, 'préhospitalière': 6, 'camphrée': 0, 'sécante': 0, 'courtière': 6, 'revivifiante': 0, 'crémière': 6, 'médico-sociale': 3, 'bidouilleuse': 2, 'choroïdienne': 4, 'crispante': 0, 'acconière': 6, 'soigneuse': 9, 'picoreuse': 2, 'olympienne': 4, 'paroxysmale': 3, 'épinceuse': 2, 'operculée': 0, 'jouissante': 0, 'cicéronienne': 4, 'pourchasseuse': 2, 'stylisticienne': 4, 'limoneuse': 9, 'obsessive': 7, 'minaudière': 6, 'grappilleuse': 2, 'érosive': 7, 'méprisée': 0, 'brigadière': 6, 'peccante': 0, 'postale': 3, 'sablonneuse': 9, 'nazaréenne': 4, 'mélangeuse': 2, 'doyenne': 4, 'corrigeuse': 2, 'directoriale': 3, 'orante': 0, 'pustulée': 0, 'envoyée': 0, 'cotylédonée': 0, 'débutante': 0, 'sprinteuse': 2, 'vapoteuse': 2, 'interculturelle': 4, 'frontalière': 6, 'cunicultrice': 1, 'configurationnelle': 4, 'distale': 3, 'rusée': 0, 'kolkhozienne': 4, 'matelassière': 6, 'abyssale': 3, 'marrie': 0, 'supercavitante': 0, 'pincharde': 0, 'épanouissante': 0, 'héraclitéenne': 4, 'insuffisante': 0, 'hydrurée': 0, 'attachante': 0, 'instinctive': 7, 'refoulée': 0, 'chevrotante': 0, 'attaquante': 0, 'butyreuse': 9, 'ivoirière': 6, 'sapientiale': 3, 'interlinguale': 3, 'hypophosphoreuse': 9, 'surrénalienne': 4, 'rossarde': 0, 'rotationnelle': 4, 'animale': 3, 'sanglotante': 0, 'saturnine': 0, 'outilleuse': 2, 'acousticienne': 4, 'auriculotemporale': 3, 'participiale': 3, 'merveilleuse': 9, 'faïencée': 0, 'agro-industrielle': 4, 'ivrognesse': 16, 'super-lourde': 0, 'subite': 0, 'ourdisseuse': 2, 'ployante': 0, 'néocoloniale': 3, 'foliacée': 0, 'nazillonne': 4, 'inquisitoriale': 3, 'bergsonienne': 4, 'totale': 3, 'maintenicienne': 4, 'pépiante': 0, 'séquanaise': 0, 'orpailleuse': 2, 'sexuée': 0, 'sous-préfectorale': 3, 'motarde': 0, 'odoriférante': 0, 'prédicatrice': 1, 'auto-stoppeuse': 2, 'rase': 0, 'élavée': 0, 'englobante': 0, 'inadaptée': 0, 'impromptue': 0, 'géorgienne': 4, 'métreuse': 2, 'persuasive': 7, 'intrarachidienne': 4, 'farineuse': 9, 'claveleuse': 9, 'piroguière': 6, 'pullulante': 0, 'céruléenne': 4, 'emballeuse': 2, 'affûteuse': 2, 'franco-péruvienne': 4, 'clandestine': 0, 'surnaturelle': 4, 'argentière': 6, 'bissau-guinéenne': 4, 'fureteuse': 2, 'pacifiante': 0, 'fondue': 0, 'tessellée': 0, 'hockeyeuse': 2, 'divulgatrice': 1, 'vireuse': 9, 'voltairienne': 4, 'marxisante': 0, 'éducationnelle': 4, 'désastreuse': 9, 'infructueuse': 9, 'reluisante': 0, 'galiléenne': 4, 'difficultueuse': 9, 'apicale': 3, 'carolingienne': 4, 'dynamisante': 0, 'préfrontale': 3, 'matérielle': 4, 'pustuleuse': 9, 'distancielle': 4, 'alizée': 0, 'fignoleuse': 2, 'carpettière': 6, 'testeuse': 2, 'allurée': 0, 'parigote': 0, 'directe': 0, 'dépendeuse': 2, 'dento-faciale': 3, 'iodurée': 0, 'partitive': 7, 'antidreyfusarde': 0, 'bonimenteuse': 2, 'grumeleuse': 9, 'cogniticienne': 4, 'résurgente': 0, 'immigrée': 0, 'professorale': 3, 'fuyarde': 0, 'investigatrice': 1, 'clarificatrice': 1, 'calière': 6, 'exécutante': 0, 'tubuleuse': 9, 'borélienne': 4, 'claquette': 4, 'danubienne': 4, 'subliminale': 3, 'palmilobée': 0, 'brouilleuse': 2, 'bavochée': 0, 'relapse': 0, 'prétorienne': 4, 'colossienne': 4, 'miraculeuse': 9, 'chiqueuse': 2, 'implorante': 0, 'défricheuse': 2, 'chahuteuse': 2, 'inégale': 3, 'cataclysmale': 3, 'colonisée': 0, 'ombilicale': 3, 'icarienne': 4, 'conciliatrice': 1, 'transférentielle': 4, 'majeure': 0, 'ammoniaquée': 0, 'sarcomateuse': 9, 'européenne': 4, 'élogieuse': 9, 'fictive': 7, 'pipeuse': 2, 'détraquée': 0, 'équationnelle': 4, 'coliqueuse': 9, 'facilitatrice': 1, 'chevillarde': 0, 'argumentée': 0, 'tisseuse': 2, 'rebouteuse': 2, 'ponantaise': 0, 'thésauriseuse': 2, 'inoccupée': 0, 'résidente': 0, 'aventureuse': 9, 'provinciale': 3, 'pèquenaude': 0, 'oculomotrice': 1, 'nuitarde': 0, 'bayésienne': 4, 'déterminative': 7, 'orpheline': 0, 'triomphante': 0, 'septentrionale': 3, 'pourrissante': 0, 'aspirante': 0, 'rédactrice': 1, 'arborisée': 0, 'savoisienne': 4, 'ovulée': 0, 'bicarrée': 0, 'abrutisseuse': 2, 'sous-clavière': 6, 'laryngienne': 4, 'lactescente': 0, 'loucheuse': 2, 'discourtoise': 0, 'magistrale': 3, 'moussante': 0, 'déciduale': 3, 'compagnonne': 4, 'prévalente': 0, 'vicelarde': 0, 'destructrice': 1, 'hivernante': 0, 'états-unienne': 4, 'faitière': 6, 'débilitante': 0, 'blanchisseuse': 2, 'acromiale': 3, 'chrétienne': 4, 'anamorphosée': 0, 'ensacheuse': 2, 'gammée': 0, 'singulative': 7, 'barboteuse': 2, 'segmentale': 3, 'coaxiale': 3, 'deltoïdienne': 4, 'camée': 0, 'faiseuse': 2, 'vilipendeuse': 2, 'accapareuse': 2, 'députée': 0, 'accréditrice': 1, 'bouletée': 0, 'étasunienne': 4, 'actrice': 1, 'vosgienne': 4, 'sentimentale': 3, 'plaine': 0, 'rondelette': 4, 'bouilleuse': 2, 'intumescente': 0, 'voluptueuse': 9, 'collégiale': 3, 'tunisienne': 4, 'érudite': 0, 'avorteuse': 2, 'cliente': 0, 'moireuse': 2, 'référente': 0, 'armatrice': 1, 'friande': 0, 'colzatière': 6, 'présidente': 0, 'abstruse': 0, 'dévolue': 0, 'proscrite': 0, 'bosseuse': 2, 'intercontinentale': 3, 'notificative': 7, 'latérale': 3, 'napolitaine': 0, 'émigrante': 0, 'persane': 0, 'obsédée': 0, 'chapelière': 6, 'abasourdissante': 0, 'conflictuelle': 4, 'tendancielle': 4, 'fessière': 6, 'roulottière': 6, 'rosacée': 0, 'cérébrale': 3, 'aigrette': 4, 'saisissante': 0, 'acquittée': 0, 'concurrente': 0, 'sagittée': 0, 'mutilée': 0, 'costaricaine': 0, 'aimantine': 0, 'tousseuse': 2, 'pâtissière': 6, 'douteuse': 9, 'refondatrice': 1, 'snifeuse': 2, 'déférente': 0, 'traceuse': 2, 'corrective': 7, 'dévergondée': 0, 'ferronnière': 6, 'sincipitale': 3, 'mudéjare': 0, 'endothéliale': 3, 'prédictive': 7, 'spiroïdale': 3, 'gaspilleuse': 2, 'intellectuelle': 4, 'bronchiteuse': 9, 'pêchue': 0, 'dessiccative': 7, 'invoquée': 0, 'débirentière': 6, 'oscillatrice': 1, 'ardente': 0, 'diédrale': 3, 'lénifiante': 0, 'cochère': 6, 'abortive': 7, 'brailleuse': 2, 'conjurée': 0, 'chouineuse': 2, 'mercière': 6, 'tresseuse': 2, 'schleue': 0, 'interrégionale': 3, 'mûrissante': 0, 'boxeuse': 2, 'simultanée': 0, 'banquière': 6, 'dissociatrice': 1, 'nilpotente': 0, 'croassante': 0, 'tricarde': 0, 'arséniée': 0, 'pinailleuse': 2, 'sienne': 4, 'rolleuse': 2, 'moniale': 3, 'équipollente': 0, 'nouveau-née': 0, 'éluviale': 3, 'plongeuse': 2, 'mixolydienne': 4, 'efflorescente': 0, 'décompensée': 0, 'gesticulatrice': 1, 'récalcitrante': 0, 'sabbathienne': 4, 'preneuse': 2, 'reptilienne': 4, 'digressive': 7, 'attrapeuse': 2, 'assyrienne': 4, 'chienne': 4, 'ondée': 0, 'saoule': 0, 'interférente': 0, 'postpalatale': 3, 'bûcheronne': 4, 'professeure': 0, 'passementière': 6, 'surcostale': 3, 'sultane': 0, 'énarquienne': 4, 'choisisseuse': 2, 'prédécoupée': 0, 'semestrielle': 4, 'émettrice': 1, 'florencée': 0, 'extraterritoriale': 3, 'monopolisante': 0, 'médiate': 0, 'spumescente': 0, 'branleuse': 2, 'tarsale': 3, 'rongeuse': 2, 'invasive': 7, 'affixée': 0, 'plucheuse': 9, 'incurieuse': 9, 'bimbelotière': 6, 'franco-libanaise': 0, 'progénitrice': 1, 'officieuse': 9, 'obligeante': 0, 'aryenne': 4, 'sidérale': 3, 'arbitrale': 3, 'causante': 0, 'césarienne': 4, 'inexécutée': 0, 'allergisante': 0, 'quadrimestrielle': 4, 'caractérisante': 0, 'pénicillinorésistante': 0, 'différentiée': 0, 'incroyante': 0, 'ajusteuse': 2, 'ismaélienne': 4, 'nivo-pluviale': 3, 'purpurine': 0, 'héritée': 0, 'festoyeuse': 2, 'irrésignée': 0, 'fourrière': 6, 'instigatrice': 1, 'boiseuse': 2, 'zigzagante': 0, 'réelle': 4, 'coiffante': 0, 'projective': 7, 'anarchisante': 0, 'recouvreuse': 2, 'sauveteuse': 2, 'metteuse': 2, 'omnipraticienne': 4, 'creuse': 9, 'auto-adhésive': 7, 'aborale': 3, 'neuronale': 3, 'mendiante': 0, 'impétrante': 0, 'bajocienne': 4, 'usinière': 6, 'minéralisante': 0, 'bombeuse': 2, 'chicaneuse': 2, 'inavouée': 0, 'galopine': 0, 'diapositive': 7, 'castratrice': 1, 'matrimoniale': 3, 'scapulo-humérale': 3, 'édifiante': 0, 'antécambrienne': 4, 'jardineuse': 9, 'orienteuse': 2, 'acéteuse': 9, 'moissonneuse': 2, 'jamaïcaine': 0, 'magdalénienne': 4, 'froufroutante': 0, 'directionnelle': 4, 'revancharde': 0, 'austro-hongroise': 0, 'bicarbonatée': 0, 'préconsciente': 0, 'alliacée': 0, 'bissexuelle': 4, 'exiguë': 0, 'chipeuse': 2, 'festive': 7, 'sélénienne': 4, 'intra-artérielle': 4, 'chaineuse': 2, 'minoenne': 4, 'inspectrice': 1, 'irlandaise': 0, 'primatiale': 3, 'pantouflarde': 0, 'générationnelle': 4, 'alexandrine': 0, 'cyberdélinquante': 0, 'nivéale': 3, 'psychotechnicienne': 4, 'maldivienne': 4, 'incitatrice': 1, 'penseuse': 2, 'défranchie': 0, 'dévaliseuse': 2, 'monoparentale': 3, 'exubérante': 0, 'attentive': 7, 'collective': 7, 'inconstante': 0, 'pleurnicharde': 0, 'pupitreuse': 2, 'hypoglycémiante': 0, 'osseuse': 9, 'raccrocheuse': 2, 'fécondante': 0, 'globe-trotteuse': 2, 'fichante': 0, 'haschichine': 0, 'retentissante': 0, 'garante': 0, 'versante': 0, 'périnéale': 3, 'malayo-polynésienne': 4, 'attenante': 0, 'équitante': 0, 'sanctifiante': 0, 'étroite': 0, 'élue': 0, 'surjacente': 0, 'franco-panaméenne': 4, 'imprimitive': 7, 'trafiquante': 0, 'geôlière': 6, 'bachelière': 6, 'manuscrite': 0, 'religieuse': 9, 'orageuse': 9, 'chatouilleuse': 2, 'banlieusarde': 0, 'farfouilleuse': 2, 'passive': 7, 'hébraïsante': 0, 'ghanéenne': 4, 'métalliseuse': 2, 'inclémente': 0, 'hottentote': 0, 'zélatrice': 1, 'gigotée': 0, 'bleue': 0, 'boratée': 0, 'strasbourgeoise': 0, 'conchylienne': 4, 'intendante': 0, 'encrouée': 0, 'marnaise': 0, 'grandissante': 0, 'écharneuse': 2, 'transformationnelle': 4, 'joliette': 4, 'phosphoreuse': 9, 'augustine': 0, 'bordelaise': 0, 'signifiante': 0, 'superstitieuse': 9, 'calibreuse': 2, 'bivariante': 0, 'prédatrice': 1, 'radiante': 0, 'emmerdante': 0, 'adjointe': 0, 'nubienne': 4, 'qatarienne': 4, 'esthétisante': 0, 'franco-indienne': 4, 'irrassasiée': 0, 'affolée': 0, 'copieuse': 9, 'virilocale': 3, 'maladroite': 0, 'fagnarde': 0, 'extraconjugale': 3, 'exaltante': 0, 'séreuse': 9, 'lavante': 0, 'subrogée': 0, 'branchue': 0, 'tumescente': 0, 'martyre': 0, 'vulgarisatrice': 1, 'palestinienne': 4, 'afro-brésilienne': 4, 'bétonneuse': 2, 'conseilleuse': 2, 'dionysienne': 4, 'afro-américaine': 0, 'curatrice': 1, 'psychochirurgienne': 4, 'lésinante': 0, 'pesante': 0, 'poignante': 0, 'rapporteuse': 2, 'urbaine': 0, 'déverbale': 3, 'colitigante': 0, 'baroudeuse': 2, 'protohistorienne': 4, 'profonde': 0, 'cambiale': 3, 'aviatrice': 1, 'tahitienne': 4, 'neurale': 3, 'déshéritée': 0, 'gréco-romaine': 0, 'délocalisante': 0, 'exhaustive': 7, 'riveuse': 2, 'expulsive': 7, 'houligane': 0, 'surproductrice': 1, 'sommelière': 6, 'fluidifiante': 0, 'colossale': 3, 'maraîchine': 0, 'oursonne': 4, 'courte': 0, 'captieuse': 9, 'soudaine': 0, 'accordeuse': 2, 'débatteuse': 2, 'radio-active': 7, 'hyaline': 0, 'accusative': 7, 'biscornue': 0, 'paridigitidée': 0, 'somptueuse': 9, 'épilatrice': 1, 'comburante': 0, 'abréviée': 0, 'archipresbytérale': 3, 'noduleuse': 9, 'électro-acousticienne': 4, 'inféconde': 0, 'rhizocarpée': 0, 'antihermitienne': 4, 'convective': 7, 'influente': 0, 'courtisée': 0, 'aboyante': 0, 'chinoise': 0, 'hercheuse': 2, 'tréflée': 0, 'endocrânienne': 4, 'oratorienne': 4, 'édentée': 0, 'vulnérante': 0, 'filiale': 3, 'rétreinte': 0, 'dépravante': 0, 'vagissante': 0, 'déposante': 0, 'euryhaline': 0, 'bullée': 0, 'comparatrice': 1, 'antichrétienne': 4, 'pochtronne': 4, 'considérative': 7, 'carthaginoise': 0, 'flagrante': 0, 'monofocale': 3, 'thébaine': 0, 'impaire': 0, 'tadjike': 0, 'artificieuse': 9, 'minorative': 7, 'smurfeuse': 2, 'jersiaise': 0, 'interdépendante': 0, 'bipartie': 0, 'sous-cutanée': 0, 'clunisienne': 4, 'officiante': 0, 'contragestive': 7, 'pondeuse': 2, 'malpolie': 0, 'lacuneuse': 9, 'envinée': 0, 'laplacienne': 4, 'nymphale': 3, 'photograveuse': 2, 'giboyeuse': 9, 'miraculée': 0, 'surdéterminante': 0, 'colo-rectale': 3, 'venteuse': 9, 'auditrice': 1, 'replète': 25, 'correctrice': 1, 'chiromancienne': 4, 'préindustrielle': 4, 'londonienne': 4, 'terminale': 3, 'cultuelle': 4, 'prébendée': 0, 'qualifiante': 0, 'enquêteuse': 2, 'chirale': 3, 'habitante': 0, 'doubleuse': 2, 'verseuse': 2, 'ennuyante': 0, 'encaisseuse': 2, 'consternante': 0, 'côtelée': 0, 'khédivale': 3, 'bénite': 0, 'viscérale': 3, 'piqueuse': 9, 'assainisseuse': 2, 'prépensionnée': 0, 'aérodynamicienne': 4, 'cimentière': 6, 'plieuse': 2, 'bodybuildeuse': 2, 'croissantée': 0, 'huitrière': 6, 'permissive': 7, 'proverbiale': 3, 'aléseuse': 2, 'exemptée': 0, 'herbacée': 0, 'ravissante': 0, 'finlandaise': 0, 'combattive': 7, 'pennée': 0, 'ferreuse': 9, 'bâtarde': 0, 'princière': 6, 'américano-irlandaise': 0, 'adhérente': 0, 'photo-émettrice': 1, 'rouergate': 0, 'polyphasée': 0, 'surgie': 0, "baha'ie": 0, 'ultra-confidentielle': 4, 'abroutie': 0, 'protégée': 0, 'distributive': 7, 'exécutive': 7, 'viagère': 6, 'camerounaise': 0, 'pétillante': 0, 'cossarde': 0, 'veveysanne': 4, 'superovariée': 0, 'vrillante': 0, 'laudative': 7, 'détimbrée': 0, 'néodarwinienne': 4, 'inapaisée': 0, 'calculeuse': 9, 'empoisonneuse': 2, 'houleuse': 9, 'inutilisée': 0, 'invertébrée': 0, 'glossopharyngienne': 4, 'vengeresse': 20, 'lycéenne': 4, 'omniprésente': 0, 'franco-coréenne': 4, 'glaneuse': 2, 'mireuse': 2, 'perceptuelle': 4, 'wagnérienne': 4, 'parcheminière': 6, 'princesse': 16, 'vermoulue': 0, 'quantitative': 7, 'antidiagonale': 3, 'égrillarde': 0, 'euskarienne': 4, 'verrée': 0, 'abuseuse': 2, 'psychomotrice': 1, 'cheminote': 0, 'loculée': 0, 'faillie': 0, 'bigleuse': 9, 'étampeuse': 2, 'vertigineuse': 9, 'malaisée': 0, 'intercantonale': 3, 'comploteuse': 2, 'labio-dentale': 3, 'vicennale': 3, 'assistée': 0, 'néocorticale': 3, 'contentive': 7, 'assaillante': 0, 'sorcière': 6, 'prieure': 0, 'factuelle': 4, 'pâteuse': 9, 'gazouillante': 0, 'dominée': 0, 'démentielle': 4, 'effaceuse': 2, 'soule': 0, 'vitrificatrice': 1, 'voleuse': 2, 'oiseuse': 9, 'atomicienne': 4, 'frappante': 0, 'massacreuse': 2, 'agente': 0, 'susjacente': 0, 'échiquetée': 0, 'pénicillino-résistante': 0, 'kinoise': 0, 'traductrice': 1, 'surreprésentée': 0, 'tuyauteuse': 2, 'blogueuse': 2, 'assimilative': 7, 'herbeuse': 9, 'mucronée': 0, 'fracassante': 0, 'constitutionnelle': 4, 'friponne': 4, 'urcéolée': 0, 'cultivatrice': 1, 'succombante': 0, 'aviveuse': 2, 'bougonne': 4, 'tintinnabulante': 0, 'roucoulante': 0, 'hesbignonne': 4, 'exorciseuse': 2, 'pataugeuse': 2, 'malvenante': 0, 'insurgente': 0, 'patricienne': 4, 'socinienne': 4, 'albuginée': 0, 'hégélienne': 4, 'ophidienne': 4, 'parvenue': 0, 'multivaluée': 0, 'délictueuse': 9, 'régressive': 7, 'laotienne': 4, 'franco-provençale': 3, 'neutralisante': 0, 'vicariale': 3, 'cahoteuse': 9, 'infoutue': 0, 'clitoridienne': 4, 'soldeuse': 2, 'adventive': 7, 'divorcée': 0, 'mésothéliale': 3, 'rhinopharyngienne': 4, 'agrandisseuse': 2, 'neurodégénérative': 7, 'chère': 6, 'diluante': 0, 'consultante': 0, 'théière': 6, 'épandeuse': 2, 'vauclusienne': 4, 'canoteuse': 2, 'arobase': 0, 'cagoulée': 0, 'fertilisante': 0, 'effarante': 0, 'mi-close': 0, 'figurative': 7, 'suzeraine': 0, 'pleurante': 0, 'entrante': 0, 'graisseuse': 9, 'fugueuse': 2, 'nucale': 3, 'négrillonne': 4, 'réconciliatrice': 1, 'intersyndicale': 3, 'birmane': 0, 'autotractée': 0, 'bactérienne': 4, 'amaigrissante': 0, 'résinière': 6, 'rasante': 0, 'phonocaptrice': 1, 'rétrécissante': 0, 'réacquise': 0, 'coxo-fémorale': 3, 'accédante': 0, 'vicomtale': 3, 'coopératrice': 1, 'munichoise': 0, 'couillonne': 4, 'vietnamienne': 4, 'tribunitienne': 4, 'engainante': 0, 'cramoisie': 0, 'pélasgienne': 4, 'intermittente': 0, 'lapone': 0, 'halogénée': 0, 'locale': 3, 'surmultipliée': 0, 'éleveuse': 2, 'survive': 7, 'obséquieuse': 9, 'pythagoricienne': 4, 'épousée': 0, 'rougeaude': 0, 'joaillière': 6, 'domaniale': 3, 'ourse': 0, 'tensorielle': 4, 'détaillante': 0, 'néocomienne': 4, 'frondeuse': 2, 'pataude': 0, 'prompte': 0, 'téléconseillère': 6, 'galoisienne': 4, 'sérielle': 4, 'favorisante': 0, 'rotulienne': 4, 'disculpée': 0, 'transpositrice': 1, 'papelarde': 0, 'développementale': 3, 'orchestrale': 3, 'trichinée': 0, 'diphasée': 0, 'louis-philipparde': 0, 'claquante': 0, 'interreligieuse': 9, 'crocodilienne': 4, 'urétérale': 3, 'ultra-violette': 4, 'acharnée': 0, 'contuse': 0, 'farinière': 6, 'quinte': 0, 'conférencière': 6, 'pouponnée': 0, 'inabritée': 0, 'nidificatrice': 1, 'motivante': 0, 'basochienne': 4, 'désœuvrée': 0, 'vipérine': 0, 'terrienne': 4, 'bisaïeule': 0, 'champenoise': 0, 'anesthésiée': 0, 'champée': 0, 'adsorbante': 0, 'oisive': 7, 'coutelière': 6, 'booléenne': 4, 'discontinue': 0, 'citernière': 6, 'consciencieuse': 9, 'redistributrice': 1, 'éclopée': 0, 'cybermilitante': 0, 'incrémentielle': 4, 'réverbérante': 0, 'procédurale': 3, 'préimprimée': 0, 'néoformée': 0, 'involucrée': 0, 'exécutrice': 1, 'redondante': 0, 'improvisatrice': 1, 'chaldéenne': 4, 'émoustillante': 0, 'ardennaise': 0, 'octogonale': 3, 'diplômante': 0, 'violatrice': 1, 'recolleuse': 2, 'colonisatrice': 1, 'rétroactive': 7, 'terraquée': 0, 'suprasegmentale': 3, 'éplorée': 0, 'exorbitée': 0, 'alimentatrice': 1, 'ruisselante': 0, 'valseuse': 2, 'compétente': 0, 'intacte': 0, 'bouffante': 0, 'améliorante': 0, 'monovariante': 0, 'malencontreuse': 9, 'convaincue': 0, 'biparentale': 3, 'litigieuse': 9, 'censoriale': 3, 'recrue': 0, 'effleurie': 0, 'dispensatrice': 1, 'citadine': 0, 'algocultrice': 1, 'intoxicante': 0, 'désobligeante': 0, 'franco-indonésienne': 4, 'sino-tibétaine': 0, 'africaine': 0, 'bahaïe': 0, 'téléassistante': 0, 'recto-sigmoïdienne': 4, 'tordante': 0, 'défibreuse': 2, 'monocristalline': 0, 'constitutive': 7, 'égypto-américaine': 0, 'marquise': 0, 'cambrienne': 4, 'dentale': 3, 'convoyeuse': 2, 'auto-réalisatrice': 1, 'raconteuse': 2, 'consomptive': 7, 'pluriannuelle': 4, 'maquignonne': 4, 'franco-autrichienne': 4, 'tourtelée': 0, 'malavisée': 0, 'adjutrice': 1, 'léopardée': 0, 'vindicative': 7, 'observante': 0, 'multinomiale': 3, 'manichéenne': 4, 'persiffleuse': 2, 'commandante': 0, 'fumée': 0, 'rabattue': 0, 'franco-québécoise': 0, 'élaboratrice': 1, 'théâtrale': 3, 'commerçante': 0, 'déprimante': 0, 'occlusive': 7, 'graveleuse': 9, 'staminale': 3, 'historiale': 3, 'interruptive': 7, 'grenadière': 6, 'oppositive': 7, 'disposante': 0, 'endurante': 0, 'thermohaline': 0, 'mésopotamienne': 4, 'vicomtesse': 16, 'voltigeuse': 2, 'campagnarde': 0, 'almandine': 0, 'marmitonne': 4, 'politico-sociale': 3, 'correcte': 0, 'miroitante': 0, 'ukrainienne': 4, 'mongole': 0, 'tortue': 0, 'lécheuse': 2, 'chasséenne': 4, 'scieuse': 2, 'digitée': 0, 'froissante': 0, 'outrecuidante': 0, 'slavisante': 0, 'paraveineuse': 9, 'érugineuse': 9, 'politicarde': 0, 'forestière': 6, 'covalente': 0, 'professionnelle': 4, 'chuintante': 0, 'antivénéneuse': 9, 'soiffarde': 0, 'pyrotechnicienne': 4, 'amnistiante': 0, 'évaluative': 7, 'équidimensionnelle': 4, 'antilibérale': 3, 'préœdipienne': 4, 'sanctificatrice': 1, 'dévoyée': 0, 'irréfléchie': 0, 'inchangée': 0, 'saburrale': 3, 'chleue': 0, 'lettonne': 4, 'répondante': 0, 'héraultaise': 0, 'lésionnelle': 4, 'affameuse': 2, 'lauréate': 0, 'jeûneuse': 2, 'sclérale': 3, 'nauséabonde': 0, 'grimaçante': 0, 'démultiplicatrice': 1, 'embauchée': 0, 'oblongue': 4, 'discriminante': 0, 'bobinière': 6, 'radionavigante': 0, 'ramendeuse': 2, 'pierreuse': 9, 'pileuse': 9, 'maltraitante': 0, 'tiqueuse': 2, 'soupirante': 0, 'caulescente': 0, 'rémanente': 0, 'galicienne': 4, 'hypothéticodéductive': 7, 'bi-dimensionnelle': 4, 'concrète': 25, 'savonneuse': 9, 'ougandaise': 0, 'porcine': 0, 'protéagineuse': 9, 'antitussive': 7, 'glabrescente': 0, 'azuréenne': 4, 'récessive': 7, 'sommeillante': 0, 'coagulatrice': 1, 'chatoyante': 0, 'componentielle': 4, 'paléo-environnementale': 3, 'autostoppeuse': 2, 'tourbeuse': 9, 'interpellée': 0, 'pseudoriemannienne': 4, 'majestueuse': 9, 'chasseuse': 2, 'culminante': 0, 'cessante': 0, 'épiscopale': 3, 'locrienne': 4, 'lacérante': 0, 'tigresse': 16, 'capricieuse': 9, 'détrousseuse': 2, 'loyale': 3, 'révoltée': 0, 'égrisée': 0, 'piocheuse': 2, 'citronnée': 0, 'fécale': 3, 'décisive': 7, 'ismaïlienne': 4, 'fermière': 6, 'bûcheuse': 2, 'croisetée': 0, 'catcheuse': 2, 'goménolée': 0, 'maléficieuse': 9, 'inspirante': 0, 'alliée': 0, 'inscrivante': 0, 'boudeuse': 2, 'égyptienne': 4, 'dévideuse': 2, 'cérumineuse': 9, 'vernale': 3, 'dorso-ventrale': 3, 'afro-cubaine': 0, 'indienne': 4, 'souricière': 6, 'planteuse': 2, 'volitive': 7, 'fistuleuse': 9, 'tapageuse': 2, 'blondine': 0, 'convaincante': 0, 'lettreuse': 2, 'binationale': 3, 'imparipennée': 0, 'dénigrante': 0, 'transcendante': 0, 'épargnante': 0, 'bivalente': 0, 'goutteuse': 9, 'institutionnelle': 4, 'cabochée': 0, 'culottière': 6, 'pseudo-membraneuse': 9, 'antisportive': 7, 'tutoyeuse': 2, 'barbelée': 0, 'testatrice': 1, 'efférente': 0, 'racinienne': 4, 'territoriale': 3, 'formelle': 4, 'lombo-sacrée': 0, 'réémergente': 0, 'monstrueuse': 9, 'intolérante': 0, 'réitérante': 0, 'dissidente': 0, 'régulière': 6, 'emprunteuse': 2, 'guichetière': 6, 'aldine': 0, 'compétitrice': 1, 'pouilleuse': 9, 'déménageuse': 2, 'moutonnante': 0, 'incontrôlée': 0, 'courrière': 6, 'nominative': 7, 'transporteuse': 2, 'commémorative': 7, 'boitillante': 0, 'précontrainte': 0, 'égressive': 7, 'augurale': 3, 'méfiante': 0, 'uropygienne': 4, 'encombrante': 0, 'pestilente': 0, 'redondée': 0, 'spécieuse': 9, 'souterraine': 0, 'fougueuse': 9, 'audio-visuelle': 4, 'franco-argentine': 0, 'inhibitrice': 1, 'constructrice': 1, 'dentofaciale': 3, 'munificente': 0, 'relaxée': 0, 'néo-romane': 0, 'croustillante': 0, 'maritale': 3, 'agitante': 0, 'dissonante': 0, 'tombale': 3, 'poussine': 0, 'garçonne': 4, 'coorbitale': 3, 'ennuyeuse': 9, 'défoliatrice': 1, 'multimodale': 3, 'nigaude': 0, 'récapitulative': 7, 'croissante': 0, 'lunée': 0, 'vergogneuse': 9, 'incubatrice': 1, 'carotidienne': 4, 'aspiratrice': 1, 'théodosienne': 4, 'convolutée': 0, 'pâlissante': 0, 'aéroréfrigérante': 0, 'spatiale': 3, 'parenthésée': 0, 'ondulante': 0, 'brochante': 0, 'salivante': 0, 'convalescente': 0, 'architravée': 0, 'engrêlée': 0, 'prémontrée': 0, 'câline': 0, 'shipchandleuse': 2, 'amareyeuse': 2, 'floricultrice': 1, 'caractérielle': 4, 'manganeuse': 9, 'diverse': 0, 'baladeuse': 2, 'cinglante': 0, 'mistonne': 4, 'dévastatrice': 1, 'déroutante': 0, 'oléoprotéagineuse': 9, 'informatrice': 1, 'saccareuse': 9, 'façonnière': 6, 'coaccusée': 0, 'dysfonctionnelle': 4, 'moustérienne': 4, 'confessionnelle': 4, 'écouteuse': 2, 'huissière': 6, 'covariante': 0, 'franco-algérienne': 4, 'médiale': 3, 'ecclésiale': 3, 'décélérée': 0, 'cocue': 0, 'repreneuse': 2, 'graduelle': 4, 'polyédrale': 3, 'étalonnière': 6, 'adolescente': 0, 'coéquipière': 6, 'sulpicienne': 4, 'affluente': 0, 'annulative': 7, 'débarrasseuse': 2, 'photocopieuse': 2, 'moucheuse': 2, 'beauceronne': 4, 'tremblotante': 0, 'beethovénienne': 4, 'psycho-sensori-motrice': 1, 'différente': 0, 'phosphorée': 0, 'nutricière': 6, 'virulente': 0, 'aggravante': 0, 'inclusive': 7, 'expansée': 0, 'bidonnante': 0, 'céréalicultrice': 1, 'prétendante': 0, 'franco-colombienne': 4, 'paramédicale': 3, 'bikeuse': 2, 'anfractueuse': 9, 'fichue': 0, 'déponente': 0, 'cumularde': 0, 'péléenne': 4, 'descendante': 0, 'constrictive': 7, 'franco-albanaise': 0, 'faignante': 0, 'gardeuse': 2, 'manouvrière': 6, 'crétoise': 0, 'synclinale': 3, 'promotionnelle': 4, 'cyclopéenne': 4, 'tullière': 6, 'zététicienne': 4, 'picarde': 0, 'solière': 6, 'asphalteuse': 2, 'humiliante': 0, 'incivile': 0, 'charmeuse': 2, 'componée': 0, 'rénale': 3, 'rafraichie': 0, 'cellophanée': 0, 'séquestrée': 0, 'striduleuse': 9, 'abaissante': 0, 'brosseuse': 2, 'paraphernale': 3, 'séquentielle': 4, 'continente': 0, 'nommée': 0, 'ondine': 0, 'astacicultrice': 1, 'occitanienne': 4, 'brumeuse': 9, 'myrmidone': 0, 'polygonale': 3, 'sensuelle': 4, 'arbalétrière': 6, 'maxillo-faciale': 3, 'cartonnière': 6, 'raisonnante': 0, 'trottante': 0, 'lusitanienne': 4, 'bouffonne': 4, 'colporteuse': 2, 'soldate': 0, 'pétiolée': 0, 'plongeante': 0, 'adversative': 7, 'réprouvée': 0, 'bathyale': 3, 'marronne': 4, 'ladine': 0, 'subjonctive': 7, 'appréciatrice': 1, 'souffrante': 0, 'extorqueuse': 2, 'subordonnée': 0, 'liftière': 6, 'angoissante': 0, 'handicapante': 0, 'approchante': 0, 'déhiscente': 0, 'zélée': 0, 'négligente': 0, 'éblouissante': 0, 'tubarde': 0, 'amorale': 3, 'griotte': 4, 'bisimpliciale': 3, 'pseudo-riemannienne': 4, 'écœurante': 0, 'diffuse': 0, 'hollywoodienne': 4, 'contrélectromotrice': 1, 'raboteuse': 9, 'interprétative': 7, 'beugleuse': 2, 'inusuelle': 4, 'remueuse': 2, 'proeuropéenne': 4, 'polylobée': 0, 'échéante': 0, 'mutine': 0, 'recarburée': 0, 'libanaise': 0, 'prostituée': 0, 'intrigante': 0, 'sectorielle': 4, 'monumentale': 3, 'enlumineuse': 2, 'colleuse': 2, 'sculpturale': 3, 'angineuse': 9, 'languedocienne': 4, 'korrigane': 0, 'sondeuse': 2, 'censuelle': 4, 'dictatrice': 1, 'shampooineuse': 2, 'poussive': 7, 'infecte': 0, 'exempte': 0, 'puncheuse': 2, 'écumante': 0, 'socio-culturelle': 4, 'ogivale': 3, 'ingressive': 7, 'rogneuse': 2, 'nourrissante': 0, 'suborneuse': 2, 'extrafine': 0, 'ilotière': 6, 'pédocriminelle': 4, 'serpigineuse': 9, 'niçoise': 0, 'souffreteuse': 9, 'préparatrice': 1, 'pharyngale': 3, 'golfeuse': 2, 'annale': 3, 'subsistante': 0, 'interorbitale': 3, 'prurigineuse': 9, 'discordante': 0, 'embryonnée': 0, 'préteuse': 2, 'cadastrale': 3, 'expérimentatrice': 1, 'gaffeuse': 2, 'buandière': 6, 'chaînetière': 6, 'norroise': 0, 'primo-accédante': 0, 'lugeuse': 2, 'punisseuse': 2, 'tourière': 6, 'manducatrice': 1, 'susmentionnée': 0, 'mésenchymateuse': 9, 'oublieuse': 9, 'codétentrice': 1, 'interstitielle': 4, 'fêtarde': 0, 'négro-africaine': 0, 'urétrale': 3, 'gazeuse': 9, 'inexistante': 0, 'cheloue': 0, 'endêvée': 0, 'latine': 0, 'continuatrice': 1, 'consommatrice': 1, 'papuleuse': 9, 'centralienne': 4, 'belgo-congolaise': 0, 'drainante': 0, 'regardeuse': 2, 'subversive': 7, 'affronteuse': 2, 'insinuative': 7, 'justificatrice': 1, 'latitudinale': 3, 'parentale': 3, 'diététicienne': 4, 'décemvirale': 3, 'poursuivante': 0, 'saboteuse': 2, 'piaffante': 0, 'clapoteuse': 9, 'gonzesse': 16, 'opprimante': 0, 'caprine': 0, 'innocentée': 0, 'désidérative': 7, 'informulée': 0, 'fédératrice': 1, 'casquettière': 6, 'pétrisseuse': 2, 'bantoue': 0, 'mignonne': 4, 'succédanée': 0, 'romande': 0, 'magnétisante': 0, 'sud-coréenne': 4, 'démonteuse': 2, 'olfactive': 7, 'récriminée': 0, 'épatante': 0, 'aiguilleteuse': 2, 'blette': 4, 'béante': 0, 'franco-bolivienne': 4, 'excrémentielle': 4, 'bouquineuse': 2, 'ramollissante': 0, 'mildiousée': 0, 'rouleuse': 2, 'fourbue': 0, 'verbale': 3, 'néozélandaise': 0, 'malchanceuse': 9, 'active': 7, 'semi-chenillée': 0, 'vasoconstrictrice': 1, 'partante': 0, 'finassière': 6, 'biréfringente': 0, 'crémeuse': 9, 'anesthésiante': 0, 'feue': 0, 'canadienne': 4, 'boursicoteuse': 2, 'mélangeante': 0, 'expropriante': 0, 'chiante': 0, 'teigneuse': 9, 'tourmenteuse': 2, 'tonale': 0, 'volante': 0, 'relevante': 0, 'sénestrée': 0, 'limeuse': 2, 'verbeuse': 9, 'chaînière': 6, 'incitante': 0, 'rabâcheuse': 2, 'tourbillonnante': 0, 'révérencielle': 4, 'extractive': 7, 'feuillue': 0, 'naine': 0, 'racketteuse': 2, 'ampoulée': 0, 'ensellée': 0, 'nonpareille': 4, 'erronée': 0, 'contreproductive': 7, 'dévoreuse': 2, 'reconstituante': 0, 'pignorative': 7, 'campeuse': 2, 'appréhensive': 7, 'jugeuse': 2, 'barbichue': 0, 'jaillissante': 0, 'électronicienne': 4, 'effilocheuse': 2, 'rougeoyante': 0, 'renforçante': 0, 'amplective': 7, 'post-prandiale': 3, 'vieillotte': 4, 'soudante': 0, 'sabotière': 6, 'ionienne': 4, 'hibernante': 0, 'avionneuse': 2, 'gardiane': 0, 'agioteuse': 2, 'ultra-marine': 0, 'sustentatrice': 1, 'staminée': 0, 'archiconnue': 0, 'multifactorielle': 4, 'espionne': 4, 'satineuse': 2, 'komsomole': 0, 'libournaise': 0, 'conductive': 7, 'dominicale': 3, 'buccale': 3, 'décente': 0, 'miséreuse': 9, 'ouzbèke': 29, 'rédactionnelle': 4, 'lavandière': 6, 'calomniée': 0, 'idéale': 3, 'croulante': 0, 'arpenteuse': 2, 'manuéline': 0, 'variétale': 3, 'montreuse': 2, 'colorectale': 3, 'saumonée': 0, 'afficheuse': 2, 'rentoileuse': 2, 'lumineuse': 9, 'simplificatrice': 1, 'anévrismale': 3, 'affirmative': 7, 'irrigatrice': 1, 'abandonnatrice': 1, 'étudiante': 0, 'scapulohumérale': 3, 'dreyfusarde': 0, 'élastiquée': 0, 'soulonne': 4, 'cagoularde': 0, 'aoutienne': 4, 'totalisatrice': 1, 'asexuée': 0, 'malgracieuse': 9, 'performative': 7, 'creusoise': 0, 'démone': 0, 'mormone': 0, 'cauteleuse': 9, 'admirative': 7, 'expirante': 0, 'turbulente': 0, 'égalisatrice': 1, 'azotée': 0, 'forcenée': 0, 'progressive': 7, 'releveuse': 2, 'cadette': 4, 'allante': 0, 'campinoise': 0, 'possessionnelle': 4, 'arithméticienne': 4, 'fusionnelle': 4, 'triviale': 3, 'lessiveuse': 2, 'tétravalente': 0, 'répulsive': 7, 'roulante': 0, 'timoraise': 0, 'pilo-sébacée': 0, 'plastiqueuse': 2, 'interpellante': 0, 'bretonne': 4, 'minorante': 0, 'mantelée': 0, 'astronauticienne': 4, 'plurinationale': 3, 'succincte': 0, 'mouleuse': 2, 'russo-japonaise': 0, 'computationnelle': 4, 'ponceuse': 9, 'graniteuse': 9, 'radieuse': 9, 'tangente': 0, 'suiveuse': 2, 'torturée': 0, 'tannante': 0, 'bluffeuse': 2, 'déprimée': 0, 'multigraduée': 0, 'vertueuse': 9, 'écureuse': 2, 'contraceptive': 7, 'arsenicale': 3, 'décongestive': 7, 'incompétente': 0, 'dilapidatrice': 1, 'polonaise': 0, 'muséale': 3, 'franco-suédoise': 0, 'microlocalisée': 0, 'doctorante': 0, 'empaqueteuse': 2, 'débarbante': 0, 'inhibée': 0, 'labiée': 0, 'cruentée': 0, 'chargeuse': 2, 'entéro-rénale': 3, 'décurrente': 0, 'poplitée': 0, 'monoskieuse': 2, 'conviviale': 3, 'précolombienne': 4, 'fricative': 7, 'venante': 0, 'philippienne': 4, 'participante': 0, 'rectrice': 1, 'portière': 6, 'préfète': 25, 'sacerdotale': 3, 'abondante': 0, 'perturbante': 0, 'hyperglycémiante': 0, 'guerrière': 6, 'expropriée': 0, 'outsideuse': 2, 'rêvasseuse': 2, 'stagnante': 0, 'simonienne': 4, 'cuiseuse': 2, 'cauchemardeuse': 9, 'sanguinolente': 0, 'pistillée': 0, 'soulote': 0, 'mahousse': 4, 'innovante': 0, 'plurale': 3, 'envoutante': 0, 'vivifiante': 0, 'miauleuse': 2, 'cornière': 6, 'boulinière': 6, 'autoadhésive': 7, 'subjacente': 0, 'récupératrice': 1, 'damasquineuse': 2, 'tontinière': 6, 'centrale': 3, 'croyante': 0, 'réviseuse': 2, 'vasarde': 0, 'convolutive': 7, 'épicière': 6, 'accueillante': 0, 'graissante': 0, 'castillane': 0, 'réchauffante': 0, 'poitevine': 0, 'menstruelle': 4, 'matoise': 0, 'coagulante': 0, 'télévisuelle': 4, 'tétragonale': 3, 'gentillette': 4, 'harangueuse': 2, 'brouteuse': 2, 'iléale': 3, 'séculière': 6, 'exagératrice': 1, 'sous-maîtresse': 16, 'prépotente': 0, 'baiseuse': 2, 'inférentielle': 4, 'paludéenne': 4, 'transsibérienne': 4, 'chineuse': 2, 'siffleuse': 2, 'cortico-surrénale': 3, 'grand-ducale': 3, 'bisexuée': 0, 'auto-équilibrante': 0, 'séronégative': 7, 'spongieuse': 9, 'austro-allemande': 0, 'coureuse': 2, 'œsophagienne': 4, 'significatrice': 1, 'caribéenne': 4, 'rejointoyeuse': 2, 'notariale': 3, 'chômeuse': 2, 'rewriteuse': 2, 'décapante': 0, 'cæcale': 3, 'médusante': 0, 'usante': 0, 'essuyeuse': 2, 'métisse': 4, 'culpabilisante': 0, 'promeneuse': 2, 'rétrovirale': 3, 'obsédante': 0, 'préardennaise': 0, 'jacobienne': 4, 'autorisatrice': 1, 'bafouilleuse': 2, 'interjective': 7, 'deviseuse': 2, 'tricheuse': 2, 'endiamantée': 0, 'suffocante': 0, 'illative': 7, 'opérante': 0, 'pharamineuse': 9, 'basanée': 0, 'glaçante': 0, 'westphalienne': 4, 'éliminatrice': 1, 'paquetée': 0, 'franco-danoise': 0, 'pékinoise': 0, 'recouvrante': 0, 'tourneuse': 2, 'ravisseuse': 2, 'malthusienne': 4, 'flabellée': 0, 'corsetière': 6, 'démarqueuse': 2, 'capitée': 0, 'filandreuse': 9, 'catarrhale': 3, 'madrée': 0, 'abottée': 0, 'immatérielle': 4, 'épicrânienne': 4, 'portugaise': 0, 'vassale': 3, 'créditrice': 1, 'téléopératrice': 1, 'réversale': 3, 'cézannienne': 4, 'inspirée': 0, 'cuivreuse': 9, 'crurale': 3, 'miteuse': 9, 'natale': 0, 'guivrée': 0, 'alcalinisante': 0, 'orwellienne': 4, 'suivante': 0, 'intra-utérine': 0, 'marieuse': 2, 'embrigadée': 0, 'cicatrisante': 0, 'ininterrompue': 0, 'orientale': 3, 'linéale': 3, 'moutonnière': 6, 'tarnaise': 0, 'néoconservatrice': 1, 'tibiale': 3, 'productive': 7, 'américano-turque': 13, 'gratifiante': 0, 'sacro-sainte': 0, 'marseillaise': 0, 'télétravailleuse': 2, 'réflective': 7, 'adjudicative': 7, 'impérieuse': 9, 'impermanente': 0, 'duelle': 4, 'receleuse': 2, 'esthéticienne': 4, 'trépidante': 0, 'confessante': 0, 'khâgneuse': 9, 'menine': 0, 'polytransfusée': 0, 'hyperfocale': 3, 'équilibreuse': 2, 'concourante': 0, 'flagellatrice': 1, 'explicative': 7, 'sélacienne': 4, 'biomédicale': 3, 'talibane': 0, 'néphridienne': 4, 'abdominale': 3, 'civilisationnelle': 4, 'contre-manifestante': 0, 'américano-mexicaine': 0, 'épigée': 0, 'raseuse': 2, 'nullarde': 0, 'effectrice': 1, 'artificielle': 4, 'laryngée': 0, 'désaltérante': 0, 'lainière': 6, 'microgrenue': 0, 'musicienne': 4, 'intimidée': 0, 'séductrice': 1, 'géodésienne': 4, 'pétroleuse': 2, 'barytée': 0, 'basale': 3, 'gallicane': 0, 'exploitante': 0, 'énonciatrice': 1, 'consensuelle': 4, 'interprétante': 0, 'enduiseuse': 2, 'sédative': 7, 'trébuchante': 0, 'sablière': 6, 'embarquée': 0, 'chtarbée': 0, 'anatolienne': 4, 'atterrante': 0, 'salvadorienne': 4, 'outrancière': 6, 'abjecte': 0, 'insomnieuse': 9, 'bonnarde': 0, 'traficoteuse': 2, 'paranormale': 3, 'anxieuse': 9, 'patrimoniale': 3, 'occidentale': 3, 'absidiale': 3, 'lombarde': 0, 'marbrière': 6, 'chaude': 0, 'synanthérée': 0, 'cintreuse': 2, 'bienfaisante': 0, 'coassociée': 0, 'inexpressive': 7, 'paulicienne': 4, 'oasienne': 4, 'ronde': 0, 'dégénérée': 0, 'ducale': 3, 'pellagreuse': 9, 'bivaluée': 0, 'gobeuse': 2, 'opérationnelle': 4, 'moribonde': 0, 'discompteuse': 2, 'fiérote': 0, 'isolée': 0, 'pourprine': 0, 'boguée': 0, 'onduleuse': 9, 'roselière': 6, 'tabacultrice': 1, 'fangeuse': 9, 'quadrilobée': 0, 'impardonnée': 0, 'conditionneuse': 2, 'cingalaise': 0, 'démaquillante': 0, 'sulfureuse': 9, 'assaillie': 0, 'incorporatrice': 1, 'assommée': 0, 'immune': 0, 'sergente': 0, 'hispanisante': 0, 'coquilleuse': 2, 'indépendante': 0, 'directrice': 1, 'vergée': 0, 'prétranchée': 0, 'menuisière': 6, 'panaméenne': 4, 'sublétale': 3, 'fruiticultrice': 1, 'new-yorkaise': 0, 'effrontée': 0, 'intégrée': 0, 'comateuse': 9, 'caporale': 3, 'confuse': 0, 'cumulative': 7, 'canine': 0, 'mussive': 7, 'assiégeante': 0, 'fêlée': 0, 'boulotte': 4, 'chemisière': 6, 'préservatrice': 1, 'laiteuse': 9, 'récréationnelle': 4, 'intempestive': 7, 'camionneuse': 2, 'intramodale': 3, 'congrue': 0, 'chercheuse': 2, 'revendicatrice': 1, 'départementale': 3, 'intertropicale': 3, 'vice-rectrice': 1, 'flamingante': 0, 'morte': 0, 'multiplicatrice': 1, 'rôdeuse': 2, 'maladive': 7, 'franco-roumaine': 0, 'cristallisante': 0, 'vaporeuse': 9, 'scoute': 0, 'inversive': 7, 'synagogale': 3, 'pythienne': 4, 'isoclinale': 3, 'paléoenvironnementale': 3, 'ordurière': 6, 'terreuse': 9, 'acceptante': 0, 'décalvante': 0, 'équipotentielle': 4, 'bâloise': 0, 'andorrane': 0, 'insermentée': 0, 'abélianisée': 0, 'immémoriale': 3, 'informationnelle': 4, 'brûlée': 0, 'ondoyante': 0, 'légumineuse': 9, 'hitlérienne': 4, 'algale': 3, 'incréée': 0, 'piaffeuse': 2, 'fraiche': 26, 'narquoise': 0, 'trieuse': 2, 'frôleuse': 2, 'médiaplanneuse': 2, 'niqueuse': 2, 'conventuelle': 4, 'cémenteuse': 9, 'souscriptrice': 1, 'écaillère': 6, 'tropézienne': 4, 'oxycarbonée': 0, 'nitrificatrice': 1, 'fidélisante': 0, 'inouïe': 0, 'rhéto-romane': 0, 'jargonneuse': 9, 'darwinienne': 4, 'franciscaine': 0, 'sabreuse': 2, 'inélégante': 0, 'triomphatrice': 1, 'exultante': 0, 'vigneronne': 4, 'périe': 0, 'épicurienne': 4, 'fruitée': 0, 'navigante': 0, 'extrême-orientale': 3, 'dédoubleuse': 2, 'sous-frutescente': 0, 'vice-première': 6, 'bossue': 0, 'récréative': 7, 'polyamoureuse': 2, 'intéroceptive': 7, 'finale': 0, 'bio-indicatrice': 1, 'agréeuse': 2, 'visuelle': 4, 'arachnoïdienne': 4, 'papale': 3, 'langagière': 6, 'prépositive': 7, 'indifférenciée': 0, 'dénicheuse': 2, 'architecturale': 3, 'drue': 0, 'florissante': 0, 'louangeuse': 2, 'transpadane': 0, 'zambienne': 4, 'tibéto-birmane': 0, 'dartreuse': 9, 'gravatière': 6, 'proéminente': 0, 'uniformisante': 0, 'affouagère': 6, 'capverdienne': 4, 'emballante': 0, 'dormeuse': 2, 'épistolière': 6, 'interactive': 7, 'impétueuse': 9, 'confiante': 0, 'extra-légale': 3, 'insatisfaite': 0, 'proudhonienne': 4, 'fornicatrice': 1, 'trisectrice': 1, 'parchemineuse': 9, 'acéricultrice': 1, 'chauffeuse': 2, 'inimaginée': 0, 'prégnante': 0, 'ragoutante': 0, 'millésimale': 3, 'reconstructive': 7, 'scoriacée': 0, 'rétractrice': 1, 'carrée': 0, 'inattendue': 0, 'palatine': 0, 'riante': 0, 'faïencière': 6, 'transalpine': 0, 'érythémateuse': 9, 'tarée': 0, 'rassasiante': 0, 'chafouine': 0, 'saline': 0, 'courtisane': 0, 'jongleuse': 2, 'spécificatrice': 1, 'optimale': 3, 'aéroportée': 0, 'photorésistante': 0, 'rabroueuse': 2, 'ricaine': 0, 'pharmacodépendante': 0, 'trigéminée': 0, 'contrattaquante': 0, 'gironde': 0, 'évanescente': 0, 'marguillière': 6, 'nautonière': 6, 'repentante': 0, 'paléochrétienne': 4, 'horripilante': 0, 'crouteuse': 9, 'antiacarienne': 4, 'extra-territoriale': 3, 'dealeuse': 2, 'maternelle': 4, 'titularisée': 0, 'indiscutée': 0, 'éditrice': 1, 'ostréicultrice': 1, 'fâcheuse': 9, 'coquillière': 6, 'traineuse': 2, 'postindustrielle': 4, 'rapiate': 0, 'salmonicultrice': 1, 'colleteuse': 2, 'surinamaise': 0, 'lactée': 0, 'antidérapante': 0, 'parkinsonienne': 4, 'fabulatrice': 1, 'judicieuse': 9, 'planante': 0, 'saponacée': 0, 'tupie': 0, 'hindoustanie': 0, 'retordeuse': 2, 'sphéroïdale': 3, 'villeuse': 9, 'foulonnière': 6, 'factitive': 7, 'imitatrice': 1, 'bistrotière': 6, 'préprogrammée': 0, 'échantillonneuse': 2, 'étourdie': 0, 'propagatrice': 1, 'infinie': 0, 'concise': 0, 'claudicante': 0, 'mucilagineuse': 9, 'privative': 7, 'encline': 0, 'générative': 7, 'genevoise': 0, 'hellénisante': 0, 'libyenne': 4, 'maïeuticienne': 4, 'psychoactive': 7, 'prénatale': 0, 'saint-cyrienne': 4, 'slavonne': 4, 'vérificative': 7, 'parcimonieuse': 9, 'grignoteuse': 2, 'ensommeillée': 0, 'pleureuse': 2, 'événementielle': 4, 'coursonne': 4, 'modélisatrice': 1, 'kosovare': 0, 'peureuse': 9, 'rouspéteuse': 2, 'fontenière': 6, 'morbihannaise': 0, 'inamicale': 3, 'prétentieuse': 9, 'défensive': 7, 'couenneuse': 9, 'retardatrice': 1, 'fractionnelle': 4, 'onusienne': 4, 'industrielle': 4, 'piquante': 0, 'baudelairienne': 4, 'inhumée': 0, 'oiselière': 6, 'pistoleuse': 2, 'éreinteuse': 2, 'attributive': 7, 'contramirale': 3, 'autogérée': 0, 'paludière': 6, 'celluleuse': 9, 'surlignante': 0, 'déshydratante': 0, 'médaillée': 0, 'biinvariante': 0, 'angevine': 0, 'compulsionnelle': 4, 'motivatrice': 1, 'antiseigneuriale': 3, 'minotière': 6, 'lancéolée': 0, 'ratiocinante': 0, 'bijective': 7, 'soûlante': 0, 'sélectionneuse': 2, 'braqueuse': 2, 'coursière': 6, 'contrebandière': 6, 'compressive': 7, 'menue': 0, 'ambigüe': 12, 'envoûteuse': 2, 'tridentée': 0, 'vice-championne': 4, 'pédicellée': 0, 'trichineuse': 9, 'shogunale': 3, 'renarde': 0, 'démouleuse': 2, 'râpeuse': 9, 'végane': 0, 'centauresse': 16, 'surdouée': 0, 'hongreuse': 2, 'riemannienne': 4, 'amiantée': 0, 'moyenne': 4, 'penchante': 0, 'cartilagineuse': 9, 'cérémoniale': 0, 'larmoyeuse': 2, 'inoubliée': 0, 'hallstattienne': 4, 'diffusive': 7, 'clubbeuse': 2, 'conjugale': 3, 'dompteuse': 2, 'acheuléenne': 4, 'glougloutante': 0, 'antiinfectieuse': 9, 'médico-sportive': 7, 'extéroceptive': 7, 'concurrentielle': 4, 'ruineuse': 9, 'intersubjective': 7, 'dégustatrice': 1, 'angoissée': 0, 'provocatrice': 1, 'désabonnée': 0, 'inécoutée': 0, 'postulatrice': 1, 'chainetière': 6, 'inemployée': 0, 'cajoleuse': 2, 'cochonne': 4, 'aérospatiale': 3, 'mortaiseuse': 2, 'infractrice': 1, 'diablesse': 16, 'paniquarde': 0, 'torturante': 0, 'cossue': 0, 'planétésimale': 3, 'pitchounette': 4, 'franco-japonaise': 0, 'conclusive': 7, 'crépisseuse': 2, 'lacrymale': 3, 'baladodiffuseuse': 2, 'politico-financière': 6, 'marqueteuse': 2, 'ultra-légère': 6, 'chançarde': 0, 'autoéquilibrante': 0, 'tâtonnante': 0, 'existentielle': 4, 'tétanisante': 0, 'suppurative': 7, 'lente': 0, 'ânière': 6, 'bêlante': 0, 'présomptueuse': 9, 'cantonaise': 0, 'champignonneuse': 9, 'primoaccédante': 0, 'endocrinienne': 4, 'contemporaine': 0, 'monoclinale': 3, 'patronne': 4, 'puissante': 0, 'dauphinoise': 0, 'inconstitutionnelle': 4, 'abolitive': 7, 'kantienne': 4, 'sacramentelle': 4, 'enveloppante': 0, 'avaleuse': 2, 'lessivielle': 4, 'franco-haïtienne': 4, 'pétaradante': 0, 'magouilleuse': 2, 'doseuse': 2, 'impunie': 0, 'marine': 0, 'franco-marocaine': 0, 'tolérante': 0, 'instinctuelle': 4, 'génitrice': 1, 'excrétrice': 1, 'inquiétante': 0, 'amirale': 3, 'frisonne': 4, 'tricennale': 3, 'mosaïquée': 0, 'duodécimale': 3, 'dédaigneuse': 9, 'consolante': 0, 'cornélienne': 4, 'libéralisante': 0, 'busquée': 0, 'gênante': 0, 'crapoussine': 0, 'sondée': 0, 'engraisseuse': 2, 'française': 0, 'ouvrière': 6, 'ensileuse': 2, 'absolutive': 7, 'touchante': 0, 'géométrale': 3, 'déferlante': 0, 'franco-chilienne': 4, 'ostracée': 0, 'hélicicultrice': 1, 'supraconductrice': 1, 'médailleuse': 2, 'souahélie': 0, 'rubiconde': 0, 'édulcorante': 0, 'pochetronne': 4, 'tyrrhénienne': 4, 'entraineuse': 2, 'comtesse': 16, 'coercitive': 7, 'murale': 3, 'offensée': 0, 'détachante': 0, 'décrépite': 0, 'attirante': 0, 'israélo-américaine': 0, 'ligérienne': 4, 'gourmée': 0, 'législative': 7, 'vachère': 6, 'uropygiale': 3, 'dresseuse': 2, 'effractive': 7, 'psychologisante': 0, 'navigatrice': 1, 'scarieuse': 9, 'afflictive': 7, 'enjambée': 0, 'éburnéenne': 4, 'évaginée': 0, 'pollicitante': 0, 'contrarotative': 7, 'bien-pensante': 0, 'limitative': 7, 'nettoyeuse': 2, 'tufière': 6, 'patronale': 3, 'sibylline': 0, 'foraine': 0, 'chatte': 4, 'hiératisée': 0, 'sacrale': 3, 'grenadine': 0, 'aguicheuse': 2, 'sexagésimale': 3, 'néo-libérale': 3, 'grinçante': 0, 'tenancière': 6, 'boulonnière': 6, 'adjective': 7, 'créative': 7, 'mollette': 4, 'incestueuse': 9, 'murmurante': 0, 'linguale': 3, 'podcasteuse': 2, 'inadéquate': 0, 'transactionnelle': 4, 'ambassadrice': 1, 'aromatisante': 0, 'serveuse': 2, 'carrossière': 6, 'procréative': 7, 'fine': 0, 'chleuhe': 0, 'chenillée': 0, 'orthonormée': 0, 'travestie': 0, 'coruscante': 0, 'dysendocrinienne': 4, 'digitale': 3, 'confraternelle': 4, 'coïncidente': 0, 'stratificationnelle': 4, 'appareilleuse': 2, 'printanière': 6, 'antinationale': 3, 'vaillante': 0, 'mi-partie': 0, 'rubigineuse': 9, 'reloue': 0, 'impensée': 0, 'roumie': 0, 'sauve': 7, 'précuite': 0, 'prévôtale': 3, 'clabaudeuse': 2, 'saisonnale': 3, 'accrescente': 0, 'rutilante': 0, 'transgénérationnelle': 4, 'revive': 7, 'squameuse': 9, 'franco-québecoise': 0, 'précise': 0, 'pédonculée': 0, 'administratrice': 1, 'drupacée': 0, 'nord-africaine': 0, 'équipée': 0, 'estuarienne': 4, 'recrudescente': 0, 'écervelée': 0, 'spéculative': 7, 'inexplorée': 0, 'algonkine': 0, 'courtaude': 0, 'isolante': 0, 'intertidale': 3, 'valvée': 0, 'indignée': 0, 'défenseure': 0, 'précieuse': 9, 'prométhéenne': 4, 'dissolue': 0, 'gonflante': 0, 'chenue': 0, 'scrofuleuse': 9, 'prévenante': 0, 'suréminente': 0, 'anticommutative': 7, 'dauphine': 0, 'nietzschéenne': 4, 'inentamée': 0, 'innovatrice': 1, 'deutérée': 0, 'baleinière': 6, 'redoublante': 0, 'contrariante': 0, 'saoudienne': 4, 'réfléchissante': 0, 'criarde': 0, 'panarde': 0, 'languissante': 0, 'organochlorée': 0, 'dérivative': 7, 'hagarde': 0, 'dérivante': 0, 'racoleuse': 2, 'pompéienne': 4, 'jaugeuse': 2, 'turbosoufflante': 0, 'indésirée': 0, 'généralisatrice': 1, 'psychoéducatrice': 1, 'continue': 0, 'magnétomotrice': 1, 'javanaise': 0, 'hypertendue': 0, 'décroissante': 0, 'mularde': 0, 'largueuse': 2, 'auto-adjointe': 0, 'affidée': 0, 'excommuniée': 0, 'griffue': 0, 'péquenaude': 0, 'discutailleuse': 2, 'stéroïdienne': 4, 'chanvrière': 6, 'auto-entrepreneuse': 2, 'artisanale': 3, 'gestationnelle': 4, 'croûteuse': 9, 'pollueuse': 2, 'caritative': 7, 'adiposogénitale': 3, 'mortelle': 4, 'collectionneuse': 2, 'anticléricale': 3, 'bucco-génitale': 3, 'évacuatrice': 1, 'langoustière': 6, 'stoloniale': 3, 'rejetonne': 4, 'sursaturante': 0, 'multidimensionnelle': 4, 'liégeoise': 0, 'vermeille': 4, 'noceuse': 2, 'débroussailleuse': 2, 'cogneuse': 2, 'sénescente': 0, 'présanctifiée': 0, 'filtreuse': 2, 'tagueuse': 2, 'thermale': 3, 'dégénérescente': 0, 'prenante': 0, 'étiqueteuse': 2, 'panaméricaine': 0, 'bangladaise': 0, 'révoltante': 0, 'aiguiseuse': 2, 'houlomotrice': 1, 'agonisante': 0, 'maitresse': 16, 'neurosensorielle': 4, 'incessante': 0, 'compromettante': 0, 'ramasseuse': 2, 'économico-sociale': 3, 'haletante': 0, 'rabelaisienne': 4, 'ennéagonale': 3, 'offreuse': 2, 'infante': 0, 'interastrale': 3, 'boutonnière': 6, 'branlante': 0, 'chagrine': 0, 'colombienne': 4, 'apparitrice': 1, 'tatillonne': 4, 'indélibérée': 0, 'transsexuelle': 4, 'encalminée': 0, 'conoïdale': 3, 'foireuse': 9, 'fusionnante': 0, 'environnementale': 3, 'esbroufeuse': 2, 'anglo-américaine': 0, 'surpuissante': 0, 'sacrosainte': 0, 'pseudomembraneuse': 9, 'sectionnelle': 4, 'dénotative': 7, 'bruxelloise': 0, 'capitoline': 0, 'alcalifiante': 0, 'multispectrale': 3, 'barguigneuse': 2, 'grammairienne': 4, 'récolteuse': 2, 'psycho-éducative': 7, 'détergente': 0, 'condamnée': 0, 'apprivoiseuse': 2, 'unificatrice': 1, 'insignifiante': 0, 'malodorante': 0, 'vibrationnelle': 4, 'impressive': 7, 'langoureuse': 9, 'transparente': 0, 'jaïne': 0, 'unidimensionnelle': 4, 'vectorielle': 4, 'abusive': 7, 'grimpante': 0, 'bretonnante': 0, 'transversale': 3, 'dégressive': 7, 'fixatrice': 1, 'insouciante': 0, 'jointive': 7, 'cadavéreuse': 9, 'régularisante': 0, 'babillarde': 0, 'dalmatienne': 4, 'chansonnière': 6, 'sagittale': 3, 'courtoise': 0, 'guérissante': 0, 'danseuse': 2, 'contaminatrice': 1, 'pfaffienne': 4, 'ménapienne': 4, 'malentendante': 0, 'globetrotteuse': 2, 'jeunotte': 4, 'péagère': 6, 'filonienne': 4, 'benoîte': 0, 'fistulisante': 0, 'boriquée': 0, 'approbative': 7, 'frustrée': 0, 'créatrice': 1, 'caméléonienne': 4, 'détonante': 0, 'prêteuse': 2, 'discriminative': 7, 'moulinière': 6, 'apprenante': 0, 'inaccomplie': 0, 'blessante': 0, 'privatrice': 1, 'lutécienne': 4, 'charbonneuse': 9, 'cylindreuse': 2, 'burineuse': 2, 'plébéienne': 4, 'jalouse': 9, 'irrégulière': 6, 'décennale': 3, 'briqueteuse': 2, 'âgée': 0, 'ardoisière': 6, 'vibrante': 0, 'truqueuse': 2, 'énonciative': 7, 'grouillante': 0, 'aigüe': 12, 'gastro-intestinale': 3, 'rectale': 3, 'dissipatrice': 1, 'omanaise': 0, 'démotivante': 0, 'ronronnante': 0, 'co-orbitale': 3, 'intraveineuse': 9, 'incommodante': 0, 'bitonale': 3, 'vésicale': 3, 'prédominante': 0, 'chausseuse': 2, 'opposante': 0, 'désireuse': 9, 'chuchoteuse': 2, 'griffeuse': 2, 'masquante': 0, 'récente': 0, 'farceuse': 2, 'sanscrite': 0, 'boutiquière': 6, 'mandarine': 0, 'amibienne': 4, 'disetteuse': 9, 'relaxante': 0, 'caressante': 0, 'biscaïenne': 4, 'virile': 0, 'sommative': 7, 'médicolégale': 3, 'haschichée': 0, 'procrastinatrice': 1, 'auriculo-temporale': 3, 'abstractive': 7, 'antivenimeuse': 9, 'matinale': 3, 'chroniqueuse': 2, 'ravine': 0, 'componctueuse': 9, 'transandine': 0, 'byzantine': 0, 'modérée': 0, 'robinetière': 6, 'accidentelle': 4, 'foutrale': 0, 'psychostimulante': 0, 'exinscrite': 0, 'galeuse': 9, 'bêta-bloquante': 0, 'subconsciente': 0, 'bouvière': 6, 'tombeuse': 2, 'franco-canadienne': 4, 'étireuse': 2, 'verglacée': 0, 'globale': 3, 'extrasensorielle': 4, 'oléagineuse': 9, 'frileuse': 9, 'jetsetteuse': 2, 'acquéreuse': 2, 'néo-grammairienne': 4, 'gondolière': 6, 'tuilière': 6, 'clavelée': 0, 'tellurienne': 4, 'eurodéputée': 0, 'rédemptrice': 1, 'meunière': 6, 'marketeuse': 2, 'azérie': 0, 'margeuse': 2, 'congestive': 7, 'faucheuse': 2, 'convulsive': 7, 'buteuse': 2, 'détractrice': 1, 'dormante': 0, 'villafranchienne': 4, 'incidente': 0, 'désosseuse': 2, 'rengagée': 0, 'illusionnée': 0, 'herculéenne': 4, 'diagonale': 3, 'empileuse': 2, 'analysante': 0, 'gondolante': 0, 'furtive': 7, 'muletière': 6, 'aérotransportée': 0, 'collectrice': 1, 'folioteuse': 2, 'chalonnaise': 0, 'arrobase': 0, 'parente': 0, 'lamaneuse': 2, 'pénitente': 0, 'porcelainière': 6, 'renvoyée': 0, 'freineuse': 2, 'rosière': 6, 'coadjutrice': 1, 'communicante': 0, 'ambitieuse': 9, 'roborative': 7, 'obturatrice': 1, 'grenouillante': 0, 'informative': 7, 'phylloxérée': 0, 'fabuleuse': 9, 'glorificatrice': 1, 'corrosive': 7, 'dératée': 0, 'cacaotière': 6, 'épilaryngienne': 4, 'géniale': 3, 'monovalente': 0, 'sino-américaine': 0, 'ribaude': 0, 'lézarde': 0, 'aliénante': 0, 'bénigne': 24, 'changeante': 0, 'vermiculée': 0, 'enrageante': 0, 'chocolatière': 6, 'ébouleuse': 9, 'estimatrice': 1, 'dominante': 0, 'nilo-saharienne': 4, 'grenailleuse': 2, 'neurovégétative': 7, 'danoise': 0, 'annuelle': 4, 'approximative': 7, 'sous-équipée': 0, 'murissante': 0, 'migratrice': 1, 'matutinale': 3, 'gigoteuse': 2, 'archidiocésaine': 0, 'hyperboréenne': 4, 'spinorielle': 4, 'exilée': 0, 'lyncheuse': 2, 'chromeuse': 2, 'antéro-postérieure': 0, 'frimeuse': 2, 'menteuse': 2, 'fraudeuse': 2, 'conglomérale': 3, 'ultrarésistante': 0, 'réfugiée': 0, 'ceinturière': 6, 'endogée': 0, 'communicative': 7, 'stérilisatrice': 1, 'comitiale': 3, 'impudente': 0, 'métropolitaine': 0, 'adextrée': 0, 'baconienne': 4, 'nasilleuse': 2, 'préservative': 7, 'julienne': 4, 'prochinoise': 0, 'essencière': 6, 'postdoctorante': 0, 'suborbitale': 3, 'organisationnelle': 4, 'shogounale': 3, 'siccative': 7, 'sous-développée': 0, 'séricicultrice': 1, 'peinarde': 0, 'grelotante': 0, 'monteuse': 2, 'corrompue': 0, 'contiguë': 0, 'pelucheuse': 9, 'déviante': 0, 'sifflante': 0, 'serine': 0, 'infectée': 0, 'tour-opératrice': 1, 'musicale': 3, 'décidue': 0, 'balourde': 0, 'marqueuse': 2, 'croupale': 3, 'acridienne': 4, 'revendicative': 7, 'liminale': 3, 'dinandière': 6, 'procureuse': 2, 'nigériane': 0, 'plumassière': 6, 'sibérienne': 4, 'impolie': 0, 'préemballée': 0, 'prooccidentale': 3, 'queutarde': 0, 'pendante': 0, 'subaigüe': 12, 'courtille': 4, 'logicienne': 4, 'coopérative': 7, 'bohémienne': 4, 'thermisée': 0, 'grésillante': 0, 'girondine': 0, 'bateleuse': 2, 'transgressive': 7, 'chipoteuse': 2, 'sinueuse': 9, 'presbytérienne': 4, 'euro-méditerranéenne': 4, 'équinoxiale': 3, 'périclitante': 0, 'violette': 4, 'nocive': 7, 'pailleuse': 9, 'alcoolorésistante': 0, 'laitée': 0, 'athéromateuse': 9, 'hémolysante': 0, 'interalliée': 0, 'quarte': 0, 'polarisante': 0, 'urineuse': 9, 'grenadienne': 4, 'réale': 3, 'coécrite': 0, 'phénoménale': 3, 'keynésienne': 4, 'daronne': 4, 'sonneuse': 2, 'martiale': 3, 'minéralisatrice': 1, 'pavillonnée': 0, 'décapitée': 0, 'bucheuse': 2, 'indo-aryenne': 4, 'basilicale': 3, 'iridienne': 4, 'chantourneuse': 2, 'zéphyrienne': 4, 'dépliante': 0, 'punitive': 7, 'déconcertante': 0, 'jacassante': 0, 'amicrobienne': 4, 'horrifiante': 0, 'mûre': 0, 'robineuse': 9, 'carnassière': 6, 'juxtaposante': 0, 'mauvaise': 0, 'cartonneuse': 9, 'abondée': 0, 'inachevée': 0, 'triomphale': 3, 'couchante': 0, 'pascale': 0, 'louvette': 4, 'stricte': 0, 'châtaine': 0, 'non-initiée': 0, 'courbatue': 0, 'débauchée': 0, 'phéniquée': 0, 'écrivailleuse': 2, 'brute': 0, 'certaine': 0, 'téléactrice': 1, 'damnée': 0, 'rhabdomancienne': 4, 'factrice': 1, 'normative': 7, 'sertisseuse': 2, 'ultra-résistante': 0, 'montréalaise': 0, 'circadienne': 4, 'lionnée': 0, 'gueuse': 9, 'feignante': 0, 'sabéenne': 4, 'contagieuse': 9, 'amazonienne': 4, 'laïusseuse': 2, 'superlourde': 0, 'missilière': 6, 'cornemuseuse': 2, 'vitale': 3, 'hilarante': 0, 'œdipienne': 4, 'freinante': 0, 'impérative': 7, 'populicultrice': 1, 'brûlante': 0, 'photosensibilisante': 0, 'néronienne': 4, 'raquetière': 6, 'abductrice': 1, 'électromotrice': 1, 'catalogueuse': 2, 'impulsive': 7, 'parolière': 6, 'négative': 7, 'quadrifoliée': 0, 'plane': 0, 'caséeuse': 9, 'rassise': 0, 'codominante': 0, 'éveilleuse': 2, 'pondératrice': 1, 'aérostière': 6, 'anticlinale': 3, 'bootleggeuse': 2, 'solutréenne': 4, 'enivrante': 0, 'fixative': 7, 'ragoûtante': 0, 'mesquine': 0, 'biophysicienne': 4, 'méritante': 0, 'handballeuse': 2, 'franco-équatorienne': 4, 'sanctifiée': 0, 'rectosigmoïdienne': 4, 'suraiguë': 0, 'cratérisée': 0, 'inconditionnelle': 4, 'insondée': 0, 'pariétale': 3, 'intersectionnelle': 4, 'diserte': 0, 'fricasseuse': 2, 'œstroprogestative': 7, 'suppressive': 7, 'pétulante': 0, 'tardive': 7, 'dialogueuse': 2, 'lambine': 0, 'passée': 0, 'solliciteuse': 2, 'combattante': 0, 'associative': 7, 'thermocollante': 0, 'caricaturale': 3, 'gratuite': 0, 'châtelperronienne': 4, 'automotrice': 1, 'zouloue': 0, 'carreautée': 0, 'gourde': 0, 'extravertie': 0, 'pontificale': 3, 'psychoaffective': 7, 'maïeure': 0, 'viciatrice': 1, 'magasinière': 6, 'costale': 3, 'égoutière': 6, 'obsidionale': 3, 'fondamentale': 3, 'palmiséquée': 0, 'odorante': 0, 'extradée': 0, 'létale': 3, 'gaie': 0, 'amandée': 0, 'arbustive': 7, 'inexpliquée': 0, 'prêtresse': 16, 'lampante': 0, 'capitale': 3, 'libérale': 3, 'armurée': 0, 'pharmacienne': 4, 'antifiscale': 3, 'pastorale': 3, 'ravineuse': 9, 'chancelière': 6, 'post-doctorante': 0, 'potentielle': 4, 'besantée': 0, 'guêpière': 6, 'atrière': 6, 'inintéressante': 0, 'assoupissante': 0, 'itérative': 7, 'dégonflarde': 0, 'guillotinée': 0, 'apiéceuse': 2, 'diminutive': 7, 'visiteuse': 2, 'congruente': 0, 'adorée': 0, 'pyramidale': 3, 'piaillarde': 0, 'anticyclonale': 3, 'minette': 4, 'transmetteuse': 2, 'matriarcale': 3, 'calcifiée': 0, 'comminutive': 7, 'brachiale': 3, 'agneline': 0, 'timorée': 0, 'argenteuse': 2, 'usurpatrice': 1, 'gastro-œsophagienne': 4, 'hilbertienne': 4, 'prudhommale': 3, 'pantelante': 0, 'rectorale': 3, 'dépanneuse': 2, 'préencollée': 0, 'irrationnelle': 4, 'républicaine': 0, 'liquidienne': 4, 'félonne': 4, 'respectueuse': 9, 'injective': 7, 'douillette': 4, 'franco-ukrainienne': 4, 'coupante': 0, 'soyeuse': 9, 'remuante': 0, 'surproductive': 7, 'toulonnaise': 0, 'godilleuse': 2, 'maraudeuse': 2, 'ménagère': 6, 'interagissante': 0, 'casuelle': 4, 'plutonienne': 4, 'peseuse': 2, 'procédurière': 6, 'reconstructrice': 1, 'férale': 3, 'broyeuse': 2, 'putassière': 6, 'réjouissante': 0, 'gréeuse': 2, 'chantante': 0, 'manuelle': 4, 'rate': 0, 'braillarde': 0, 'ségrégée': 0, 'millimétrée': 0, 'dictatoriale': 3, 'quinée': 0, 'plaisante': 0, 'jaboteuse': 2, 'innommée': 0, 'elzévirienne': 4, 'trufficultrice': 1, 'transcaspienne': 4, 'équivariante': 0, 'froide': 0, 'anale': 3, 'électroluminescente': 0, 'éburnée': 0, 'crènelée': 0, 'dégrossisseuse': 2, 'amidonnière': 6, 'manieuse': 2, 'remettante': 0, 'ardue': 0, 'mitrailleuse': 2, 'réplétive': 7, 'mineure': 0, 'dindonnière': 6, 'doucereuse': 9, 'linnéenne': 4, 'crissante': 0, 'envolée': 0, 'saine': 0, 'ongulée': 0, 'affamée': 0, 'votive': 7, 'parquetière': 6, 'fervente': 0, 'subjective': 7, 'instantanée': 0, 'antireligieuse': 9, 'universelle': 4, 'équipotente': 0, 'classificatrice': 1, 'donjonnée': 0, 'mycorhizienne': 4, 'duveteuse': 9, 'continentale': 3, 'multirésistante': 0, 'malotrue': 0, 'substitutive': 7, 'portoricaine': 0, 'ultraconfidentielle': 4, 'gobeline': 0, 'magnétiseuse': 2, 'hypercorrecte': 0, 'antirétrovirale': 3, 'ensorceleuse': 2, 'farinacée': 0, 'vitreuse': 9, 'membrée': 0, 'usufruitière': 6, 'latente': 0, 'bigote': 0, 'saccharine': 0, 'prospectrice': 1, 'promotrice': 1, 'maniacodépressive': 7, 'droitière': 6, 'racée': 0, 'conjecturale': 3, 'argileuse': 9, 'distincte': 0, 'adénovirale': 3, 'expectante': 0, 'factieuse': 9, 'enseignante': 0, 'carillonneuse': 2, 'latino-américaine': 0, 'ébouquetée': 0, 'frangine': 0, 'représentante': 0, 'urgente': 0, 'aurorale': 3, 'vagale': 3, 'surfeuse': 2, 'lubrifiante': 0, 'vivandière': 6, 'audacieuse': 9, 'affriquée': 0, 'brouillassée': 0, 'indistincte': 0, 'obstétricale': 3, 'hydrolienne': 4, 'captive': 7, 'voyeuse': 2, 'imméritée': 0, 'rétrospective': 7, 'balinaise': 0, 'cliveuse': 2, 'nécromancienne': 4, 'franco-polonaise': 0, 'plaisancière': 6, 'eulérienne': 4, 'directive': 7, 'assujettissante': 0, 'excessive': 7, 'sous-officière': 6, 'est-allemande': 0, 'moqueuse': 2, 'copartageante': 0, 'contre-attaquante': 0, 'saccageuse': 2, 'non-engagée': 0, 'râteleuse': 2, 'luthière': 6, 'moralisatrice': 1, 'frictionnelle': 4, 'crevarde': 0, 'hargneuse': 9, 'rétro-éclairée': 0, 'dépressive': 7, 'polyhandicapée': 0, 'grégorienne': 4, 'invitante': 0, 'observatrice': 1, 'loqueteuse': 9, 'brigantine': 0, 'surprotectrice': 1, 'défunte': 0, 'transfiguratrice': 1, 'mensongère': 6, 'exorbitante': 0, 'azerbaïdjanaise': 0, 'luxurieuse': 9, 'somalie': 0, 'emmanchée': 0, 'couvreuse': 2, 'gingivale': 3, 'romanisante': 0, 'anglicane': 0, 'oléfiante': 0, 'numérative': 7, 'gaillarde': 0, 'laryngale': 3, 'sujette': 4, 'agrotechnicienne': 4, 'inéduquée': 0, 'éplucheuse': 2, 'déficiente': 0, 'horsaine': 0, 'corroyeuse': 2, 'décotée': 0, 'buissonneuse': 9, 'parenchymateuse': 9, 'insubordonnée': 0, 'gazonneuse': 9, 'jupitérienne': 4, 'dévalorisante': 0, 'texturale': 3, 'ahurissante': 0, 'sérieuse': 9, 'romancière': 6, 'longue': 4, 'sociétale': 3, 'montagneuse': 9, 'chilienne': 4, 'végétalienne': 4, 'botteuse': 2, 'jargonnante': 0, 'fomentatrice': 1, 'aminée': 0, 'interzonale': 3, 'portative': 7, 'irréelle': 4, 'inédite': 0, 'assimilatrice': 1, 'phénicienne': 4, 'pseudodifférentielle': 4, 'têtue': 0, 'liseuse': 2, 'morale': 3, 'pluriculturelle': 4, 'franco-paraguayenne': 4, 'péquenotte': 4, 'glorifiante': 0, 'intégrante': 0, 'pâlotte': 4, 'confucéenne': 4, 'autorégulatrice': 1, 'murie': 0, 'papilionacée': 0, 'agricultrice': 1, 'impure': 0, 'jaseuse': 2, 'bouffeuse': 2, 'adiposo-génitale': 3, 'filamenteuse': 9, 'féconde': 0, 'cuisante': 0, 'multiraciale': 3, 'profitante': 0, 'inorganisée': 0, 'successive': 7, 'acquisitive': 7, 'pagayeuse': 2, 'régularisatrice': 1, 'campignienne': 4, 'herbagère': 6, 'réactive': 7, 'taquine': 0, 'excitomotrice': 1, 'vendéenne': 4, 'antiadhésive': 7, 'empoignante': 0, 'mosane': 0, 'tempétueuse': 9, 'dépréciative': 7, 'rhinopharyngée': 0, 'palpébrale': 3, 'introublée': 0, 'interrogative': 7, 'improductive': 7, 'modalisatrice': 1, 'étourdissante': 0, 'immotivée': 0, 'hurlante': 0, 'morbilleuse': 9, 'bote': 0, 'immaculée': 0, 'harceleuse': 2, 'déterminante': 0, 'générale': 3, 'additive': 7, 'thaïe': 0, 'évoluée': 0, 'diluvienne': 4, 'indoue': 0, 'vacillante': 0, 'américano-néo-zélandaise': 0, 'politicienne': 4, 'toquarde': 0, 'geignante': 0, 'aquitaine': 0, 'préconçue': 0, 'ainée': 0, 'lubrificatrice': 1, 'pommée': 0, 'myxœdémateuse': 9, 'pubienne': 4, 'vanillée': 0, 'invocatrice': 1, 'natoufienne': 4, 'appontée': 0, 'malplaisante': 0, 'impayée': 0, 'abotée': 0, 'locutrice': 1, 'minimale': 3, 'squirreuse': 9, 'rameuse': 9, 'suante': 0, 'angoreuse': 9, 'intoxiquée': 0, 'aliénatrice': 1, 'transcanadienne': 4, 'gouvernementale': 3, 'omnipotente': 0, 'ethnocentrée': 0, 'raveuse': 2, 'dimensionnelle': 4, 'impaludée': 0, 'incrusteuse': 2, 'trisaïeule': 0, 'suintante': 0, 'grasseyante': 0, 'macédonienne': 4, 'oniromancienne': 4, 'bidirectionnelle': 4, 'truffière': 6, 'taurine': 0, 'iléo-cæcale': 3, 'enquêtée': 0, 'prénuptiale': 3, 'mycénienne': 4, 'déformante': 0, 'néo-zélandaise': 0, 'effrénée': 0, 'décideuse': 2, 'aciéreuse': 9, 'normée': 0, 'carieuse': 9, 'formière': 6, 'incrustante': 0, 'expiatrice': 1, 'fonctorielle': 4, 'conjoncturelle': 4, 'agroforestière': 6, 'syndiquée': 0, 'ingénue': 0, 'fière': 6, 'fémorale': 3, 'rassurante': 0, 'mariale': 3, 'neurochirurgienne': 4, 'abougrie': 0, 'fictionnelle': 4, 'transneptunienne': 4, 'industrieuse': 9, 'reproductive': 7, 'smaragdine': 0, 'palliative': 7, 'extra-forte': 0, 'étincelante': 0, 'nombreuse': 9, 'improbatrice': 1, 'déconstruisante': 0, 'infichue': 0, 'uninominale': 3, 'porteuse': 2, 'gestuelle': 4, 'digestive': 7, 'ânesse': 16, 'denticulée': 0, 'gypseuse': 9, 'cubaine': 0, 'attardée': 0, 'compréhensive': 7, 'franco-irakienne': 4, 'classeuse': 2, 'interféconde': 0, 'décadente': 0, 'maboule': 0, 'métallière': 6, 'inventive': 7, 'polypeuse': 9, 'pardonnante': 0, 'grelottante': 0, 'prééminente': 0, 'saucière': 6, 'artificière': 6, 'trine': 0, 'rétractive': 7, 'marcheuse': 2, 'rectificative': 7, 'alcoolo-résistante': 0, 'gourmande': 0, 'cap-hornière': 6, 'mécanicienne': 4, 'bloquante': 0, 'impénitente': 0, 'hégirienne': 4, 'enquiquineuse': 2, 'variqueuse': 9, 'adamantine': 0, 'belliqueuse': 9, 'démente': 0, 'aimée': 0, 'fromagée': 0, 'arrivante': 0, 'fastigiée': 0, 'exanthémateuse': 9, 'schisteuse': 9, 'agrippante': 0, 'tronçonneuse': 2, 'laurée': 0, 'arabisante': 0, 'claudélienne': 4, 'divinatrice': 1, 'délirante': 0, 'torse': 0, 'déshonorante': 0, 'inentendue': 0, 'encolleuse': 2, 'blousante': 0, 'coopérante': 0, 'provisionnelle': 4, 'fasciculée': 0, 'islandaise': 0, 'paraphraseuse': 2, 'tendancieuse': 9, 'scribouillarde': 0, 'semencière': 6, 'patriotarde': 0, 'désespérante': 0, 'insultante': 0, 'désherbante': 0, 'sikhe': 0}

ASCIIZERO = 48  # 48 is the ASCII code for "0"

def isFemForm (s):
    "returns True if s exists in dMasFW"
    if s in _dMasFW:
        return True
    return False

def getMasForm (s, bPlur):
    "returns masculine form with feminine form"
    if s in _dMasFW:
        return _modifyStringWithSuffixCode(s, _whatSuffixCode(_lTags[_dMasFW[s]], bPlur))
    return ""

def isMiscPlural (s):
    "returns True if s exists in dPlurMisc"
    if s in _dPlurMisc:
        return True
    return False

def getMiscPlural (s):
    "returns plural form with singular form"
    if s in _dPlurMisc:
        return _modifyStringWithSuffixCode(s, _lTags[_dPlurMisc[s]])
    return ""

def _whatSuffixCode (sAff, bPlur):
    "necessary only for dMasFW"
    if bPlur:
        if "|" not in sAff:
            return sAff+"s"
        return sAff[sAff.find("|")+1:]
    if "|" in sAff:
        return sAff[:sAff.find("|")]
    return sAff

def _modifyStringWithSuffixCode (s, sAff):
    "returns s modified by sAff"
    if not sAff:
        return ""
    if sAff == "0":
        return s
    try:
        return s[:-(ord(sAff[0])-ASCIIZERO)] + sAff[1:]  if sAff[0] != '0'  else  s + sAff[1:]
    except:
        return u"## erreur, code : " + str(sAff) + " ##"
